 addon/doxywizard/configdoc.h                   |    4 +
 addon/doxywizard/doxywizard.cpp                |  189 +-
 addon/doxywizard/doxywizard.pro.in             |    3 +
 addon/doxywizard/doxywizard_ja_JP.ts           | 3288 ++++++++++++++++++++++++
 addon/doxywizard/expert.cpp                    |  175 +-
 addon/doxywizard/for_lupdate_doxywizard.pro.in |    5 +
 addon/doxywizard/wizard.cpp                    |    2 +-
 configure                                      |    2 +-
 src/config.xml                                 |   17 +-
 src/configgen.py                               |   57 +
 10 files changed, 3613 insertions(+), 129 deletions(-)

diff --git a/addon/doxywizard/configdoc.h b/addon/doxywizard/configdoc.h
index 97ed6c3..cb849f6 100644
--- a/addon/doxywizard/configdoc.h
+++ b/addon/doxywizard/configdoc.h
@@ -1,8 +1,12 @@
 #ifndef CONFIGDOC_H
 #define CONFIGDOC_H
 
+#include <qmap.h>
+#include <qstring.h>
+
 class DocIntf;
 
 void addConfigDocs(DocIntf *doc);
+void addConfigDocs(QMap<QString, QString>* map);
 
 #endif
diff --git a/addon/doxywizard/doxywizard.cpp b/addon/doxywizard/doxywizard.cpp
index ce764e0..0b48979 100644
--- a/addon/doxywizard/doxywizard.cpp
+++ b/addon/doxywizard/doxywizard.cpp
@@ -21,29 +21,29 @@ MainWindow &MainWindow::instance()
 MainWindow::MainWindow()
   : m_settings(QString::fromAscii("Doxygen.org"), QString::fromAscii("Doxywizard"))
 {
-  QMenu *file = menuBar()->addMenu(tr("File"));
-  file->addAction(tr("Open..."), 
+  QMenu *file = menuBar()->addMenu(tr("&File"));
+  file->addAction(tr("&Open..."), 
                   this, SLOT(openConfig()), Qt::CTRL+Qt::Key_O);
-  m_recentMenu = file->addMenu(tr("Open recent"));
-  file->addAction(tr("Save"), 
+  m_recentMenu = file->addMenu(tr("Open &recent"));
+  file->addAction(tr("&Save"), 
                   this, SLOT(saveConfig()), Qt::CTRL+Qt::Key_S);
-  file->addAction(tr("Save as..."), 
+  file->addAction(tr("Save &as..."), 
                   this, SLOT(saveConfigAs()), Qt::SHIFT+Qt::CTRL+Qt::Key_S);
-  file->addAction(tr("Quit"),  
+  file->addAction(tr("&Quit"),  
                   this, SLOT(quit()), Qt::CTRL+Qt::Key_Q);
 
-  QMenu *settings = menuBar()->addMenu(tr("Settings"));
-  settings->addAction(tr("Reset to factory defaults"),
+  QMenu *settings = menuBar()->addMenu(tr("&Settings"));
+  settings->addAction(tr("&Reset to factory defaults"),
                   this,SLOT(resetToDefaults()));
-  settings->addAction(tr("Use current settings at startup"),
+  settings->addAction(tr("&Use current settings at startup"),
                   this,SLOT(makeDefaults()));
-  settings->addAction(tr("Clear recent list"),
+  settings->addAction(tr("&Clear recent list"),
                   this,SLOT(clearRecent()));
 
-  QMenu *help = menuBar()->addMenu(tr("Help"));
-  help->addAction(tr("Online manual"), 
+  QMenu *help = menuBar()->addMenu(tr("&Help"));
+  help->addAction(tr("&Online manual"), 
                   this, SLOT(manual()), Qt::Key_F1);
-  help->addAction(tr("About"), 
+  help->addAction(tr("&About"), 
                   this, SLOT(about()) );
 
   m_expert = new Expert;
@@ -244,8 +244,7 @@ void MainWindow::saveConfig(const QString &fileName)
   {
     QMessageBox::warning(this,
         tr("Error saving"),
-        tr("Error: cannot open the file ")+fileName+tr(" for writing!\n")+
-        tr("Reason given: ")+f.error());
+        tr("Error: cannot open the file %1 for writing.\nReason given: %2").arg(fileName).arg(f.error()));
     return;
   }
   QTextStream t(&f);
@@ -426,7 +425,7 @@ void MainWindow::runDoxygen()
       }
       else 
       {
-        qDebug() << tr("Can't find the doxygen command, make sure it's in your $$PATH");
+        qDebug() << tr("Can't find the doxygen command, make sure it's in your $$PATH.");
         doxygenPath = QString::fromAscii("");
       }
     }
@@ -554,7 +553,7 @@ void MainWindow::saveLog()
     else
     {
       QMessageBox::warning(0,tr("Warning"),
-          tr("Cannot open file ")+fn+tr(" for writing. Nothing saved!"),tr("ok"));
+          tr("Cannot open file %1 for writing. Nothing saved.").arg(fn),tr("ok"));
     }
   }
 }
@@ -625,19 +624,157 @@ bool MainWindow::discardUnsavedChanges(bool saveOption)
 
 //-----------------------------------------------------------------------
 
-int main(int argc,char **argv)
+struct ArgumentDecoder
 {
-  QApplication a(argc,argv);
-  MainWindow &main = MainWindow::instance();
-  if (argc==2 && argv[1][0]!='-') // name of config file as an argument
+  public:
+  struct ArgToFunc
+  {
+    public:
+    ArgToFunc() : m_func( NULL ) { }
+    ArgToFunc( const char *const optstr, void (ArgumentDecoder::*func)( QString ) )
+      : m_opt( QString::fromAscii( optstr ) ), m_func( func ), m_called( false )
+    {
+    }
+    bool valid() const { return m_opt.length() || m_func; }
+    bool checkMatch( const QString& arg, ArgumentDecoder& decoder )
+    {
+      if ( arg.indexOf( m_opt ) != 0 )
+      {
+        return false;
+      }
+      if ( m_called )
+      {
+        qDebug() << m_opt
+          + QString::fromAscii( " called twice: " ) + arg
+          + QString::fromAscii( "\n" );
+      }
+      m_called = true;
+      (decoder.*m_func)( arg.mid( m_opt.length() ) );
+      return true;
+    }
+
+    QString m_opt;
+    void (ArgumentDecoder::*m_func)( QString );
+    bool m_called;
+  };
+  
+  ArgumentDecoder( const QApplication& app, QTranslator* translator )
+     : m_app( app ), m_translator( translator )
+  {
+  }
+
+  void decode()
+  {
+    QStringList args = m_app.arguments();
+    m_locale = QLocale::system().name();
+    m_locale_overwritten = false;
+    m_localeFileDir = m_app.applicationDirPath();
+    
+    ArgToFunc optlist[] = 
+    {
+      // Longer named option should be first.
+      ArgToFunc( "--help", &ArgumentDecoder::processHelp),
+      ArgToFunc( "--ld:", &ArgumentDecoder::processLocaleFileDir ),
+      ArgToFunc( "--l:", &ArgumentDecoder::processLocale ),
+      ArgToFunc( "-h", &ArgumentDecoder::processHelp),
+      ArgToFunc( "-?", &ArgumentDecoder::processHelp),
+      ArgToFunc( "", &ArgumentDecoder::processConfigFile ),
+      ArgToFunc()
+    };
+    
+    QStringList::ConstIterator it = args.begin();
+    for ( ++it ; it != args.end() ; ++it )
+    {
+      for ( int i = 0; optlist[ i ].valid(); ++i )
+      {
+        if ( optlist[ i ].checkMatch( *it, *this ) )
+        {
+          break;
+        }
+      }
+    }
+    
+    if ( m_locale.length() )
+    {
+      QTextCodec::setCodecForTr( QTextCodec::codecForName( "utf8" ) );
+      QString l18nFileName = QString::fromAscii( "doxywizard_" ) + m_locale;
+      bool succeeded = m_translator->load( l18nFileName, m_localeFileDir );
+      if ( !succeeded && m_locale_overwritten )
+      {
+        QMessageBox::warning(
+          NULL,
+          QString::fromAscii( "Localization error" ),
+          l18nFileName + QString::fromAscii( ".qm or valid localization file not found." )
+        );
+      }
+      m_app.installTranslator( m_translator );
+    }
+  }
+  
+  void processLocale( QString remain )
+  {
+    m_locale = remain;
+    m_locale_overwritten = true;
+  }
+  
+  void processConfigFile( QString remain )
+  {
+    if ( remain.indexOf( L'-' ) == 0 )
+    {
+      QMessageBox::warning(
+        NULL,
+        QString::fromAscii( "Doxywizard Error" ),
+        QString::fromAscii( "Unknown command/option: " )
+          + remain
+          + QString::fromAscii( "\n" )
+      );
+      processHelp( remain );
+    }
+    m_configFile = remain;
+    MainWindow &main = MainWindow::instance();
+    main.loadConfigFromFile( m_configFile );
+  }
+  
+  void processLocaleFileDir( QString remain )
   {
-    main.loadConfigFromFile(QString::fromLocal8Bit(argv[1]));
+    m_localeFileDir = remain;
   }
-  else if (argc>1)
+  
+  void processHelp( QString )
   {
-    printf("Usage: %s [config file]\n",argv[0]);
-    exit(1);
+    QMessageBox::information(
+      NULL,
+      QString::fromAscii( "Doxywizard help" ),
+      QString::fromAscii(
+        "Usage: doxywizard [--l:<locale_id>]"
+        " [--ld:localization_file_dir] [config_doxyfile]\n\n"
+        "<locale_id> is string like ja_JP, or empty not to translate.\n"
+        "The default value is the string QLocale::system().name() returns.\n"
+        "doxywizard will try to load translation file 'doxywizard_<locale_id>.qm'.\n"
+        "The default settiong of your environment is '%1',\n"
+        "to load 'doxywizard_%1.qm'.\n"
+        ).arg(QLocale::system().name())
+      );
+    exit( 1 );
   }
+  
+  const QApplication& m_app;
+  QTranslator* m_translator;
+  bool m_locale_overwritten;
+  QString m_locale;
+  QString m_localeFileDir;
+  QString m_configFile;
+};
+
+//-----------------------------------------------------------------------
+
+int main(int argc,char **argv)
+{
+  QApplication app(argc,argv);
+  QTranslator translator; // should alive as long as app.
+  ArgumentDecoder argDecorder( app, &translator );
+  argDecorder.decode();
+  MainWindow &main = MainWindow::instance();
   main.show();
-  return a.exec();
+  return app.exec();
 }
diff --git a/addon/doxywizard/doxywizard.pro.in b/addon/doxywizard/doxywizard.pro.in
index 01832df..307986f 100644
--- a/addon/doxywizard/doxywizard.pro.in
+++ b/addon/doxywizard/doxywizard.pro.in
@@ -27,6 +27,9 @@ RESOURCES   += doxywizard.qrc
 INCBUFSIZE=$(PYTHON)  ../../src/increasebuffer.py
 win32:RC_FILE += doxywizard.rc
 
+TRANSLATIONS = doxywizard_ja_JP.ts
+CODECFORTR = UTF-8
+
 config.target = config_doxyw.cpp
 config.commands = $(LEX) -P$*YY -t $*.l | $(INCBUFSIZE) >$*.cpp
 config.depends = config_doxyw.l  ../../src/increasebuffer.py
diff --git a/addon/doxywizard/doxywizard_ja_JP.ts b/addon/doxywizard/doxywizard_ja_JP.ts
new file mode 100644
index 0000000..4989a19
--- /dev/null
+++ b/addon/doxywizard/doxywizard_ja_JP.ts
@@ -0,0 +1,3288 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="ja_JP">
+<defaultcodec>UTF-8</defaultcodec>
+<context>
+    <name>ConfigDoc</name>
+    <message>
+        <location filename="configdoc.cpp" line="2294"/>
+        <source>The PROJECT_NUMBER tag can be used to enter a project or revision number. This
+could be handy for archiving the generated documentation or if some version
+control system is used.</source>
+        <translation>PROJECT_NUMBER には改版番号などを指定できます。出力ごとに整理したり版数管理に用いたりすることができます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2324"/>
+        <source>The OUTPUT_LANGUAGE tag is used to specify the language in which all
+documentation generated by doxygen is written. Doxygen will use this
+information to generate all constant output in the proper language.</source>
+        <translation>OUTPUT_LANGUAGE には文書全体がどの言語で出力されるかをご指定ください。定型的な単語はここで指定した言語に基づき出力されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2447"/>
+        <source>Set the OPTIMIZE_OUTPUT_JAVA tag to YES if your project consists of Java or
+Python sources only. Doxygen will then generate output that is more tailored
+for that language. For instance, namespaces will be presented as packages,
+qualified scopes will look different, etc.</source>
+        <translation>ソースコードが Java や Python のみの場合 OPTIMIZE_OUTPUT_JAVA に YES を与えるとより適切な出力になります。C++の名前空間が package に置き換わり、スコープの表現も違ったものになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2617"/>
+        <source>If the HIDE_FRIEND_COMPOUNDS tag is set to YES, doxygen will hide all friend
+(class|struct|union) declarations. If set to NO these declarations will be
+included in the documentation.</source>
+        <translation>HIDE_FRIEND_COMPOUNDS に YES を指定すると friend 関係のクラス、構造体、共用体宣言を隠します。
+NO であればこれらも詳解に含められます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2703"/>
+        <source>The GENERATE_TODOLIST tag can be used to enable ( YES) or disable ( NO) the
+todo list. This list is created by putting \todo commands in the
+documentation.</source>
+        <translation>GENERATE_TODOLIST により TODO 一覧を含むかどうかを指示できます。
+この一覧はソースコードに \todo コマンドで記載した内容を元に作られます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2736"/>
+        <source>Set the SHOW_USED_FILES tag to NO to disable the list of files generated at
+the bottom of the documentation of classes and structs. If set to YES the list
+will mention the files that were used to generate the documentation.</source>
+        <translation>クラスや構造体の詳解末尾に抽出元となったファイルの一覧を作るかどうかを定められます。
+SHOW_USED_FILES に NO を指定すると説明文のあったファイル一覧は追加されなくなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3030"/>
+        <source>If the GENERATE_HTML tag is set to YES doxygen will generate HTML output.</source>
+        <translation>GENERATE_HTML に YES を与えると HTML 系の出力を行います。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3068"/>
+        <source>The HTML_STYLESHEET tag can be used to specify a user-defined cascading style
+sheet that is used by each HTML page. It can be used to fine-tune the look of
+the HTML output. If left blank doxygen will generate a default style sheet.
+See also section &quot;Doxygen usage&quot; for information on how to generate the style
+sheet that doxygen normally uses.
+Note: It is recommended to use HTML_EXTRA_STYLESHEET instead of this tag, as
+it is more robust and this tag (HTML_STYLESHEET) will in the future become
+obsolete.</source>
+        <translation>HTML_STYLESHEET により独自に用意したスタイルシート(CSS, Cascading Style Sheet)を指定できます。
+指定したスタイルシートは各々の HTML ページに適用され、見た目の調整に利用できます。指定がなければ doxygen が用意しているものをそのまま適用します。
+説明書の &quot;Doxygen usage&quot; 節に doxygen が通常使うスタイルシートについての情報があります。
+
+注意: HTML_EXTRA_STYLESHEET を代わりに使うことをお勧めします。より的確な制御ができるだけでなく HTML_STYLESHEET は将来廃止する可能性があります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3126"/>
+        <source>With HTML_INDEX_NUM_ENTRIES one can control the preferred number of entries
+shown in the various tree structured indices initially; the user can expand
+and collapse entries dynamically later on. Doxygen will expand the tree to
+such a level that at most the specified number of entries are visible (unless
+a fully collapsed tree already exceeds this amount). So setting the number of
+entries 1 will produce a full collapsed tree by default. 0 is a special value
+representing an infinite number of entries and will result in a full expanded
+tree by default.</source>
+        <translation>HTML_INDEX_NUM_ENTRIES には各種の木構造で表示される項目の初期表示数をご指定ください。読者は動的にこれらを展開したり閉じたりできます。
+
+指定値と同じ段数だけ根からの階層段数分が初期展開されます。完全に閉じた状態が指定値を超えている場合は根要素だけが初期の表示内容となります。
+
+従って 1 の場合、木構造の初期状態が常に完全に閉じています。
+0 は他の値とは異なり、逆に完全に開いた状態になります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2281"/>
+        <source>This tag specifies the encoding used for all characters in the config file
+that follow. The default is UTF-8 which is also the encoding used for all text
+before the first occurrence of this tag. Doxygen uses libiconv (or the iconv
+built into libc) for the transcoding. See http://www.gnu.org/software/libiconv
+for the list of possible encodings.</source>
+        <translation>設定ファイル自身の文字符号化法は指定がなければ UTF-8 として処理されます。DOXYFILE_ENCODING を用いるとこの動作を変更できます。
+Doxygen は libiconv または libc に内蔵されている iconv を用いて文字列を読み取ります。指定できる符号化法は http://www.gnu.org/software/libiconv を参照ください。
+Doxywizard はこの指定を設定ファイルの先頭に置きます。他の手段で先頭以外に置かれた場合はその位置以降から指定の符号化法が適用されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2288"/>
+        <source>The PROJECT_NAME tag is a single word (or a sequence of words surrounded by
+double-quotes, unless you are using Doxywizard) that should identify the
+project for which the documentation is generated. This name is used in the
+title of most generated pages and in a few other places.</source>
+        <translation>PROJECT_NAME には文書全体に共通する名前をご指定ください。他の文書集合と区別するために用います。
+指定された文字列は各ページやいくつかの特定場所に用いられます。
+Doxywizard _以外_ を用いる場合、かつ複数の単語から成る場合は二重引用符 &quot; で括る必要があります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2299"/>
+        <source>Using the PROJECT_BRIEF tag one can provide an optional one line description
+for a project that appears at the top of each page and should give viewer a
+quick idea about the purpose of the project. Keep the description short.</source>
+        <translation>PROJECT_BRIEFには各ページの先頭に現れる追加部分の文章をご指定ください。
+プロジェクトの目的を簡潔に記した短い文にすべきです。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2304"/>
+        <source>With the PROJECT_LOGO tag one can specify an logo or icon that is included in
+the documentation. The maximum height of the logo should not exceed 55 pixels
+and the maximum width should not exceed 200 pixels. Doxygen will copy the logo
+to the output directory.</source>
+        <translation>PROJECT_LOGO により図案ないし図像を文書に与えることができます。
+図案の寸法は 縦50×横200 ピクセルに収めるのがよいでしょう。指定ファイル自体も出力先に複製されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2310"/>
+        <source>The OUTPUT_DIRECTORY tag is used to specify the (relative or absolute) path
+into which the generated documentation will be written. If a relative path is
+entered, it will be relative to the location where doxygen was started. If
+left blank the current directory will be used.</source>
+        <translation>文書全体の出力先は、相対パスにせよ絶対パスにせよ OUTPUT_DIRECTORY にご指定ください。
+相対パスは doxygen を起動したディレクトリを基準に解析されます。省略された場合は現在注目しているディレクトリを代用します。
+
+※ doxywizard からの場合は設定ファイルのディレクトリからとなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2316"/>
+        <source>If the CREATE_SUBDIRS tag is set to YES, then doxygen will create 4096 sub-
+directories (in 2 levels) under the output directory of each output format and
+will distribute the generated files over these directories. Enabling this
+option can be useful when feeding doxygen a huge amount of source files, where
+putting all generated files in the same directory would otherwise causes
+performance problems for the file system.</source>
+        <translation>CREATE_SUBDIRS に YES を与えると、出力形式ごとの出力先に 2 階層で 4096 個の子ディレクトリを生成します。また、それらの中に各種生成ファイルを配置します。
+ソースコードが大量にあるプロジェクトを処理する際に、ファイルシステムに負荷がかかりすぎるのを回避するために用意されています。
+</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2329"/>
+        <source>If the BRIEF_MEMBER_DESC tag is set to YES doxygen will include brief member
+descriptions after the members that are listed in the file and class
+documentation (similar to Javadoc). Set to NO to disable this.</source>
+        <translation>BRIEF_MEMBER_DESC に YES を与えると、ファイルやクラスの文書において、メンバ一覧の後に概要文を出力するようになります。Javadoc のような形になります。
+NO を与えるとこの動作を行いません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2334"/>
+        <source>If the REPEAT_BRIEF tag is set to YES doxygen will prepend the brief
+description of a member or function before the detailed description
+
+Note: If both HIDE_UNDOC_MEMBERS and BRIEF_MEMBER_DESC are set to NO, the
+brief descriptions will be completely suppressed.</source>
+        <translation>REPEAT_BRIEF に YES を与えると概要文を対応する各詳解文の前に改めて出力します。
+
+注意: HIDE_UNDOC_MEMBERS と BRIEF_MEMBER_DESC の両方が NO の場合は概要文がまったく出力されなくなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2341"/>
+        <source>This tag implements a quasi-intelligent brief description abbreviator that is
+used to form the text in various listings. Each string in this list, if found
+as the leading text of the brief description, will be stripped from the text
+and the result, after processing the whole list, is used as the annotated
+text. Otherwise, the brief description is used as-is. If left blank, the
+following values are used ($name is automatically replaced with the name of
+the entity):</source>
+        <translation>ABBREVIATE_BRIEF には、自動概要抽出もどき(quasi-intelligent)に用いられる冒頭文(群)を指定できます。概要文はいろいろな一覧内の文中で使われます。指定文字列のいずれかが概要文の先頭にあると、合致部分は出力から除外され、残りの部分を概要文本体として扱います。
+どの指定文字列にも先頭が一致しない概要文は、その全体が概要文になります。指定が全くない場合は次の文字列群が指定されたものとして扱われます。$name は項目名自身に置き換えられます:
+
+</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2350"/>
+        <source>If the ALWAYS_DETAILED_SEC and REPEAT_BRIEF tags are both set to YES then
+doxygen will generate a detailed section even if there is only a brief
+description.</source>
+        <translation>ALWAYS_DETAILED_SEC と REPEAT_BRIEFの両方に YES を与えると、概要文しかない項目に対しても詳解文区画を設けるようになります。 </translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2355"/>
+        <source>If the INLINE_INHERITED_MEMB tag is set to YES, doxygen will show all
+inherited members of a class in the documentation of that class as if those
+members were ordinary class members. Constructors, destructors and assignment
+operators of the base classes will not be shown.</source>
+        <translation>INLINE_INHERITED_MEMB に YES を与えると、各クラスごとに基底クラスのメンバについても各クラスのメンバ同様に文書が出力されます。構築子・解体子・代入演算子についてはこの機能は働きません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2361"/>
+        <source>If the FULL_PATH_NAMES tag is set to YES doxygen will prepend the full path
+before files name in the file list and in the header files. If set to NO the
+shortest path that makes the file name unique will be used.</source>
+        <oldsource>If the FULL_PATH_NAMES tag is set to YES doxygen will prepend the full path
+before files name in the file list and in the header files. If set to NO the
+shortest path that makes the file name unique will be used</oldsource>
+        <translation>FULL_PATH_NAMES に YES を与えると、ヘッダファイル一覧とファイル一覧におけるファイル名出力がフルパスになります。
+NO の場合はファイルが独立を保てる範囲で短いパスが用いられます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2376"/>
+        <source>The STRIP_FROM_INC_PATH tag can be used to strip a user-defined part of the
+path mentioned in the documentation of a class, which tells the reader which
+header file to include in order to use a class. If left blank only the name of
+the header file containing the class definition is used. Otherwise one should
+specify the list of include paths that are normally passed to the compiler
+using the -I flag.</source>
+        <translation>STRIP_FROM_INC_PATH を用いてパスのユーザ依存部を doxygen 本体に通知できます。クラス文書中に出てくるパスから、指定内容を切り落として出力するようになります。読者があるクラスを使いたいときにどのヘッダファイルを include したらよいかを伝えられるようにする目的で利用できます。
+
+指定がない場合は、クラス定義を含むヘッダファイルの名前のみが用いられます。そうでない文書に対しては一般に include パス群をコンパイラの -I オプションで指定する必要があります。
+</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2384"/>
+        <source>If the SHORT_NAMES tag is set to YES, doxygen will generate much shorter (but
+less readable) file names. This can be useful is your file systems doesn&apos;t
+support long names like on DOS, Mac, or CD-ROM.</source>
+        <translation>SHORT_NAMES に YES を与えるとより短い(かつ読みにくい)ファイル名で出力を行います。 DOS, Mac あるいは CD-ROM といった媒体に格納する目的で利用できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2389"/>
+        <source>If the JAVADOC_AUTOBRIEF tag is set to YES then doxygen will interpret the
+first line (until the first dot) of a Javadoc-style comment as the brief
+description. If set to NO, the Javadoc-style will behave just like regular Qt-
+style comments (thus requiring an explicit @brief command for a brief
+description.)</source>
+        <translation>JAVADOC_AUTOBRIEF に YES を与えると Javadoc 形式の注釈において、先頭行の最初のピリオドまでを概要文扱いとします。
+NO の場合は Qt 形式の注釈としてのみ処理されます。(従って @brief コマンドを使わないと概要文を定義できなくなります。)</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2396"/>
+        <source>If the QT_AUTOBRIEF tag is set to YES then doxygen will interpret the first
+line (until the first dot) of a Qt-style comment as the brief description. If
+set to NO, the Qt-style will behave just like regular Qt-style comments (thus
+requiring an explicit \brief command for a brief description.)</source>
+        <translation>QT_AUTOBRIEF に YES を与えると Qt 形式の注釈における最初の行から最初のピリオドまでを概要文として処理します。
+NO を与えるとこの機能はなくなります。(したがって概要文の定義には @brief コマンドが必須となります。)</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2402"/>
+        <source>The MULTILINE_CPP_IS_BRIEF tag can be set to YES to make doxygen treat a
+multi-line C++ special comment block (i.e. a block of //! or /// comments) as
+a brief description. This used to be the default behavior. The new default is
+to treat a multi-line C++ comment block as a detailed description. Set this
+tag to YES if you prefer the old behavior instead.
+
+Note that setting this tag to YES also means that rational rose comments are
+not recognized any more.</source>
+        <translatorcomment>rational rose comments の意味が不明瞭。</translatorcomment>
+        <translation>MULTILINE_CPP_IS_BRIEF に YES を与えると複数行の C++ 注釈ブロック(例えば //! や /// から成るブロック)を概要文とみなします。これは過去の標準動作でした。現在の標準動作は詳解文扱いです。旧来の動作に合わせたいときに YES を与えてください。
+
+注意: YES を与えると &apos;rational rose comments&apos; (関係する=relational /* */ 型の注釈?)は処理されなくなります</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2412"/>
+        <source>If the INHERIT_DOCS tag is set to YES then an undocumented member inherits the
+documentation from any documented member that it re-implements.</source>
+        <translation>INHERIT_DOCS に YES を与えると、記述のないメンバの文章は再実装の元となるメンバの文章を継承します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2416"/>
+        <source>If the SEPARATE_MEMBER_PAGES tag is set to YES, then doxygen will produce a
+new page for each member. If set to NO, the documentation of a member will be
+part of the file/class/namespace that contains it.</source>
+        <translation>SEPARATE_MEMBER_PAGES に YES を与えるとメンバごとに新しいページを生成します。 NO の場合はファイル・クラス・名前空間のページに各メンバの文書が収められます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2421"/>
+        <source>The TAB_SIZE tag can be used to set the number of spaces in a tab. Doxygen
+uses this value to replace tabs by spaces in code fragments.</source>
+        <translation>TAB_SIZE にはタブ一つにつきいくつの空白文字が使われるかをご指定ください。コード片にあるタブ文字はこの設定に従って空白に置き換えられます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2425"/>
+        <source>This tag can be used to specify a number of aliases that act as commands in
+the documentation. An alias has the form:
+name=value
+For example adding
+&quot;sideeffect=@par Side Effects:\n&quot;
+will allow you to put the command \sideeffect (or @sideeffect) in the
+documentation, which will result in a user-defined paragraph with heading
+&quot;Side Effects:&quot;. You can put \n&apos;s in the value part of an alias to insert
+newlines.</source>
+        <translation>ALIASES には文書内のコマンドのように動作する代用字列を指定できます。
+代用字列の指定は &apos;代用字列=実内容&apos; の書式を用います。
+例えば &quot;sideeffect=@par Side Effects:\n&quot; という内容の場合、本文中に \sideeffect あるいは @sideeffect が見つかると &quot;Side Effects:&quot; という見出しがついた利用者定義の段落に置き換えられます。&apos;\n&apos; は代用結果に改行を含めたいときに利用してください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2436"/>
+        <source>This tag can be used to specify a number of word-keyword mappings (TCL only).
+A mapping has the form &quot;name=value&quot;. For example adding &quot;class=itcl::class&quot;
+will allow you to use the command class in the itcl::class meaning.</source>
+        <translation>TCL_SUBST には任意数の単語-キーワードの割当を指定できます。TCL のみに効果があります。
+&quot;名前=値&quot; の形でご指定ください。例えば &quot;class=itcl::class&quot; という定義は &apos;class&apos; コマンドを itcl::class の意味で用いることができるようにします。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2441"/>
+        <source>Set the OPTIMIZE_OUTPUT_FOR_C tag to YES if your project consists of C sources
+only. Doxygen will then generate output that is more tailored for C. For
+instance, some of the names that are used will be different. The list of all
+members will be omitted, etc.</source>
+        <translation>C 言語のソースコードしかない場合は OPTIMIZE_OUTPUT_FOR_C を YES にするとよいでしょう。一部の出力用語がより C 専用となり、全メンバの一覧がなくなるなどの動作も合わせて行います。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2453"/>
+        <source>Set the OPTIMIZE_FOR_FORTRAN tag to YES if your project consists of Fortran
+sources. Doxygen will then generate output that is tailored for Fortran.</source>
+        <translation>Fortran のソースコードだけから成る場合は OPTIMIZE_FOR_FORTRAN に YES を与えるとよいでしょう。出力がより Fortran 向けのものになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2457"/>
+        <source>Set the OPTIMIZE_OUTPUT_VHDL tag to YES if your project consists of VHDL
+sources. Doxygen will then generate output that is tailored for VHDL.</source>
+        <translation>VHDL のソースコードだけから成る場合は OPTIMIZE_OUTPUT_VHDL に YES を与えると良いでしょう。より VHDL に特化した出力になります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2461"/>
+        <source>Doxygen selects the parser to use depending on the extension of the files it
+parses. With this tag you can assign which parser to use for a given
+extension. Doxygen has a built-in mapping, but you can override or extend it
+using this tag. The format is ext=language, where ext is a file extension, and
+language is one of the parsers supported by doxygen: IDL, Java, Javascript,
+C#, C, C++, D, PHP, Objective-C, Python, Fortran, VHDL. For instance to make
+doxygen treat .inc files as Fortran files (default is PHP), and .f files as C
+(default is Fortran), use: inc=Fortran f=C.
+
+Note For files without extension you can use no_extension as a placeholder.
+
+Note that for custom extensions you also need to set FILE_PATTERNS otherwise
+the files are not read by doxygen.</source>
+        <translation>doxygen は通常拡張子に合わせてその内容を解析します。 EXTENSION_MAPPING は拡張子と解析器の割り当ての定義を追加ないし上書きするときに用います。
+指定には &apos;拡張子=プログラミング言語&apos; の書式を使います。プログラミング言語は doxygen で対応できる  IDL, Java, Javascript,
+C#, C, C++, D, PHP, Objective-C, Python, Fortran, VHDL のいずれかをご指定ください。たとえば拡張子 inc (指定がなければ PHP 扱い) を Fortran として、また拡張子 f を C 言語として処理させたい場合は inc=Fortran f=C と指定します。拡張子がないファイルについては &apos;no_extension&apos; を代わりにご指定ください。
+
+注意: 元の割り当てがない拡張子については FILE_PATTERNS にも合わせてご指定ください。そうでないと解析対象として認識されません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2476"/>
+        <source>If the MARKDOWN_SUPPORT tag is enabled then doxygen pre-processes all comments
+according to the Markdown format, which allows for more readable
+documentation. See http://daringfireball.net/projects/markdown/ for details.
+The output of markdown processing is further processed by doxygen, so you can
+mix doxygen, HTML, and XML commands with Markdown formatting. Disable only in
+case of backward compatibilities issues.</source>
+        <translation>MARKDOWN_SUPPORT に YES を与えるとすべての注釈は Markdown 形式としての前処理を受けます。Markdown は(元の状態が)より読みやすい文章として残すための書式です。 http://daringfireball.net/projects/markdown/ をご覧ください。
+Markdown の出力処理はさらにその他の doxygen の処理に掛けられます。従って Markdown の書式に doxygen 型, HTML 型, XML 型の各コマンドを混用できます。
+NO を与えるのは後方互換用途のみと考えられています。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2484"/>
+        <source>When enabled doxygen tries to link words that correspond to documented
+classes, or namespaces to their corresponding documentation. Such a link can
+be prevented in individual cases by by putting a % sign in front of the word
+or globally by setting AUTOLINK_SUPPORT to NO.</source>
+        <translation>AUTOLINK_SUPPORT に YES を与えると単語から関連クラス・名前空間へのリンクを試みます。リンク先は文書が付いているものに限ります。自動リンクを拒否したい単語については当該語が文中に出るたびに % を前置してください。NO を与えるとこの自動リンクは生成されません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2490"/>
+        <source>If you use STL classes (i.e. std::string, std::vector, etc.) but do not want
+to include (a tag file for) the STL sources as input, then you should set this
+tag to YES in order to let doxygen match functions declarations and
+definitions whose arguments contain STL classes (e.g. func(std::string);
+versus func(std::string) {}). This also make the inheritance and collaboration
+diagrams that involve STL classes more complete and accurate.</source>
+        <translation>std::string や std::vector などの STL クラスを使っており、かつ入力ソースないしタグとしては STL のソースコードを含みたくない場合、 BUILTIN_STL_SUPPORT を YES にしてください。 STL のクラスを引数に取る関数宣言や関数定義は自動的に STL のものと判断されます。同時に STL クラスが入り込む各種関係図はより速く完全な動作になります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2498"/>
+        <source>If you use Microsoft&apos;s C++/CLI language, you should set this option to YES to
+enable parsing support.</source>
+        <translation>C++/CLI を使っているときは CPP_CLI_SUPPORT に YES を与えるとより正確な解析ができます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2502"/>
+        <source>Set the SIP_SUPPORT tag to YES if your project consists of sip (see:
+http://www.riverbankcomputing.co.uk/software/sip/intro) sources only. Doxygen
+will parse them like normal C++ but will assume all classes use public instead
+of private inheritance when no explicit protection keyword is present.</source>
+        <translation>sip(http://www.riverbankcomputing.co.uk/software/sip/intro) のソースコードしかない場合は SIP_SUPPORT に YES を与えるとよいでしょう。
+C++ に似た解析処理を行いますが、省略時の継承はすべて非公開ではなく公開の扱いになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2508"/>
+        <source>For Microsoft&apos;s IDL there are propget and propput attributes to indicate
+getter and setter methods for a property. Setting this option to YES will make
+doxygen to replace the get and set methods by a property in the documentation.
+This will only work if the methods are indeed getting or setting a simple
+type. If this is not the case, or you want to show the methods anyway, you
+should set this option to NO.</source>
+        <translation>マイクロソフトの IDL には propget と propput という属性があります。これはある特性に対する取得器(getter)および設定器(setter)です。
+IDL_PROPERTY_SUPPORT に YES を与えると文書中の特性の位置にその特性の get および set メソッドを配置します。
+この機能は単純型の設定器・取得器に対してのみ有効です。もともとそのような構造になっていない場合や当該メソッドの移動を希望しない場合は NO を与えてください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2516"/>
+        <source>If member grouping is used in the documentation and the DISTRIBUTE_GROUP_DOC
+tag is set to YES, then doxygen will reuse the documentation of the first
+member in the group (if any) for the other members of the group. By default
+all members of a group must be documented explicitly.</source>
+        <translation>メンバの組み分けを行い、かつ DISTRIBUTE_GROUP_DOC が YES の場合は同じ組み分けの最初のメンバに対する文章を再利用します。省略時・初期設定ではグループ内の全メンバに文章が与えられていなくてはなりません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2522"/>
+        <source>Set the SUBGROUPING tag to YES to allow class member groups of the same type
+(for instance a group of public functions) to be put as a subgroup of that
+type (e.g. under the Public Functions section). Set it to NO to prevent
+subgrouping. Alternatively, this can be done per class using the
+\nosubgrouping command.</source>
+        <translation>SUBGROUPING に YES を与えるとクラスメンバを同じ種類(たとえば公開関数かどうか)で組み分けます。 \nosubgrouping コマンドを使うとこの機能を無視できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2529"/>
+        <source>When the INLINE_GROUPED_CLASSES tag is set to YES, classes, structs and unions
+are shown inside the group in which they are included (e.g. using \ingroup)
+instead of on a separate page (for HTML and Man pages) or section (for LaTeX
+and RTF).
+
+Note that this feature does not work in combination with
+SEPARATE_MEMBER_PAGES.</source>
+        <translation>INLINE_GROUPED_CLASSES に YES を与えるとクラス・構造体・共用体の情報はそれを含むグループの中へ出慮されます。 \ingroup の指定によります。 NO のときは独立したページ(HTML や Man の場合)や独立した節(LaTeX や RTF の場合)に出力されます。
+
+注意: SEPARATE_MEMBER_PAGES と同時に使うことはできません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2538"/>
+        <source>When the INLINE_SIMPLE_STRUCTS tag is set to YES, structs, classes, and unions
+with only public data fields or simple typedef fields will be shown inline in
+the documentation of the scope in which they are defined (i.e. file,
+namespace, or group documentation), provided this scope is documented. If set
+to NO, structs, classes, and unions are shown on a separate page (for HTML and
+Man pages) or section (for LaTeX and RTF).</source>
+        <translation>INLINE_SIMPLE_STRUCTS に YES を与えると、公開データメンバか単純な typedef フィールドしかない構造体・クラス・共用体には独立したページが与えられなくなります。
+該当する構造体などはそれが定義された名前空間やグループの文書にまとめて出力されます。
+NO の場合はこれらの構造体などに対しても独立したページ(HTML や Man)または節(LaTeX や RTF)が作られます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2546"/>
+        <source>When TYPEDEF_HIDES_STRUCT tag is enabled, a typedef of a struct, union, or
+enum is documented as struct, union, or enum with the name of the typedef. So
+typedef struct TypeS {} TypeT, will appear in the documentation as a struct
+with name TypeT. When disabled the typedef will appear as a member of a file,
+namespace, or class. And the struct will be named TypeS. This can typically be
+useful for C code in case the coding convention dictates that all compound
+types are typedef&apos;ed and only the typedef is referenced, never the tag name.</source>
+        <translation>TYPEDEF_HIDES_STRUCT に YES を与えると、構造体・共用体・列挙値の typedef はその名前を持つ構造体や列挙として処理します。
+例えば &apos;typedef struct TypeS { } TypeT&apos; は TypeT という名前の構造体として出力します。NO の場合 typedef はファイル・名前空間・クラスのメンバとして扱われ、先の例では TypeS 扱いで出力します。
+
+この機能は C 言語におけるコード規約がすべての複合型を typedef で宣言することを要求しており、かつタグ名でなく typedef 名で参照されている状態で意味を持ちます。
+ </translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2555"/>
+        <source>The size of the symbol lookup cache can be set using LOOKUP_CACHE_SIZE. This
+cache is used to resolve symbols given their name and scope. Since this can be
+an expensive process and often the same symbol appears multiple times in the
+code, doxygen keeps a cache of pre-resolved symbols. If the cache is too small
+doxygen will become slower. If the cache is too large, memory is wasted. The
+cache size is given by this formula: 2^(16+LOOKUP_CACHE_SIZE). The valid range
+is 0..9, the default is 0, corresponding to a cache size of 2^16=65536
+symbols. At the end of a run doxygen will report the cache usage and suggest
+the optimal cache size from a speed point of view.</source>
+        <translation>LOOKUP_CACHE_SIZE には項目名検索キャッシュの大きさを指定できます。このキャッシュは項目名自身とスコープの解決に用いられます。
+この機能は負荷が高い処理になる可能性があり、同じ項目名が何度もでてくるコードではしばしば高負荷となります。doxygen は解決済みの項目名をキャッシュに保持しています。キャッシュが十分に大きくないと doxygen の動作速度が低下します。大きすぎる場合はメモリの無駄使いとなります。キャッシュの実際の大きさは 2の(16+指定値)乗です。
+
+有効値は 0 - 9 で、省略値・初期値は 0 で、2の16乗=65536の大きさを表します。doxygen は実行完了時にキャッシュの実使用量と速度面からの最適値を報告します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2566"/>
+        <source>If the EXTRACT_ALL tag is set to YES doxygen will assume all entities in
+documentation are documented, even if no documentation was available. Private
+class members and static file members will be hidden unless the
+EXTRACT_PRIVATE respectively EXTRACT_STATIC tags are set to YES.
+Note: This will also disable the warnings about undocumented members that are
+normally produced when WARNINGS is set to YES.</source>
+        <translation>EXTRACT_ALL に YES を与えると、文章の付きうる全項目が(実際に文章が用意されていなくても)出力されるようになります。非公開メンバや静的ファイルメンバはそれぞれ EXTRACT_PRIVATE および  EXTRACT_STATIC が YES の場合のみ出力されます。
+
+注意:EXTRACT_ALL が YES の場合、WARNINGS が YES であっても文章がまだないことに関する警告も抑制されます。 </translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2574"/>
+        <source>If the EXTRACT_PRIVATE tag is set to YES all private members of a class will
+be included in the documentation.</source>
+        <translation>EXTRACT_PRIVATE に YES を与えると各クラスの全非公開メンバが出力されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2578"/>
+        <source>If the EXTRACT_PACKAGE tag is set to YES all members with package or internal
+scope will be included in the documentation.</source>
+        <translation>EXTRACT_PACKAGE に YES を与えると package や内部スコープに含まれるメンバもすべて出力されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2582"/>
+        <source>If the EXTRACT_STATIC tag is set to YES all static members of a file will be
+included in the documentation.</source>
+        <translation>EXTRACT_STATIC に YES を与えるとファイルの静的メンバも出力に含まれるようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2586"/>
+        <source>If the EXTRACT_LOCAL_CLASSES tag is set to YES classes (and structs) defined
+locally in source files will be included in the documentation. If set to NO
+only classes defined in header files are included. Does not have any effect
+for Java sources.</source>
+        <translation>EXTRACT_LOCAL_CLASSES に YES を与えると特定ソースコード内でのみ有効な（いわゆるローカルの）クラスや構造体も出力されるようになります。 NO の場合はヘッダファイルにあるクラス等のみが出力の対象となります。Java のソースコードに対しては影響を持ちません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2592"/>
+        <source>This flag is only useful for Objective-C code. When set to YES local methods,
+which are defined in the implementation section but not in the interface are
+included in the documentation. If set to NO only methods in the interface are
+included.</source>
+        <translation>EXTRACT_LOCAL_METHODS は Objective-C でのみ意味をもちます。インターフェースに記述がなく、実装セクションにのみ定義されたローカルメソッドは YES を与えた場合のみ出力の対象となります。 NO の場合はインターフェースに含まれるメソッドのみ出力します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2598"/>
+        <source>If this flag is set to YES, the members of anonymous namespaces will be
+extracted and appear in the documentation as a namespace called
+&apos;anonymous_namespace{file}&apos;, where file will be replaced with the base name of
+the file that contains the anonymous namespace. By default anonymous namespace
+are hidden.</source>
+        <translation>EXTRACT_ANON_NSPACES に YES を与えると匿名名前空間も出力の対象となります。この際、名前空間は &apos;anonymous_namespace{その匿名名前空間があるファイルの基底名}&apos; であるものとして出力します。省略時・初期設定では匿名名前空間の内容は隠されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2605"/>
+        <source>If the HIDE_UNDOC_MEMBERS tag is set to YES, doxygen will hide all
+undocumented members inside documented classes or files. If set to NO these
+members will be included in the various overviews, but no documentation
+section is generated. This option has no effect if EXTRACT_ALL is enabled.</source>
+        <translation>HIDE_UNDOC_MEMBERS に YES を与えるとファイルやクラス自身に文章があっても、文章のつけられていないメンバはまったく出力されなくなります。 NO の場合はこれらのメンバもある程度の概要は出力されます（当然詳解部などは付けられません）。
+ここでの指定は EXTRACT_ALL が YES の場合は意味を持ちません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2611"/>
+        <source>If the HIDE_UNDOC_CLASSES tag is set to YES, doxygen will hide all
+undocumented classes that are normally visible in the class hierarchy. If set
+to NO these classes will be included in the various overviews. This option has
+no effect if EXTRACT_ALL is enabled.</source>
+        <translation>HIDE_UNDOC_CLASSES に YES を与えると、階層においては通常可視のクラスでも、文章の付いていないものは出力されなくなります。 NO の場合はある程度の概要が出力されます。
+ここでの指定は EXTRACT_ALL が YES の場合は意味を持ちません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2622"/>
+        <source>If the HIDE_IN_BODY_DOCS tag is set to YES, doxygen will hide any
+documentation blocks found inside the body of a function. If set to NO these
+blocks will be appended to the function&apos;s detailed documentation block.</source>
+        <translation>HIDE_IN_BODY_DOCS に YES を与えると、関数本体内にある文書ブロックは隠されるようになります。 NO の場合はこれらの内容も各関数の詳解部に追加されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2627"/>
+        <source>The INTERNAL_DOCS tag determines if documentation that is typed after a
+\internal command is included. If the tag is set to NO then the documentation
+will be excluded. Set it to YES to include the internal documentation.</source>
+        <translation>INTERNAL_DOCS に YES を与えると \internal コマンド以降に入力された文章を出力に含むようになります。内部の文章をも出力させたい場合に YES にしてください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2632"/>
+        <source>If the CASE_SENSE_NAMES tag is set to NO then doxygen will only generate file
+names in lower-case letters. If set to YES upper-case letters are also
+allowed. This is useful if you have classes or files whose names only differ
+in case and if your file system supports case sensitive file names. Windows
+and Mac users are advised to set this option to NO.</source>
+        <translation>CASE_SENSE_NAMES に YES を与えるとファイル名の大文字小文字を区別できるものとして出力を行います。NO の場合は小文字のみ使います。大文字小文字のみの違いしかないクラスやファイルなどがあり、さらにファイルシステムもそれらを区別できる場合に YES を与えてください。
+Windows と Mac では NO にしておくことをお勧めします。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2639"/>
+        <source>If the HIDE_SCOPE_NAMES tag is set to NO then doxygen will show members with
+their full class and namespace scopes in the documentation. If set to YES the
+scope will be hidden.</source>
+        <translation>HIDE_SCOPE_NAMES に YES を与えると出力分枝には完全なクラス名や名前空間名を隠すようになります。
+NO の場合はこれらを完全な形で出力します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2644"/>
+        <source>If the SHOW_INCLUDE_FILES tag is set to YES then doxygen will put a list of
+the files that are included by a file in the documentation of that file.</source>
+        <translation>SHOW_INCLUDE_FILES に YES を与えるとあるファイルの文書に、それから include しているファイルの一覧を含めて出力するようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2648"/>
+        <source>If the SHOW_GROUPED_MEMB_INC tag is set to YES then Doxygen will add for each
+grouped member an include statement to the documentation, telling the reader
+which file to include in order to use the member.</source>
+        <translation>SHOW_GROUPED_MEMB_INC に YES を与えると、グループ化されているメンバごとに必要なファイルを示す include 文を付加して出力するようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2653"/>
+        <source>If the FORCE_LOCAL_INCLUDES tag is set to YES then doxygen will list include
+files with double quotes in the documentation rather than with sharp brackets.</source>
+        <translation>FORCE_LOCAL_INCLUDES に YES を与えるとファイルを include するときに &lt; &gt; ではなく &quot; &quot; を使ったものとして処理します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2657"/>
+        <source>If the INLINE_INFO tag is set to YES then a tag [inline] is inserted in the
+documentation for inline members.</source>
+        <translation>INLINE_INFO に YES を与えると、インラインメンバの文書に [inline] の附箋を付けるようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2661"/>
+        <source>If the SORT_MEMBER_DOCS tag is set to YES then doxygen will sort the
+(detailed) documentation of file and class members alphabetically by member
+name. If set to NO the members will appear in declaration order.</source>
+        <translation>SORT_MEMBER_DOCS に YES を与えると、詳解文をメンバ名順に並べ替えます。
+NO の場合はソースコードで宣言した順に出力されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2672"/>
+        <source>If the SORT_MEMBERS_CTORS_1ST tag is set to YES then doxygen will sort the
+(brief and detailed) documentation of class members so that constructors and
+destructors are listed first. If set to NO the constructors will appear in the
+respective orders defined by SORT_BRIEF_DOCS and SORT_MEMBER_DOCS.
+Note: If SORT_BRIEF_DOCS is set to NO this option is ignored for sorting brief
+member documentation.
+Note: If SORT_MEMBER_DOCS is set to NO this option is ignored for sorting
+detailed member documentation.</source>
+        <translation>SORT_MEMBERS_CTORS_1ST に YES を与えると、概要・詳解のそれぞれで構築子と解体子を先頭に出力するようになります。
+
+注意: SORT_BRIEF_DOCS や SORT_MEMBER_DOCS に NO が与えられている場合、それぞれにおいて SORT_MEMBERS_CTORS_1ST の指定は無視されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2682"/>
+        <source>If the SORT_GROUP_NAMES tag is set to YES then doxygen will sort the hierarchy
+of group names into alphabetical order. If set to NO the group names will
+appear in their defined order.</source>
+        <translation>SORT_GROUP_NAMES に YES を与えると、グループ階層がグループ名順となります。 NO の場合は定義された順に出力されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2687"/>
+        <source>If the SORT_BY_SCOPE_NAME tag is set to YES, the class list will be sorted by
+fully-qualified names, including namespaces. If set to NO, the class list will
+be sorted only by class name, not including the namespace part.
+Note: This option is not very useful if HIDE_SCOPE_NAMES is set to YES.
+Note: This option applies only to the class list, not to the alphabetical
+list.</source>
+        <translation>SORT_BY_SCOPE_NAME に YES を与えると、クラス一覧は名前空間を含んだ完全名をもとに並べ替えて出力されるようになります。 NO の場合はクラス名だけを元とし、名前空間は並べ替えに寄与しません。
+注意: HIDE_SCOPE_NAMES が YES の場合はあまり意味がありません。
+注意: この指定はクラスの一覧のみに適用されます。文字符号順の一覧には適用されません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2695"/>
+        <source>If the STRICT_PROTO_MATCHING option is enabled and doxygen fails to do proper
+type resolution of all parameters of a function it will reject a match between
+the prototype and the implementation of a member function even if there is
+only one candidate or it is obvious which candidate to choose by doing a
+simple string match. By disabling STRICT_PROTO_MATCHING doxygen will still
+accept a match between prototype and implementation in such cases.</source>
+        <translation>STRICT_PROTO_MATCHING を有効にしておくと、引数解決に適当なものがないときに、関数の原型と実装の関連付けを放棄します。
+これは候補が一つしかなかったり、単純な文字列比較で明らかだったりした場合にも適用されます。
+無効にしておいた場合は宣言形と定義形に上述のようなずれがあってもそれを許容します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2708"/>
+        <source>The GENERATE_TESTLIST tag can be used to enable ( YES) or disable ( NO) the
+test list. This list is created by putting \test commands in the
+documentation.</source>
+        <translation>GENERATE_TESTLIST には \test コマンドによる試行一覧を出力するかどうかを指定できます。 YES で出力します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2713"/>
+        <source>The GENERATE_BUGLIST tag can be used to enable ( YES) or disable ( NO) the bug
+list. This list is created by putting \bug commands in the documentation.</source>
+        <translation>GENERATE_BUGLIST には \bug コマンドによるバグ一覧を出力するかどうかを指定できます。 YES で出力します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2717"/>
+        <source>The GENERATE_DEPRECATEDLIST tag can be used to enable ( YES) or disable ( NO)
+the deprecated list. This list is created by putting \deprecated commands in
+the documentation.</source>
+        <translation>GENERATE_DEPRECATEDLIST には \deprecated コマンドによる非推奨一覧を出力するかどうかを指定できます。 YES で出力します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2722"/>
+        <source>The ENABLED_SECTIONS tag can be used to enable conditional documentation
+sections, marked by \if &lt;section_label&gt; ... \endif and \cond &lt;section_label&gt;
+... \endcond blocks.</source>
+        <translation>ENABLED_SECTIONS には \if &lt;節附箋&gt; … \endif や \cond &lt;節附箋&gt; … \endcond の形で示された区間のうち有効にする附箋を指定できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2727"/>
+        <source>The MAX_INITIALIZER_LINES tag determines the maximum number of lines that the
+initial value of a variable or macro / define can have for it to appear in the
+documentation. If the initializer consists of more lines than specified here
+it will be hidden. Use a value of 0 to hide initializers completely. The
+appearance of the value of individual variables and macros / defines can be
+controlled using \showinitializer or \hideinitializer command in the
+documentation regardless of this setting.</source>
+        <translation>MAX_INITIALIZER_LINES には変数の初期値・マクロ・define の実装文が何行以内であれば出力解説文にも複写されるかを指定できます。
+指定値よりも長い行数で定義されている各定義内容は直接出力されなくなります。 0 を与えた場合、初期化子はすべて出力から除外するようになります。
+ただし \showintializer や \hideinitializer コマンドで個々の変数やマクロに対する処理を変更できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2741"/>
+        <source>Set the SHOW_FILES tag to NO to disable the generation of the Files page. This
+will remove the Files entry from the Quick Index and from the Folder Tree View
+(if specified).</source>
+        <translation>SHOW_FILES に YES を与えるとファイルページを生成します。 NO の場合は急行索引やフォルダのツリービューにファイル項目を作りません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2746"/>
+        <source>Set the SHOW_NAMESPACES tag to NO to disable the generation of the Namespaces
+page. This will remove the Namespaces entry from the Quick Index and from the
+Folder Tree View (if specified).</source>
+        <translation>SHOW_NAMESPACES に YES を与えると名前空間ページを生成します。 NO の場合は急行索引やフォルダツリービューに名前空間の項目を作りません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2751"/>
+        <source>The FILE_VERSION_FILTER tag can be used to specify a program or script that
+doxygen should invoke to get the current version for each file (typically from
+the version control system). Doxygen will invoke the program by executing (via
+popen()) the command command input-file, where command is the value of the
+FILE_VERSION_FILTER tag, and input-file is the name of an input file provided
+by doxygen. Whatever the program writes to standard output is used as the file
+version. For an example see the documentation.</source>
+        <translation>FILE_VERSION_FILTER にはプログラムやスクリプトを指定できます。doxygen は指定されたプログラムなどから各入力ファイルの「現在の版」を取得します。版数制御系(version control system)から取得するという使い方ができます。 doxygen は popen() を用いて &apos;コマンド 入力ファイル&apos; を実行します。 &apos;コマンド&apos; は FILE_VERSION_FILTER に与えられた文字列、 &apos;入力ファイル&apos; は doxygen から入力ファイルごとに変化させるファイル名です。実行したプログラムが標準出力に書き出したものを版を表す文字列として受け付けます。実例としては説明書そのものを参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2760"/>
+        <source>The LAYOUT_FILE tag can be used to specify a layout file which will be parsed
+by doxygen. The layout file controls the global structure of the generated
+output files in an output format independent way. To create the layout file
+that represents doxygen&apos;s defaults, run doxygen with the -l option. You can
+optionally specify a file name after the option, if omitted DoxygenLayout.xml
+will be used as the name of the layout file.
+
+Note that if you run doxygen from a directory containing a file called
+DoxygenLayout.xml, doxygen will parse it automatically even if the LAYOUT_FILE
+tag is left empty.</source>
+        <translation>LAYOUT_FILE には doxygen が解析すべき配置ファイルを指定できます。配置ファイルは出力の全体構造を出力様式に依存しない形で制御します。 doxygen の初期設定を表す配置ファイルの生成には -l オプションを用いて doxygen を実行してください。 -lオプションはファイル名を指定することもしないこともでき、後者の場合は DoxygenLayout.xml が指定されたものとして動作します。
+
+注意: doxygen の起動ディレクトリに DoxygenLayout.xml というファイルがあれば LAYOUT_FILE に指定がなくてもそれを読み取りに行きます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2772"/>
+        <source>The CITE_BIB_FILES tag can be used to specify one or more bib files containing
+the reference definitions. This must be a list of .bib files. The .bib
+extension is automatically appended if omitted. This requires the bibtex tool
+to be installed. See also http://en.wikipedia.org/wiki/BibTeX for more info.
+For LaTeX the style of the bibliography can be controlled using
+LATEX_BIB_STYLE. To use this feature you need bibtex and perl available in the
+search path. Do not use file names with spaces, bibtex cannot handle them. See
+also \cite for info how to create references.</source>
+        <translation>CITE_BIB_FILES には、参照の定義を含んだ任意数の bib ファイルを指定できます。bib ファイルの一覧になるようにご指定ください。
+拡張子が省略された場合は自動的に bib が割り当てられます。
+bibtex ツールの設置が必要です。詳細は http://ja.wikipedia.org/wiki/BibTeX をご覧ください。
+LaTeX における参考文献の書式は LATEX_BIB_STYLE で制御できます。この機能は bibtex と perl に実行パスを通しておかなくてはなりません。bibtex 側の理由で空白文字をファイル名に使うことはできません。参考文献の生成に関しては \cite も参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2782"/>
+        <source>The QUIET tag can be used to turn on/off the messages that are generated to
+standard output by doxygen. If QUIET is set to YES this implies that the
+messages are off.</source>
+        <translation>QUIET に YES を与えると doxygen から標準出力へのメッセージを抑制できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2787"/>
+        <source>The WARNINGS tag can be used to turn on/off the warning messages that are
+generated to standard error ( stderr) by doxygen. If WARNINGS is set to YES
+this implies that the warnings are on.
+
+Tip: Turn warnings on while writing the documentation.</source>
+        <translation>WARNINGS に YES を与えると標準エラー出力(stderr)に警告文が出力されるようになります。
+
+Tip: 文書を書いている途中だけ YES にしておくのがお勧めです。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2794"/>
+        <source>If the WARN_IF_UNDOCUMENTED tag is set to YES, then doxygen will generate
+warnings for undocumented members. If EXTRACT_ALL is set to YES then this flag
+will automatically be disabled.</source>
+        <translation>WARN_IF_UNDOCUMENTED に YES を与えると文書が付けられていないメンバについて警告を行うようになります。
+EXTRACT_ALL が NO の場合のみ動作します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2799"/>
+        <source>If the WARN_IF_DOC_ERROR tag is set to YES, doxygen will generate warnings for
+potential errors in the documentation, such as not documenting some parameters
+in a documented function, or documenting parameters that don&apos;t exist or using
+markup commands wrongly.</source>
+        <translation>WARN_IF_DOC_ERROR に YES を与えると文書内の問題と思われる点について警告を行うようになります。
+例えば関数の引数について一部にしか説明がない場合や、マークアップコマンドの使い方が不正であったり存在しないコマンドであったりした場合に警告を出します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2805"/>
+        <source>This WARN_NO_PARAMDOC option can be enabled to get warnings for functions that
+are documented, but have no documentation for their parameters or return
+value. If set to NO doxygen will only warn about wrong or incomplete parameter
+documentation, but not about the absence of documentation.</source>
+        <translation>WARN_NO_PARAMDOC に YES を与えると、文書が付けられている関数のうち、引数や戻り値についての文書がないものについて警告を行うようになります。
+NO の場合、誤っているか不完全な文書については警告しますが文書そのものを欠いているときは警告対象になりません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2811"/>
+        <source>The WARN_FORMAT tag determines the format of the warning messages that doxygen
+can produce. The string should contain the $file, $line, and $text tags, which
+will be replaced by the file and line number from which the warning originated
+and the warning text. Optionally the format may contain $version, which will
+be replaced by the version of the file (if it could be obtained via
+FILE_VERSION_FILTER).</source>
+        <oldsource>The WARN_FORMAT tag determines the format of the warning messages that doxygen
+can produce. The string should contain the $file, $line, and $text tags, which
+will be replaced by the file and line number from which the warning originated
+and the warning text. Optionally the format may contain $version, which will
+be replaced by the version of the file (if it could be obtained via
+FILE_VERSION_FILTER)</oldsource>
+        <translation>WARN_FORMAT には doxygen が生成する警告の書式を指定できます。
+書式には $file, $line, $text を含めるべきです。順にファイル名・原因となった行の番号・警告文に置き換えられます。
+このほか $version も利用できます。これは FILE_VERSION_FILTER の機能により得られるファイルの版数に置き換えられます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2819"/>
+        <source>The WARN_LOGFILE tag can be used to specify a file to which warning and error
+messages should be written. If left blank the output is written to standard
+error (stderr).</source>
+        <translation>WARN_LOGFILE には警告やエラーメッセージの書き込み先ファイルを指定できます。
+指定がなければ標準エラー出力(stderr)に出力されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2824"/>
+        <source>The INPUT tag is used to specify the files and/or directories that contain
+documented source files. You may enter file names like myfile.cpp or
+directories like /usr/src/myproject. Separate the files or directories with
+spaces.
+Note: If this tag is empty the current directory is searched.</source>
+        <translation>INPUT には文書のついたソースコードがあるファイルまたはディレクトリをご指定ください。
+myfile.cpp のようなファイル名と /usr/src/myproject のようなディレクトリ名を指定できます。それぞれの指定先は空白文字で区切ってください。
+指定が全くない場合は動作時のディレクトリを代わりに適用します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2831"/>
+        <source>This tag can be used to specify the character encoding of the source files
+that doxygen parses. Internally doxygen uses the UTF-8 encoding. Doxygen uses
+libiconv (or the iconv built into libc) for the transcoding. See the libiconv
+documentation (see: http://www.gnu.org/software/libiconv) for the list of
+possible encodings.</source>
+        <translation>INPUT_ENCODING にはソースファイルの文字符号化法をご指定ください。doxygen は libiconv もしくは libc に含まれている iconv により指定の内容から UTF-8 への変換を行った上で解析を行います。
+利用できる符号化法については http://www.gnu.org/software/libiconv を参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2844"/>
+        <source>The RECURSIVE tag can be used to specify whether or not subdirectories should
+be searched for input files as well.</source>
+        <translation>入れ子となっているフォルダも入力ファイルの検索先に含める場合は RECURSIVE に YES を与えてください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2848"/>
+        <source>The EXCLUDE tag can be used to specify files and/or directories that should be
+excluded from the INPUT source files. This way you can easily exclude a
+subdirectory from a directory tree whose root is specified with the INPUT tag.
+
+Note that relative paths are relative to the directory from which doxygen is
+run.</source>
+        <translation>EXCLUDE には INPUT に指定したものから処理対象を除外するファイルやディレクトリを指定できます。
+これにより INPUT で全体の根ディレクトリを指定し、不要な子ディレクトリだけを除外できます。
+
+相対パスの解析は doxygen の実行ディレクトリを基準に行う点にご注意ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2856"/>
+        <source>The EXCLUDE_SYMLINKS tag can be used to select whether or not files or
+directories that are symbolic links (a Unix file system feature) are excluded
+from the input.</source>
+        <translation>EXCLUDE_SYMLINKS にはどのファイルやディレクトリがシンボリックリンクであり、入力から除外すべきなのかをご指定ください。 </translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2861"/>
+        <source>If the value of the INPUT tag contains directories, you can use the
+EXCLUDE_PATTERNS tag to specify one or more wildcard patterns to exclude
+certain files from those directories.
+
+Note that the wildcards are matched against the file with absolute path, so to
+exclude all test directories for example use the pattern */test/*.</source>
+        <oldsource>If the value of the INPUT tag contains directories, you can use the
+EXCLUDE_PATTERNS tag to specify one or more wildcard patterns to exclude
+certain files from those directories.
+
+Note that the wildcards are matched against the file with absolute path, so to
+exclude all test directories for example use the pattern */test/*</oldsource>
+        <translation>INPUT へ指定したディレクトリに対して除外対象を EXCLUDE_PATTERNS に与えることができます。
+除外対象はワイルドカードを用いた複数の書式を用いることができます。
+
+注意: ワイルドカードはファイルの絶対パスに対して合致検査を行います。従ってたとえば &apos;test&apos; ディレクトリのすべてを除外するときは &apos;*/test/*&apos; と指示する必要があります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2876"/>
+        <source>The EXAMPLE_PATH tag can be used to specify one or more files or directories
+that contain example code fragments that are included (see the \include
+command).</source>
+        <translation>EXAMPLE_PATH には例題コード断片がある任意数のファイルやディレクトリを指定できます。 \include コマンドの説明を参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2881"/>
+        <source>If the value of the EXAMPLE_PATH tag contains directories, you can use the
+EXAMPLE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp and
+*.h) to filter out the source-files in the directories. If left blank all
+files are included.</source>
+        <translation>EXAMPLE_PATH にディレクトリを指定した場合、さらに EXAMPLE_PATTERNS へ対象となるソースファイルを指定できます。指定にはワイルドカード * を用いて *.cpp あるいは *.h などの形を使うことができます。指定が全くない場合は全てのファイルが対象となります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2887"/>
+        <source>If the EXAMPLE_RECURSIVE tag is set to YES then subdirectories will be
+searched for input files to be used with the \include or \dontinclude commands
+irrespective of the value of the RECURSIVE tag.</source>
+        <translation>EXAMPLE_RECURSIVE に YES を与えると \include コマンドや \dontinclude コマンドで使われる入力ファイルの検索に子ディレクトリ内も再帰検索するようになります。この動作は RECURSIVE の指定とは独立しています。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2892"/>
+        <source>The IMAGE_PATH tag can be used to specify one or more files or directories
+that contain images that are to be included in the documentation (see the
+\image command).</source>
+        <translation>出力文書に使われる画像は IMAGE_PATH で元の所在を指示できます。任意数のファイルやディレクトリを与えることができます。 \image コマンドの説明も参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2897"/>
+        <source>The INPUT_FILTER tag can be used to specify a program that doxygen should
+invoke to filter for each input file. Doxygen will invoke the filter program
+by executing (via popen()) the command:
+
+&lt;filter&gt; &lt;input-file&gt;
+
+where &lt;filter&gt; is the value of the INPUT_FILTER tag, and &lt;input-file&gt; is the
+name of an input file. Doxygen will then use the output that the filter
+program writes to standard output. If FILTER_PATTERNS is specified, this tag
+will be ignored.
+
+Note that the filter must not add or remove lines; it is applied before the
+code is scanned, but not when the output code is generated. If lines are added
+or removed, the anchors will not be placed correctly.</source>
+        <translation>INPUT_FILTER には入力ファイルごとに doxygen が実行すべきプログラムを指定できます。 doxygen は popen() を用いて次のコマンドを実行します。
+&lt;フィルタ&gt; &lt;入力ファイル&gt;
+上記の &lt;フィルタ&gt; には INPUT_FILTER への指定値が、 &lt;入力ファイル&gt; にはそれぞれの入力ファイル名が代入されます。
+doxygen が自ら解析する対象は、フィルタプログラムからの標準出力になります。
+なお、適用するフィルタは FILTER_PATTERNS の指定が優先されます。
+
+フィルタプログラムに行を追加させたり削除させたりしないでください。行(番号)はフィルタに渡す前に定められ、その時の行番号をもとに出力を生成します。従って行の加除があると出力のリンクアンカーが正しい位置に来なくなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2913"/>
+        <source>The FILTER_PATTERNS tag can be used to specify filters on a per file pattern
+basis. Doxygen will compare the file name with each pattern and apply the
+filter if there is a match. The filters are a list of the form: pattern=filter
+(like *.cpp=my_cpp_filter). See INPUT_FILTER for further information on how
+filters are used. If the FILTER_PATTERNS tag is empty or if none of the
+patterns match the file name, INPUT_FILTER is applied.</source>
+        <translation>FILTER_PATTERNS にはファイルパターンごとに異なるフィルタを適用したい場合に用いることができます。
+doxygen は各パターンを各入力ファイル名と比較し、条件に合ったフィルタを実行します。
+フィルタは &apos;パターン=フィルタ&apos; 、たとえば *.cpp=my_cpp_filter という様式でご指定ください。
+フィルタの動作については INPUT_FILTER の説明をご覧ください。
+FILTER_PATTERNS が空であったり、ある入力ファイルの名前に一致するパターンがなかったりした場合はそのファイルについて INPUT_FILTER が適用されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2921"/>
+        <source>If the FILTER_SOURCE_FILES tag is set to YES, the input filter (if set using
+INPUT_FILTER ) will also be used to filter the input files that are used for
+producing the source files to browse (i.e. when SOURCE_BROWSER is set to YES).</source>
+        <translation>FILTER_SOURCE_FILES に YES を与えると INPUT_FILTER に指定されたフィルタの結果をブラウザ用の出力にも適用します。
+SOURCE_BROWSER などが YES になっていないと意味を持ちません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2926"/>
+        <source>The FILTER_SOURCE_PATTERNS tag can be used to specify source filters per file
+pattern. A pattern will override the setting for FILTER_PATTERN (if any) and
+it is also possible to disable source filtering for a specific pattern using
+*.ext= (so without naming a filter).</source>
+        <translation>FILTER_SOURCE_PATTERNS にはファイルパターンごとのソースフィルタを指定できます。
+この内容は FILTER_PATTERN を上書きします。
+また、 &apos;*.拡張子=&apos; という書式により特定のパターンに対するフィルタ適用を回避させることもできます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2932"/>
+        <source>If the USE_MDFILE_AS_MAINPAGE tag refers to the name of a markdown file that
+is part of the input, its contents will be placed on the main page
+(index.html). This can be useful if you have a project on for instance GitHub
+and want to reuse the introduction page also for the doxygen output.</source>
+        <translation>USE_MDFILE_AS_MAINPAGE により、入力にあるうちの Markdown ファイルを参照させ、その内容で index.html を置き換えさせることができます。
+GitHub にあるプロジェクトから案内ページを再利用して出力に使いたい場合に便利です。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2938"/>
+        <source>If the SOURCE_BROWSER tag is set to YES then a list of source files will be
+generated. Documented entities will be cross-referenced with these sources.
+
+Note: To get rid of all source code in the generated output, make sure that
+also VERBATIM_HEADERS is set to NO.</source>
+        <translation>SOURCE_BROWSER に YES を与えるとソースファイルの一覧を生成するようになります。
+文書が付けられた項目とは相互参照できるようになっています。
+
+注意: 出力にすべてのソースコードを含めたいときは VERBATIM_HEADERS に NO を与えてください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2945"/>
+        <source>Setting the INLINE_SOURCES tag to YES will include the body of functions,
+classes and enums directly into the documentation.</source>
+        <translation>INLINE_SOURCES に YES を与えると関数・クラス・列挙の本体部分を各文書の中に含めるようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2949"/>
+        <source>Setting the STRIP_CODE_COMMENTS tag to YES will instruct doxygen to hide any
+special comment blocks from generated source code fragments. Normal C, C++ and
+Fortran comments will always remain visible.</source>
+        <translation>STRIP_CODE_COMMENTS に YES を与えると出力されたソースコード部から特殊処理コマンドのブロックを隠すようになります。
+ C言語,、C++、Fortranの注釈は常に可視状態にされます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2954"/>
+        <source>If the REFERENCED_BY_RELATION tag is set to YES then for each documented
+function all documented functions referencing it will be listed.</source>
+        <translation>REFERENCED_BY_RELATION に YES を与えると、文書が付いている関数ごとに、それを参照している関数(のうち文書が付いているもの)の一覧が出力されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2958"/>
+        <source>If the REFERENCES_RELATION tag is set to YES then for each documented function
+all documented entities called/used by that function will be listed.</source>
+        <translation>REFERENCES_RELATION に YES を与えると文書の付いている関数ごとに、その関数が呼び出している関数(のうち文書が付いているもの)の一覧が出力されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2962"/>
+        <source>If the REFERENCES_LINK_SOURCE tag is set to YES and SOURCE_BROWSER tag is set
+to YES, then the hyperlinks from functions in REFERENCES_RELATION and
+REFERENCED_BY_RELATION lists will link to the source code. Otherwise they will
+link to the documentation.</source>
+        <translation>REFERENCES_LINK_SOURCE と SOURCE_BROWSER の両方に YES を与えると、 REFERENCES_RELATION および REFERENCED_BY_RELATION の指定により生成されるリンク先はソースコードになります。どちらかが NO の場合は関数に付けられた文書がリンク先になります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2968"/>
+        <source>If SOURCE_TOOLTIPS is enabled (the default) then hovering a hyperlink in the
+source code will show a tooltip with additional information such as prototype,
+brief description and links to the definition and documentation. Since this
+will make the HTML file larger and loading of large files a bit slower, you
+can opt to disable this feature.</source>
+        <translation>SOURCE_TOOLTIPS に YES を与えるとソースコード内のハイパーリンクにポインタを載せたときにリンク先の譲歩が表示されるように出力します。宣言や概要文のほか、定義と詳解へのリンクが表示されます。生成する HTML ファイルが大きくなり、またブラウザへの読み込み時間もいくらか長くなります。出力を軽量化したい場合は NO をご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2975"/>
+        <source>If the USE_HTAGS tag is set to YES then the references to source code will
+point to the HTML generated by the htags(1) tool instead of doxygen built-in
+source browser. The htags tool is part of GNU&apos;s global source tagging system
+(see http://www.gnu.org/software/global/global.html). You will need version
+4.8.6 or higher.
+
+To use it do the following:
+- Install the latest version of global
+- Enable SOURCE_BROWSER and USE_HTAGS in the config file
+- Make sure the INPUT points to the root of the source tree
+- Run doxygen as normal
+
+Doxygen will invoke htags (and that will in turn invoke gtags), so these
+tools must be available from the command line (i.e. in the search path).
+
+The result: instead of the source browser generated by doxygen, the links to
+source code will now point to the output of htags.</source>
+        <translation>USE_HTAGS に YES を与えるとソースコードへの参照先は htags(1) ツールが出力した HTML になります。 NO の場合は doxygen が再成形したソースコードです。 htag ツールは GNU の大域ソース標識札系です。 http://www.gnu.org/software/global/global.html を参照ください。 4.8.6 以上の版が必要です。
+
+この機能を使う手順は次の通りです:
+- &apos;global&apos; の最新版を設置してください。
+- SOURCE_BROWSER と USE_HTAGS の両方を有効にしてください。
+- INPUT がソースツリーの根を指していることをご確認ください。
+- 通常通り doxygen を実行してください。
+
+doxygen は htags を呼び出します。htags はさらに gtags を呼び出すでしょう。このためこれらのツールがコマンドラインからパスを通すなどして実行可能でなくてはなりません。以上の手続きで doxygen の自前生成ソースコードの代わりに htags が生成した HTML へのリンクが作られるようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2994"/>
+        <source>If the VERBATIM_HEADERS tag is set the YES then doxygen will generate a
+verbatim copy of the header file for each class for which an include is
+specified. Set to NO to disable this.
+See also: Section \class.</source>
+        <translation>VERBATIM_HEADERS に YES を与えると、クラスの出力ごとに各クラスが include により必要としていたヘッダファイルをそのまま複写するようになります。 \class 節を参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3000"/>
+        <source>If the CLANG_ASSISTED_PARSING tag is set to YES, then doxygen will use the
+clang parser (see: http://clang.llvm.org/) for more acurate parsing at the
+cost of reduced performance. This can be particularly helpful with template
+rich C++ code for which doxygen&apos;s built-in parser lacks the necessary type
+information.
+Note: The availability of this option depends on whether or not doxygen was
+compiled with the --with-libclang option.</source>
+        <translation>CLANG_ASSISTED_PARSING に YES を与えると clang の解析器を用いてより正確な処理と性能の改善を試みます。 clang については http://clang.llvm.org/ を参照ください。特にテンプレートをふんだんに使った C++ コードに効果があります(doxygen の解析器は必要な型情報の扱いがやや弱くなっています)。
+
+注意: doxygen 自身が --with-libclang オプションを付けてビルドされていないと有効になりません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3009"/>
+        <source>If clang assisted parsing is enabled you can provide the compiler with command
+line options that you would normally use when invoking the compiler. Note that
+the include paths will already be set by doxygen for the files and directories
+specified with INPUT and INCLUDE_PATH.</source>
+        <translation>CLANG_ASSISTED_PARSING に YES を指定する際のコンパイラに与えるオプションは CLANG_OPTIONS をご利用ください。なお、ファイルやディレクトリに対する include パスは INPUT と INCLUDE_PATH. の内容を元に呼び出し前に doxygen が設定します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3015"/>
+        <source>If the ALPHABETICAL_INDEX tag is set to YES, an alphabetical index of all
+compounds will be generated. Enable this if the project contains a lot of
+classes, structs, unions or interfaces.</source>
+        <translation>ALPHABETICAL_INDEX に YES を与えると全構成項目に対する文字順索引を出慮するようになります。クラス・構造体・共用体が多数にわたるプロジェクトに対して有効にするとよいでしょう。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3020"/>
+        <source>The COLS_IN_ALPHA_INDEX tag can be used to specify the number of columns in
+which the alphabetical index list will be split.</source>
+        <translation>文字順索引における表示の段数(柱の数)は COLS_IN_ALPHA_INDEX にご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3024"/>
+        <source>In case all classes in a project start with a common prefix, all classes will
+be put under the same header in the alphabetical index. The IGNORE_PREFIX tag
+can be used to specify a prefix (or a list of prefixes) that should be ignored
+while generating the index headers.</source>
+        <translation>プロジェクト内の全クラスが共通の前置字を持っていると、そのままでは文字順索引の見出しが機能しなくなってしまいます。IGNORE_PREFIX にその共通先頭字列を設定しておくと、索引に配置する際に指定部分が無視されます。共通前置字列は複数指定できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3033"/>
+        <source>The HTML_OUTPUT tag is used to specify where the HTML docs will be put. If a
+relative path is entered the value of OUTPUT_DIRECTORY will be put in front of
+it.</source>
+        <translation>HTML_OUTPUT には HTML 形式の出力先をご指定ください。
+相対パスを指定した場合は OUTPUT_DIRECTORY の内容を前置した状態で解析します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3038"/>
+        <source>The HTML_FILE_EXTENSION tag can be used to specify the file extension for each
+generated HTML page (for example: .htm, .php, .asp).</source>
+        <translation>HTML_FILE_EXTENSION には出力する HTML ファイルに与える拡張子を指定できます。 .htm, .php, .asp といったものが考えられます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3042"/>
+        <source>The HTML_HEADER tag can be used to specify a user-defined HTML header file for
+each generated HTML page. If the tag is left blank doxygen will generate a
+standard header.
+
+To get valid HTML the header file that includes any scripts and style sheets
+that doxygen needs, which is dependent on the configuration options used (e.g.
+the setting GENERATE_TREEVIEW). It is highly recommended to start with a
+default header using
+doxygen -w html new_header.html new_footer.html new_stylesheet.css
+YourConfigFile
+and then modify the file new_header.html. See also section &quot;Doxygen usage&quot;
+for information on how to generate the default header that doxygen normally
+uses.
+Note: The header is subject to change so you typically have to regenerate the
+default header when upgrading to a newer version of doxygen. For a description
+of the possible markers and block names see the documentation.</source>
+        <translation>HTML_HEADER にはユーザー定義の HTML 見出しファイルを指定できます。この内容は出力する各 HTML ファイルに利用されます。空白のままであった場合は内蔵の標準見出しを適用します。
+
+doxygen で必要となるスクリプトやスタイルシートを正しく含んだ見出し HTML ファイル、というのは他のオプションをどう使ったかに依存します(例えば GENERATE_TREEVIEW)。最初から作る場合は &apos;doxygen -w html new_header.html new_footer.html new_stylesheet.css doxygen用設定ファイル名&apos; というコマンドを実行し、得られた new_header.html などを修正するのが良いでしょう。doxygen が通所用いる標準の見出しファイルがどう生成されるかについては &quot;Doxygen usage&quot; を参照ください。
+
+注意: 見出しは今後変更されうるものなので、doxygen 本体の更新に合わせてここで指定したファイルも変更を要する可能性があります。変更の可能性があるマーカーやブロック名については説明書をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3060"/>
+        <source>The HTML_FOOTER tag can be used to specify a user-defined HTML footer for each
+generated HTML page. If the tag is left blank doxygen will generate a standard
+footer. See HTML_HEADER for more information on how to generate a default
+footer and what special commands can be used inside the footer. See also
+section &quot;Doxygen usage&quot; for information on how to generate the default footer
+that doxygen normally uses.</source>
+        <translation>HTML_FOOTER には利用者定義の下部見出し HTML を指定できます。指定がなければ内蔵の標準下見出しを適用します。詳細は HTML_HEADER の説明をご覧ください。標準下見出しの取得方法、下見出し内で使える特殊指示などについて記しています。また、 &quot;Doxygen usage&quot; にも doxygen 本体がどのようにして標準下見出しを生成するかを記しています。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3078"/>
+        <source>The HTML_EXTRA_STYLESHEET tag can be used to specify an additional user-
+defined cascading style sheet that is included after the standard style sheets
+created by doxygen. Using this option one can overrule certain style aspects.
+This is preferred over using HTML_STYLESHEET since it does not replace the
+standard style sheet and is therefor more robust against future updates.
+Doxygen will copy the style sheet file to the output directory. For an example
+see the documentation.</source>
+        <translation>HTML_EXTRA_STYLESHEET にはユーザー定義の段階スタイルシート(CSS, Cascading Style sheet)を指定できます。ユーザー指定のそれは doxygen の標準スタイルシートの後に挿入されます。この指定により、適当なスタイル規則の上書きができます。
+HTML_STYLESHEET よりもこちらの利用が望まれます。 HTML_STYLESHEET は標準スタイルシートを置き換えてしまうため将来の更新の影響をより強く受けやすくなります。指定されたスタイルシートはそのまま出力ディレクトリに複製されます。実例としては説明書を参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3087"/>
+        <source>The HTML_EXTRA_FILES tag can be used to specify one or more extra images or
+other source files which should be copied to the HTML output directory. Note
+that these files will be copied to the base HTML output directory. Use the
+$relpath^ marker in the HTML_HEADER and/or HTML_FOOTER files to load these
+files. In the HTML_STYLESHEET file, use the file name only. Also note that the
+files will be copied as-is; there are no commands or markers available.</source>
+        <translation>HTML_EXTRA_FILES には任意数の HTML 出力ディレクトリに複製すべき画像やその他ソースのファイルを指定できます。
+指定されたファイルは HTML 出力ディレクトリにそのまま配置される点にご注意ください。HTML_HEADER や HTML_FOOTER で指定された $relpath^ マーカーによりこれらのファイルを読み出せます。 HTML_STYLESHEET に指定されたファイルからはファイル名だけをご指定ください。ファイルはそのまま複製され、それに関して可能な指示やマーカーはありません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3095"/>
+        <source>The HTML_COLORSTYLE_HUE tag controls the color of the HTML output. Doxygen
+will adjust the colors in the stylesheet and background images according to
+this color. Hue is specified as an angle on a colorwheel, see
+http://en.wikipedia.org/wiki/Hue for more information. For instance the value
+0 represents red, 60 is yellow, 120 is green, 180 is cyan, 240 is blue, 300
+purple, and 360 is red again.</source>
+        <translation>HTML_COLORSTYLE_HUE は HTML 出力の色制御の一つです。doxygen はスタイルシートと背景色を指定値に基づき調整します。色相(Hue)とは色あいの事で、色相環における角度で指定します。 詳細は http://ja.wikipedia.org/wiki/色相 を参照ください。
+色相は単位°による値でご指定ください。0 が赤、60が黄、120が緑、180が水色、240が青、300が紫、360で一周回って赤に戻ります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3103"/>
+        <source>The HTML_COLORSTYLE_SAT tag controls the purity (or saturation) of the colors
+in the HTML output. For a value of 0 the output will use grayscales only. A
+value of 255 will produce the most vivid colors.</source>
+        <translation>HTML_COLORSTYLE_SAT は HTML 出力の色制御の一つです。彩度(saturation)ないし純度(purity)を 0 (無彩色, 灰色・白・黒) - 255 (もっとも鮮やか、色味がある) でご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3108"/>
+        <source>The HTML_COLORSTYLE_GAMMA tag controls the gamma correction applied to the
+luminance component of the colors in the HTML output. Values below 100
+gradually make the output lighter, whereas values above 100 make the output
+darker. The value divided by 100 is the actual gamma applied, so 80 represents
+a gamma of 0.8, The value 220 represents a gamma of 2.2, and 100 does not
+change the gamma.</source>
+        <translation>HTML_COLORSTYLE_GAMMA では HTML出力の明度を調整できます。 100 .を基準に値が小さくなるにつれて明るくなり、大きくなるにつれて暗くなります。実際に使われるγ値を 100 倍した値を設定ください。すなわち 80 で 0.8、220 で 2.2 を与えたことになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3116"/>
+        <source>If the HTML_TIMESTAMP tag is set to YES then the footer of each generated HTML
+page will contain the date and time when the page was generated. Setting this
+to NO can help when comparing the output of multiple runs.</source>
+        <translation>HTML_TIMESTAMP に YES を与えると HTML ページを出力するするごとに、下見出しにその生成日時を入れるようになります。
+複数の出力処理を比較する場合に NO を設定するのがよいでしょう。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3121"/>
+        <source>If the HTML_DYNAMIC_SECTIONS tag is set to YES then the generated HTML
+documentation will contain sections that can be hidden and shown after the
+page has loaded.</source>
+        <translation>HTML_DYNAMIC_SECTIONS に YES を与えると、文書中の節表示が切り替えられる HTML ページを出力するようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3136"/>
+        <source>If the GENERATE_DOCSET tag is set to YES, additional index files will be
+generated that can be used as input for Apple&apos;s Xcode 3 integrated development
+environment (see: http://developer.apple.com/tools/xcode/), introduced with
+OSX 10.5 (Leopard). To create a documentation set, doxygen will generate a
+Makefile in the HTML output directory. Running make will produce the docset in
+that directory and running make install will install the docset in
+~/Library/Developer/Shared/Documentation/DocSets so that Xcode will find it at
+startup. See http://developer.apple.com/tools/creatingdocsetswithdoxygen.html
+for more information.</source>
+        <translation>GENERATE_DOCSET に YES を与えると索引ファイルを生成するようになります。この索引ファイルは OSX 10.5 (Leopard) から含まれるようになった Apple の Xcode 3 統合開発環境への入力として使えます。 xcode については http://developer.apple.com/tools/xcode をご覧ください。
+YES にすると、 doxygen は HTML 出力ディレクトリに Makefile を生成します。これに対し &apos;make&apos; を実行すると文書集合が作られ、さらに &apos;make install&apos; によって  ~/Library/Developer/Shared/Documentation/DocSets に複製されます。以後起動時に Xcode がこれを見つけられるようになります。詳細は http://developer.apple.com/tools/creatingdocsetswithdoxygen.htm をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3147"/>
+        <source>This tag determines the name of the docset feed. A documentation feed provides
+an umbrella under which multiple documentation sets from a single provider
+(such as a company or product suite) can be grouped.</source>
+        <translation>DOCSET_FEEDNAME には文書集合供給元名(the name of the docset feed)をご指定ください。
+会社や商品などの提供元を単位とした文書供給元名で、複数の文書集合をグループ化できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3152"/>
+        <source>This tag specifies a string that should uniquely identify the documentation
+set bundle. This should be a reverse domain-name style string, e.g.
+com.mycompany.MyDocSet. Doxygen will append .docset to the name.</source>
+        <translation>DOCSET_BUNDLE_ID には他と重複しない文書集合の識別子をご指定ください。これには com.mycompany.MyDocSet のような URL による所属の逆順表記を使うべきです。doxygen は文書集合に指定された文字列を名前として与えます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3157"/>
+        <source>The DOCSET_PUBLISHER_ID tag specifies a string that should uniquely identify
+the documentation publisher. This should be a reverse domain-name style
+string, e.g. com.mycompany.MyDocSet.documentation.</source>
+        <translation>DOCSET_PUBLISHER_ID には文書の発行者を他と重複しない識別子でご指定ください。
+これには com.mycompany.MyDocSet.documentation のような URL による所属の逆順表記を使うべきです。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3162"/>
+        <source>The DOCSET_PUBLISHER_NAME tag identifies the documentation publisher.</source>
+        <translation>DOCSET_PUBLISHER_NAME は文書の発行者名をご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3165"/>
+        <source>If the GENERATE_HTMLHELP tag is set to YES then doxygen generates three
+additional HTML index files: index.hhp, index.hhc, and index.hhk. The
+index.hhp is a project file that can be read by Microsoft&apos;s HTML Help Workshop
+(see: http://www.microsoft.com/en-us/download/details.aspx?id=21138) on
+Windows.
+
+The HTML Help Workshop contains a compiler that can convert all HTML output
+generated by doxygen into a single compiled HTML file (.chm). Compiled HTML
+files are now used as the Windows 98 help format, and will replace the old
+Windows help format (.hlp) on all Windows platforms in the future. Compressed
+HTML files also contain an index, a table of contents, and you can search for
+words in the documentation. The HTML workshop also contains a viewer for
+compressed HTML files.</source>
+        <translation>GENERATE_HTMLHELP に YES を与えると HTML 出力に対して次の 3 ファイルを追加します: index.hhp, index.hhc, index.hhk
+index.hhp はマイクロソフトの HTML Help Workshop で読み取るためのものです。 http://www.microsoft.com/en-us/download/details.aspx?id=21138 をご覧ください。
+
+HTML Help Workshop は doxygen で作った HTML ファイル群を一つの HTML ファイル (.chm, Compiled HTML file) にまとめるソフトウェアが含まれています。 chm ファイルは Windows 98 の説明ファイル様式として用いられ、それ以前の Windows help 形式(.hlp) を置き換えるものとされました。 chm ファイルは目次・索引および単語検索機能を含んでいます。 HTML Workshop は chm ビューアも含んでいます。
+
+訳注: chm 形式は Windows Vista 以降 MAML(Microsoft Assistance Markup Language) にその地位を譲っています。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3185"/>
+        <source>The HHC_LOCATION tag can be used to specify the location (absolute path
+including file name) of the HTML help compiler ( hhc.exe). If non-empty
+doxygen will try to run the HTML help compiler on the generated index.hhp.</source>
+        <translation>HHC_LOCATION で HTML ヘルプコンパイラ( hhc.exe) の位置を指示できます。ファイル名を含んだ絶対パスを与えてください。指定があれば doxygen の方から自動的に hhc.exe の呼び出しを試みます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3190"/>
+        <source>The GENERATE_CHI flag controls if a separate .chi index file is generated (
+YES) or that it should be included in the master .chm file ( NO).</source>
+        <translation>GENERATE_CHI に YES を与えると索引を .chi ファイルとして独立に出力するようになります。 NO の場合は .chm ファイルに結合されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3194"/>
+        <source>The CHM_INDEX_ENCODING is used to encode HtmlHelp index ( hhk), content ( hhc)
+and project file content.</source>
+        <translation>CHM_INDEX_ENCODING には HTML ヘルプの索引 (.hhk)、内容( .hhc)およびプロジェクトの中身の文字符号化法をご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3198"/>
+        <source>The BINARY_TOC flag controls whether a binary table of contents is generated (
+YES) or a normal table of contents ( NO) in the .chm file.</source>
+        <translatorcomment>何を意味するのか解ってません。</translatorcomment>
+        <translation>BINARY_TOC に YES を与えると目次をバイナリで作ります。 NO の場合は通常の目次を .chm ファイル内に作ります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3206"/>
+        <source>If the GENERATE_QHP tag is set to YES and both QHP_NAMESPACE and
+QHP_VIRTUAL_FOLDER are set, an additional index file will be generated that
+can be used as input for Qt&apos;s qhelpgenerator to generate a Qt Compressed Help
+(.qch) of the generated HTML documentation.</source>
+        <translation>GENERATE_QHP に YES を与えると QHP_NAMESPACE および QHP_VIRTUAL_FOLDER の内容に応じて Qt の qhelpgenerator に用いられる索引ファイルを追加出力するようになります。Qt Compressed Help ( .qch) を生成するときに使用されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3217"/>
+        <source>The QHP_NAMESPACE tag specifies the namespace to use when generating Qt Help
+Project output. For more information please see Qt Help Project / Namespace
+(see: http://qt-project.org/doc/qt-4.8/qthelpproject.html#namespace).</source>
+        <translation>QHP_NAMESPACE には Qt Help Project の出力に用いる名前空間をご指定ください。
+詳細は Qt Help Project / Namespace, http://qt-project.org/doc/qt-4.8/qthelpproject.html#namespace をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3222"/>
+        <source>The QHP_VIRTUAL_FOLDER tag specifies the virtual folder to use when generating
+Qt Help Project output. For more information please see Qt Help Project /
+Virtual Folders (see: http://qt-project.org/doc/qt-4.8/qthelpproject.html
+#virtual-folders).</source>
+        <oldsource>The QHP_VIRTUAL_FOLDER tag specifies the namespace to use when generating Qt
+Help Project output. For more information please see Qt Help Project / Virtual
+Folders (see: http://qt-project.org/doc/qt-4.8/qthelpproject.html#virtual-
+folders).</oldsource>
+        <translation>QHP_VIRTUAL_FOLDER には Qt Help Project の出力に使う仮想フォルダの名前をご指定ください。
+詳細は Qt Help Project / Virtual Folders, http://qt-project.org/doc/qt-4.8/qthelpproject.html#virtual-folders をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3228"/>
+        <source>If the QHP_CUST_FILTER_NAME tag is set, it specifies the name of a custom
+filter to add. For more information please see Qt Help Project / Custom
+Filters (see: http://qt-project.org/doc/qt-4.8/qthelpproject.html#custom-
+filters).</source>
+        <translation>QHP_CUST_FILTER_NAME にはカスタムフィルタ名を指定できます。
+詳細は Qt Help Project / Custom Filters, http://qt-project.org/doc/qt-4.8/qthelpproject.html#custom-filters をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3234"/>
+        <source>The QHP_CUST_FILTER_ATTRS tag specifies the list of the attributes of the
+custom filter to add. For more information please see Qt Help Project / Custom
+Filters (see: http://qt-project.org/doc/qt-4.8/qthelpproject.html#custom-
+filters).</source>
+        <translation>QHP_CUST_FILTER_ATTRS には追加するカスタムフィルタの各種属性を指定できます。
+詳細は Qt Help Project / Custom Filters, http://qt-project.org/doc/qt-4.8/qthelpproject.html#custom-filters をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3240"/>
+        <source>The QHP_SECT_FILTER_ATTRS tag specifies the list of the attributes this
+project&apos;s filter section matches. Qt Help Project / Filter Attributes (see:
+http://qt-project.org/doc/qt-4.8/qthelpproject.html#filter-attributes).</source>
+        <translation>QHP_SECT_FILTER_ATTRS にはこのプロジェクトのフィルタ節に合致する属性一覧をご指定ください。
+Qt Help Project / Filter Attributes (http://qt-project.org/doc/qt-4.8/qthelpproject.html#filter-attributes) を参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3245"/>
+        <source>The QHG_LOCATION tag can be used to specify the location of Qt&apos;s
+qhelpgenerator. If non-empty doxygen will try to run qhelpgenerator on the
+generated .qhp file.</source>
+        <translation>QHG_LOCATION には Qt の qhelpgenerator の場所をご指定ください。
+指定があった場合は、生成した qhp を qhelpgenerator に渡す形の実行を試みます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3250"/>
+        <source>If the GENERATE_ECLIPSEHELP tag is set to YES, additional index files will be
+generated, together with the HTML files, they form an Eclipse help plugin. To
+install this plugin and make it available under the help contents menu in
+Eclipse, the contents of the directory containing the HTML and XML files needs
+to be copied into the plugins directory of eclipse. The name of the directory
+within the plugins directory should be the same as the ECLIPSE_DOC_ID value.
+After copying Eclipse needs to be restarted before the help appears.</source>
+        <translation>GENERATE_ECLIPSEHELP に YES を与えると追加の索引ファイルを生成します。 HTML ファイルとともに Eclipse のヘルププラグインとして用いられます。プラグインを Eclipse に設置し、ヘルプコンテンツメニューのもとで使えるようにするには、HTMLおよびXMLファイルを Eclipse のプラグインディレクトリに複製する必要があります。プラグインディレクトリ内におけるディレクトリ名は ECLIPSE_DOC_ID と一致させてください。複製後、ヘルプを認識させるため Eclipse を再起動しなくてはなりません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3259"/>
+        <source>A unique identifier for the Eclipse help plugin. When installing the plugin
+the directory name containing the HTML and XML files should also have this
+name. Each documentation set should have its own identifier.</source>
+        <translation>ECLIPSE_DOC_ID には Eclipse ヘルププラグインにおける他と衝突しない識別子をご指定ください。
+HTML および XML ファイルを含み、プラグインディレクトリに設置されるディレクトリ名もこの識別子と一致させなくてはなりません。各々の文書集合に自身の識別子を与えておくべきでしょう。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3264"/>
+        <source>If you want full control over the layout of the generated HTML pages it might
+be necessary to disable the index and replace it with your own. The
+DISABLE_INDEX tag can be used to turn on/off the condensed index (tabs) at top
+of each HTML page. A value of NO enables the index and the value YES disables
+it. Since the tabs in the index contain the same information as the navigation
+tree, you can set this option to YES if you also set GENERATE_TREEVIEW to YES.</source>
+        <translation>生成された HTML における表現配置を完全に制御したい場合は、索引を無効化し、自身の用意したもので置き換える必要があるかもしれません。
+DISABLE_INDEX は各HTML ページの上部にある要約見出し(タブ)を自動出力(NO)または抑制(YES)することができます。
+
+このほか、上部の見出しは移動用木構造と情報を共有しているので、GENERATE_TREEVIEW と DISABLE_INDEX の両方に YES を与えて木構造に移動補助を一任することもできます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3272"/>
+        <source>The GENERATE_TREEVIEW tag is used to specify whether a tree-like index
+structure should be generated to display hierarchical information. If the tag
+value is set to YES, a side panel will be generated containing a tree-like
+index structure (just like the one that is generated for HTML Help). For this
+to work a browser that supports JavaScript, DHTML, CSS and frames is required
+(i.e. any modern browser). Windows users are probably better off using the
+HTML help feature. Via custom stylesheets (see HTML_EXTRA_STYLESHEET) one can
+further fine-tune the look of the index. As an example, the default style
+sheet generated by doxygen has an example that shows how to put an image at
+the root of the tree instead of the PROJECT_NAME. Since the tree basically has
+the same information as the tab index, you could consider setting
+DISABLE_INDEX to YES when enabling this option.</source>
+        <translation>GENERATE_TREEVIEW には木構造索引による階層化情報表示を行うかどうかをご指定ください。
+YES を与えると、HTMLヘルプのような木構造索引を作り、横側に区画をとって配置します。この機能はブラウザ側が Javascript, DHTML, CSS と HTML のフレームに対応していないと動作しません。Windows においては HTML ヘルプ機能を切っておいた方が良いかもしれません。
+HTML_EXTRA_STYLESHEET による編集済みスタイルシートを用いてより好みの見た目にすることもできます。例えば doxygen 標準スタイルシートには PROJECT_NAME の 代わりに木構造の根にどの画像を置くかが指定されています。
+この機能は各 HTML 上部のタブ索引とほぼ同じ情報を持っているため、こちらを有効にして DISABLE_INDEX にも YES を与えてタブ側を無効にすることもできます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3286"/>
+        <source>The ENUM_VALUES_PER_LINE tag can be used to set the number of enum values that
+doxygen will group on one line in the generated HTML documentation.
+
+Note that a value of 0 will completely suppress the enum values from appearing
+in the overview section.</source>
+        <translation>ENUM_VALUES_PER_LINE には HTML 文書の生成において列挙値を一行にいくつ表示させるかをご指定ください。
+なお 0 を指定した場合は概要節における列挙値表示を行わなくなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3293"/>
+        <source>If the treeview is enabled (see GENERATE_TREEVIEW) then this tag can be used
+to set the initial width (in pixels) of the frame in which the tree is shown.</source>
+        <translation>GENERATE_TREEVIEW に YES を与えているとき、TREEVIEW_WIDTH に木構造索引部の初期表示幅を設定できます。ピクセル単位でご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3297"/>
+        <source>When the EXT_LINKS_IN_WINDOW option is set to YES doxygen will open links to
+external symbols imported via tag files in a separate window.</source>
+        <translation>EXT_LINKS_IN_WINDOW に YES を与えると import したタグファイルに対する外部参照は、リンクの際に独立した窓枠で開くようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3301"/>
+        <source>Use this tag to change the font size of LaTeX formulas included as images in
+the HTML documentation. When you change the font size after a successful
+doxygen run you need to manually remove any form_*.png images from the HTML
+output directory to force them to be regenerated.</source>
+        <translation>HTML 文書出力における LaTeX 生成数式の書体寸法は FORMULA_FONTSIZE で変更できます。
+
+いったん出力が完成した後でこの指定値を変更した場合は、既存の出力から from_*.png に該当するファイルを手動で削除しておかないと画像の再生成が行われませんのでご注意ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3307"/>
+        <source>Use the FORMULA_TRANPARENT tag to determine whether or not the images
+generated for formulas are transparent PNGs. Transparent PNGs are not
+supported properly for IE 6.0, but are supported on all modern browsers.
+
+Note that when changing this option you need to delete any form_*.png files in
+the HTML output directory before the changes have effect.</source>
+        <translation>数式を表す PNG ファイルが透過属性を持つかどうかを FORMULA_TRANPARENT にご指定ください。
+透過 PNG は IE 6.0 では表示されず、他方多くの他のブラウザでは表示できます。
+
+いったん出力が完成した後でこの指定値を変更した場合は、既存の出力から from_*.png に該当するファイルを手動で削除しておかないと画像の再生成が行われませんのでご注意ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3315"/>
+        <source>Enable the USE_MATHJAX option to render LaTeX formulas using MathJax (see
+http://www.mathjax.org) which uses client side Javascript for the rendering
+instead of using prerendered bitmaps. Use this if you do not have LaTeX
+installed or if you want to formulas look prettier in the HTML output. When
+enabled you may also need to install MathJax separately and configure the path
+to it using the MATHJAX_RELPATH option.</source>
+        <translation>USE_MATHJAX を有効にすると、内蔵機能の代わりに MathJax http://www.mathjax.org で LaTeX の数式を画像化するようになります。
+LaTeX インストーラがない場合や HTML 出力の数式により高質なものを使いたい場合にご利用ください。
+この機能は MathJax の設置および MATHJAX_RELPATH によるパス指定が必要です。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3323"/>
+        <source>When MathJax is enabled you can set the default output format to be used for
+the MathJax output. See the MathJax site (see:
+http://docs.mathjax.org/en/latest/output.html) for more details.</source>
+        <translation>MATHJAX_FORMAT には MathJax の標準出力様式を指定できます。詳細は MathJax のサイト http://docs.mathjax.org/en/latest/output.html をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3328"/>
+        <source>When MathJax is enabled you need to specify the location relative to the HTML
+output directory using the MATHJAX_RELPATH option. The destination directory
+should contain the MathJax.js script. For instance, if the mathjax directory
+is located at the same level as the HTML output directory, then
+MATHJAX_RELPATH should be ../mathjax. The default value points to the MathJax
+Content Delivery Network so you can quickly see the result without installing
+MathJax. However, it is strongly recommended to install a local copy of
+MathJax from http://www.mathjax.org before deployment.</source>
+        <translation>MathJax の出力先相対パスを MATHJAX_RELPATH に指定できます。パスは HTML 出力ディレクトリを基準に解析されます。
+出力先ディレクトリには MathJax.js スクリプトが収められていなくてはなりません。たとえば mathjax ディレクトリが HTML 出力と同じ階層にある場合、MATHJAX_RELPATH には &apos;../mathjax&apos; をご指定ください。
+省略値・初期値は MathJax
+Content Delivery Network を指しているため MathJax が未設置でも出力結果の目視検証はできますが、公開に当たっては必要なスクリプトの複製と設置が強く推奨されています。
+http://www.mathjax.org にて複製すべきスクリプトが配布されています。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3338"/>
+        <source>The MATHJAX_EXTENSIONS tag can be used to specify one or more MathJax
+extension names that should be enabled during MathJax rendering. For example
+MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols</source>
+        <translation>MATHJAX_EXTENSIONS には任意数の MathJax 用拡張名を指定できます。MathJax によるレンダリングの際に有効になります。
+次のような使い方になります:
+MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3343"/>
+        <source>The MATHJAX_CODEFILE tag can be used to specify a file with javascript pieces
+of code that will be used on startup of the MathJax code. See the MathJax site
+(see: http://docs.mathjax.org/en/latest/output.html) for more details. For an
+example see the documentation.</source>
+        <translation>MATHJAX_CODEFILE には MathJax コードの開始時に使われる Javascript コード片ファイルを指定できます。
+詳細は MathJax のサイト http://docs.mathjax.org/en/latest/output.html をご覧ください。
+利用例は説明所を参照ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3349"/>
+        <source>When the SEARCHENGINE tag is enabled doxygen will generate a search box for
+the HTML output. The underlying search engine uses javascript and DHTML and
+should work on any modern browser. Note that when using HTML help
+(GENERATE_HTMLHELP), Qt help (GENERATE_QHP), or docsets (GENERATE_DOCSET)
+there is already a search function so this one should typically be disabled.
+For large projects the javascript based search engine can be slow, then
+enabling SERVER_BASED_SEARCH may provide a better solution. It is possible to
+search using the keyboard; to jump to the search box use &lt;access key&gt; + S
+(what the &lt;access key&gt; is depends on the OS and browser, but it is typically
+&lt;CTRL&gt;, &lt;ALT&gt;/&lt;option&gt;, or both). Inside the search box use the &lt;cursor down
+key&gt; to jump into the search results window, the results can be navigated
+using the &lt;cursor keys&gt;. Press &lt;Enter&gt; to select an item or &lt;escape&gt; to cancel
+the search. The filter options can be selected when the cursor is inside the
+search box by pressing &lt;Shift&gt;+&lt;cursor down&gt;. Also here use the &lt;cursor keys&gt;
+to select a filter and &lt;Enter&gt; or &lt;escape&gt; to activate or cancel the filter
+option.</source>
+        <translation>SEARCHENGINE を有効にすると HTML 出力に検索欄を追加するようになります。
+検索処理には DHTML と Javascript を使うため、これらに対応した近年のブラウザが必要です。
+
+HTML ヘルプ(GENERATE_HTMLHELP)、Qt ヘルプ(GENERATE_QHP)、文書集合(GENERATE_DOCSET)のいずれかを利用する場合はそれぞれに検索機能がありますのでこちらの設定は通常無効にしてください。
+
+プロジェクト全体が大きい場合は Javascript による検索機能の処理負荷が高くなることがあります。SERVER_BASED_SEARCH を併用することで解決できる場合があります。
+
+&lt;修飾キー&gt;を押しながら S キーを入力することでキーボードから検索欄に移ることができます。修飾キーは OS やブラウザ によって異なりますが、Ctrl, Alt, Option キーなどが通例です。
+検索欄からは矢印↓キーで検索結果ウィンドウに入れます。検索結果の中は各矢印キーで移動できます。
+Enter キーで注目項目のページに移動、Escape (Esc) キーで検索結果を破棄します。
+検索対象の絞り込みは検索欄内で&lt;Shift&gt;を押しながら矢印↓キーを押してください。絞り込みウィンドウが出てきますのでその中で同様に矢印キーで移動、Enter キーで変更決定、Escape キーで無変更となります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3367"/>
+        <source>When the SERVER_BASED_SEARCH tag is enabled the search engine will be
+implemented using a web server instead of a web client using Javascript. There
+are two flavours of web server based searching depending on the
+EXTERNAL_SEARCH setting. When disabled, doxygen will generate a PHP script for
+searching and an index file used by the script. When EXTERNAL_SEARCH is
+enabled the indexing and searching needs to be provided by external tools. See
+the section &quot;External Indexing and Searching&quot; for details.</source>
+        <translation>SERVER_BASED_SEARCH を有効にすると Javascript と読者側ブラウザによるものの代わりに文書提供側のウェブサーバによる検索機能が使えるようになります。
+ウェブサーバ検索にはさらに二種類が用意されており、EXTERNAL_SEARCH の設定で選択します。
+EXTERNAL_SEARCH が無効の場合は PHP スクリプトによる検索機能と索引の準備が行われます。
+EXTERNAL_SEARCH が有効の場合は 別途外部ツールが必要となります。詳細は &quot;External Indexing and Searching&quot; 節をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3376"/>
+        <source>When EXTERNAL_SEARCH tag is enabled doxygen will no longer generate the PHP
+script for searching. Instead the search results are written to an XML file
+which needs to be processed by an external indexer. Doxygen will invoke an
+external search engine pointed to by the SEARCHENGINE_URL option to obtain the
+search results.
+
+Doxygen ships with an example indexer ( doxyindexer) and search engine
+(doxysearch.cgi) which are based on the open source search engine library
+Xapian (see: http://xapian.org/).
+
+See the section &quot;External Indexing and Searching&quot; for details.</source>
+        <translation>EXTERNAL_SEARCH を有効にすると PHP による検索機能提供を止め、検索結果に用いる情報を XML ファイルに書き出すようになります。この XML ファイルは外部の索引づけ機能により使われることになります。外部の検索機能は SEARCHENGINE_URL に指定された URL をもとに呼び出しを行います。
+
+doxygen では索引生成と検索機能の作例として doxyindexer および doxyseach.cgi を公開しています。これらはオープンソースの検索エンジン Xapian ( http://xapian.org ) を土台としています。
+詳細は説明書の &quot;External Indexing and Searching&quot; 節をご覧ください。 </translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3389"/>
+        <source>The SEARCHENGINE_URL should point to a search engine hosted by a web server
+which will return the search results when EXTERNAL_SEARCH is enabled.
+
+Doxygen ships with an example indexer ( doxyindexer) and search engine
+(doxysearch.cgi) which are based on the open source search engine library
+Xapian (see: http://xapian.org/). See the section &quot;External Indexing and
+Searching&quot; for details.</source>
+        <translation>SEARCHENGINE_URL には EXTERNAL_SEARCH が有効の時の検索結果を返すウェブサーバ をご指定ください。
+
+doxygen では索引生成と検索機能の作例として doxyindexer および doxyseach.cgi を公開しています。これらはオープンソースの検索エンジン Xapian ( http://xapian.org ) を土台としています。
+詳細は説明書の &quot;External Indexing and Searching&quot; 節をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3398"/>
+        <source>When SERVER_BASED_SEARCH and EXTERNAL_SEARCH are both enabled the unindexed
+search data is written to a file for indexing by an external tool. With the
+SEARCHDATA_FILE tag the name of this file can be specified.</source>
+        <translation>SERVER_BASED_SEARCH と EXTERNAL_SEARCH の両方を有効にすると、索引上にまだない検索結果用情報を特定のファイルに書き込みます。このファイルは外部の索引生成ツールに利用されます。 SEARCHDATA_FILE にはこのファイルの名前をご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3403"/>
+        <source>When SERVER_BASED_SEARCH and EXTERNAL_SEARCH are both enabled the
+EXTERNAL_SEARCH_ID tag can be used as an identifier for the project. This is
+useful in combination with EXTRA_SEARCH_MAPPINGS to search through multiple
+projects and redirect the results back to the right project.</source>
+        <translation>SERVER_BASED_SEARCH と SERVER_BASED_SEARCH の両方を有効にすると、EXTERNAL_SEARCH_ID にプロジェクトごとの識別子を指定できます。
+EXTRA_SEARCH_MAPPINGS と合わせて利用することで複数のプロジェクトからまとめて検索し、検索結果を個々のプロジェクトとそれぞれ再結合させる目的で利用できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3409"/>
+        <source>The EXTRA_SEARCH_MAPPINGS tag can be used to enable searching through doxygen
+projects other than the one defined by this configuration file, but that are
+all added to the same external search index. Each project needs to have a
+unique id set via EXTERNAL_SEARCH_ID. The search mapping then maps the id of
+to a relative location where the documentation can be found. The format is:
+EXTRA_SEARCH_MAPPINGS = tagname1=loc1 tagname2=loc2 ...</source>
+        <translation>EXTRA_SEARCH_MAPPINGS は複数の doxygen プロジェクトを通した検索に利用できます。
+複数プロジェクトの検索結果用データを一つの外部索引にまとめ上げて使うときに活用してください。この場合、各々のプロジェクトは独立した識別子をEXTERNAL_SEARCH_ID に指定されている必要があります。そうすることで、検索割当機能が識別子と各々のプロジェクトへの相対位置を関連付けられ、一括した検索結果でプロジェクトごとに区別ができるようになります。
+書式は次の通りです:
+EXTRA_SEARCH_MAPPINGS = 識別子1=場所1 識別子2=場所2 …</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3420"/>
+        <source>The LATEX_OUTPUT tag is used to specify where the LaTeX docs will be put. If a
+relative path is entered the value of OUTPUT_DIRECTORY will be put in front of
+it.</source>
+        <translation>LATEX_OUTPUT には LaTeX 文書の出力先をご指定ください。
+相対パスを指定した場合は OUTPUT_DIRECTORY の内容を前置した状態で解析します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3425"/>
+        <source>The LATEX_CMD_NAME tag can be used to specify the LaTeX command name to be
+invoked.
+
+Note that when enabling USE_PDFLATEX this option is only used for generating
+bitmaps for formulas in the HTML output, but not in the Makefile that is
+written to the output directory.</source>
+        <translation>LATEX_CMD_NAME には LaTeX を実行するコマンド名をご指定ください。
+
+USE_PDFLATEX を有効にしている場合、こちらの設定は HTML 出力における数式画像の生成にのみ使われ、出力ディレクトリ上の Makefile には影響を与えなくなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3433"/>
+        <source>The MAKEINDEX_CMD_NAME tag can be used to specify the command name to generate
+index for LaTeX.</source>
+        <translation>MAKEINDEX_CMD_NAME には LeTeX 用の索引を生成するコマンド名をご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3437"/>
+        <source>If the COMPACT_LATEX tag is set to YES doxygen generates more compact LaTeX
+documents. This may be useful for small projects and may help to save some
+trees in general.</source>
+        <translation>COMPACT_LATEX に YES を与えると LaTeX 出力はより小さなものになります。
+この機能は小さなプロジェクトに有用で、一般的に木構造を省きます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3442"/>
+        <source>The PAPER_TYPE tag can be used to set the paper type that is used by the
+printer.</source>
+        <translation>プリンタで使われる用紙の種別は PAPER_TYPE で指定できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3446"/>
+        <source>The EXTRA_PACKAGES tag can be used to specify one or more LaTeX package names
+that should be included in the LaTeX output. To get the times font for
+instance you can specify
+EXTRA_PACKAGES=times
+If left blank no extra packages will be included.</source>
+        <translation>EXTRA_PACKAGES には任意数の LaTeX パッケージ名を設定できます。出力に必要なものをここでご指定ください。
+例えば times 書体が必要であれば &apos;EXTRA_PACKAGES=time&apos; と記述します。
+空のままであれば特に何もしません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3453"/>
+        <source>The LATEX_HEADER tag can be used to specify a personal LaTeX header for the
+generated LaTeX document. The header should contain everything until the first
+chapter. If it is left blank doxygen will generate a standard header. See
+section &quot;Doxygen usage&quot; for information on how to let doxygen write the
+default header to a separate file.
+
+Note: Only use a user-defined header if you know what you are doing! The
+following commands have a special meaning inside the header: $title,
+$datetime, $date, $doxygenversion, $projectname, $projectnumber. Doxygen will
+replace them by respectively the title of the page, the current date and time,
+only the current date, the version number of doxygen, the project name (see
+PROJECT_NAME), or the project number (see PROJECT_NUMBER).</source>
+        <translation>LATEX_HEADER には出力のための個人の LaTeX 見出しを指定できます。見出しは最初の章が始まるまでの全てを含んでいなければなりません。
+指定がない場合は doxygen 内蔵の標準見出しが使われます。詳細は &quot;Doxygen usage&quot; をご覧ください。 doxygen からファイルの形で標準見出しを得る方法もそちらにあります。
+
+注意: 何をしているのか理解されている場合だけこの機能をご利用ください。見出しの中では次のコマンドが特殊な意味を持っています:
+$title, $datetime, $date, $doxygenversion, $projectname, $projectnumber
+doxygen は上記をそれぞれページタイトル、生成日時、生成日、doxygen の版数、プロジェクト名(PROJECT_NAME を参照の事)、プロジェクトの版数(PROJECT_NUMBER を参照の事)に置き換えます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3474"/>
+        <source>The LATEX_EXTRA_FILES tag can be used to specify one or more extra images or
+other source files which should be copied to the LATEX_OUTPUT output
+directory. Note that the files will be copied as-is; there are no commands or
+markers available.</source>
+        <translation>LATEX_EXTRA_FILES には任意数の追加画像やソースファイルを指定できます。 LATEX_OUTPUT に必要なものをご指定ください。
+指定されたファイルはそのまま複写されます。複写に関するコマンドやマーカーはありません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3480"/>
+        <source>If the PDF_HYPERLINKS tag is set to YES, the LaTeX that is generated is
+prepared for conversion to PDF (using ps2pdf or pdflatex). The PDF file will
+contain links (just like the HTML output) instead of page references. This
+makes the output suitable for online browsing using a PDF viewer.</source>
+        <translation>PDF_HYPERLINKS に YES を与えると LaTeX からは PDF に変換する準備を出力します。途中 ps2pdf または pdflatex へ情報が渡されます。
+このようにして作った PDF ファイルはページ参照の代わりに HTML のようなリンクが付けられています。 PDF ビューアを使ったオンライン文書として出慮したい場合に用いてください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3486"/>
+        <source>If the LATEX_PDFLATEX tag is set to YES, doxygen will use pdflatex to generate
+the PDF file directly from the LaTeX files. Set this option to YES to get a
+higher quality PDF documentation.</source>
+        <translation>LATEX_PDFLATEX に YES を与えると doxygen は LaTeX ファイルを pdflatex に渡して直接 PDF ファイルを生成するようになります。より質の高い PDF ファイルが得られます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3497"/>
+        <source>If the LATEX_HIDE_INDICES tag is set to YES then doxygen will not include the
+index chapters (such as File Index, Compound Index, etc.) in the output.</source>
+        <translation>LATEX_HIDE_INDICES に YES を与えると索引の章が出力から省かれます。ファイル索引などが出力されなくなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3501"/>
+        <source>If the LATEX_SOURCE_CODE tag is set to YES then doxygen will include source
+code with syntax highlighting in the LaTeX output.
+
+Note that which sources are shown also depends on other settings such as
+SOURCE_BROWSER.</source>
+        <translation>LATEX_SOURCE_CODE に YES を与えると文法強調を伴ったソースコードも LaTeX 出力に含まれるようになります。
+
+どのソースコードが含まれるかについては SOURCE_BROWSER ほか各種の設定に依存します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3518"/>
+        <source>The RTF_OUTPUT tag is used to specify where the RTF docs will be put. If a
+relative path is entered the value of OUTPUT_DIRECTORY will be put in front of
+it.</source>
+        <translation>RTF_OUTPUT には RTF 形式文書の出力先ををご指定ください。
+相対パスを指定した場合は OUTPUT_DIRECTORY の内容を前置した状態で解析します。 </translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3523"/>
+        <source>If the COMPACT_RTF tag is set to YES doxygen generates more compact RTF
+documents. This may be useful for small projects and may help to save some
+trees in general.</source>
+        <translation>COMPACT_RTF に YES を与えると RTF 出力はより小さなものになります。
+この機能は小さなプロジェクトに有用で、一般的に木構造を省きます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3528"/>
+        <source>If the RTF_HYPERLINKS tag is set to YES, the RTF that is generated will
+contain hyperlink fields. The RTF file will contain links (just like the HTML
+output) instead of page references. This makes the output suitable for online
+browsing using Word or some other Word compatible readers that support those
+fields.
+
+Note: WordPad (write) and others do not support links.</source>
+        <translation>RTF_HYPERLINKS に YES を与えると RTF 出力にハイパーリンクを含めるようになります。
+ページ参照の代わりに HTML のようなリンクを持った RTF ファイルを生成します。この機能は Word やその互換リーダーを前提としたオンライン公開に便利です。
+
+注意: WordPad(write.exe)は RTF ファイルを読めますがリンク機能には対応していません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3537"/>
+        <source>Load stylesheet definitions from file. Syntax is similar to doxygen&apos;s config
+file, i.e. a series of assignments. You only have to provide replacements,
+missing definitions are set to their default value.
+
+See also section &quot;Doxygen usage&quot; for information on how to generate the
+default style sheet that doxygen normally uses.</source>
+        <translation>スタイルシート定義をファイルから読み取ります。書式は doxygen の設定ファイル同様割当の繰り返しです。省略値・初期設定と異なる分だけを定義するだけで結構です。
+
+詳細は &quot;Doxygen usage&quot; 節をご覧ください。 doxygen が通常使用する標準スタイルシートを得る方法もそちらにあります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3545"/>
+        <source>Set optional variables used in the generation of an RTF document. Syntax is
+similar to doxygen&apos;s config file. A template extensions file can be generated
+using doxygen -e rtf extensionFile.</source>
+        <translation>RTF 文書を生成するときに使われる追加変数を指定できます。書式は doxygen の設定ファイルと同様です。
+&apos;doxygen -e rtf 拡張ファイル&apos; という書式により雛型の拡張ファイルを得ることができます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3550"/>
+        <source>If the GENERATE_MAN tag is set to YES doxygen will generate man pages for
+classes and files.</source>
+        <translation>GENERATE_MAN に YES を与えるとクラスやファイルに対して man ページを生成するようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3554"/>
+        <source>The MAN_OUTPUT tag is used to specify where the man pages will be put. If a
+relative path is entered the value of OUTPUT_DIRECTORY will be put in front of
+it. A directory man3 will be created inside the directory specified by
+MAN_OUTPUT.</source>
+        <translation>MAN_OUTPUT には man ページの出力先ご指定ください。
+相対パスを指定した場合は OUTPUT_DIRECTORY の内容を前置した状態で解析します。
+指定したディレクトリのなかに man3 というディレクトリが作られます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3560"/>
+        <source>The MAN_EXTENSION tag determines the extension that is added to the generated
+man pages. In case the manual section does not start with a number, the number
+3 is prepended. The dot (.) at the beginning of the MAN_EXTENSION tag is
+optional.</source>
+        <translation>MAN_EXTENSION には man ページ出力の拡張子をご指定ください。数字で始まらない説明書節には 3 が前置されます。
+MAN_EXTENSION の先頭にピリオド ( . ) を付けるのは任意です。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3566"/>
+        <source>If the MAN_LINKS tag is set to YES and doxygen generates man output, then it
+will generate one additional man file for each entity documented in the real
+man page(s). These additional files only source the real man page, but without
+them the man command would be unable to find the correct page.</source>
+        <translation>MAN_LINKS に YES を与えると、まず man 出力を行い、その後に各項目への実文書リンクからなる別の man ファイルも出力します。
+実際の man ページにとっては、この追加ファイルはソースファイルの役割しか果たしませんが、これが欠けていると man コマンドは正しいページを表示できなくなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3572"/>
+        <source>If the GENERATE_XML tag is set to YES doxygen will generate an XML file that
+captures the structure of the code including all documentation.</source>
+        <translation>GENERATE_XML に YES を与えると XML ファイルを生成するようになります。
+XML ファイルにはすべての文書を含んだコードの構造が書き込まれます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3576"/>
+        <source>The XML_OUTPUT tag is used to specify where the XML pages will be put. If a
+relative path is entered the value of OUTPUT_DIRECTORY will be put in front of
+it.</source>
+        <translation>XML_OUTPUT には XML ページの出力先をご指定ください。
+相対パスを指定した場合は OUTPUT_DIRECTORY の内容を前置した状態で解析します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3581"/>
+        <source>The XML_SCHEMA tag can be used to specify a XML schema, which can be used by a
+validating XML parser to check the syntax of the XML files.</source>
+        <translation>XML_SCHEMA には XML スキーマを指定できます。
+XML スキーマは XML 解析器によって用いられ、 XML ファイルの文法検査基準となります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3589"/>
+        <source>If the XML_PROGRAMLISTING tag is set to YES doxygen will dump the program
+listings (including syntax highlighting and cross-referencing information) to
+the XML output. Note that enabling this will significantly increase the size
+of the XML output.</source>
+        <translation>XML_PROGRAMLISTING に YES を与えると doxygen は文法強調・相互参照情報も含めたプログラムリスティング原情報を XML 出力に加えます。
+XML 出力の量が大きく増えますのでご注意ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3595"/>
+        <source>If the GENERATE_DOCBOOK tag is set to YES doxygen will generate Docbook files
+that can be used to generate PDF.</source>
+        <translation>GENERATE_DOCBOOK に YES を与えると Docbook ファイルを生成します。このファイルは PDF の生成に利用できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3599"/>
+        <source>The DOCBOOK_OUTPUT tag is used to specify where the Docbook pages will be put.
+If a relative path is entered the value of OUTPUT_DIRECTORY will be put in
+front of it.</source>
+        <translation>DOCBOOK_OUTPUT には Docbook ページの出力先をご指定ください。
+相対パスを指定した場合は OUTPUT_DIRECTORY の内容を前置した状態で解析します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3604"/>
+        <source>If the GENERATE_AUTOGEN_DEF tag is set to YES doxygen will generate an AutoGen
+Definitions (see http://autogen.sf.net) file that captures the structure of
+the code including all documentation. Note that this feature is still
+experimental and incomplete at the moment.</source>
+        <translation>GENERATE_AUTOGEN_DEF に YES を与えると doxygen は Autogen 定義ファイルを生成します。 http://autogen.sf.net を参照ください。
+Autogen 定義ファイルは全ての文書を含んだコード構造を記録します。
+
+当機能は実験段階です。現時点では完成しておりません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3610"/>
+        <source>If the GENERATE_PERLMOD tag is set to YES doxygen will generate a Perl module
+file that captures the structure of the code including all documentation.
+
+Note that this feature is still experimental and incomplete at the moment.</source>
+        <translation>GENERATE_PERLMOD に YES を与えると Perl モジュールファイルを生成するようになります。
+Perl モジュールファイルは全ての文書を含んだコード構造を記録します。
+
+当機能は実験段階です。現時点では完成しておりません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3616"/>
+        <source>If the PERLMOD_LATEX tag is set to YES doxygen will generate the necessary
+Makefile rules, Perl scripts and LaTeX code to be able to generate PDF and DVI
+output from the Perl module output.</source>
+        <translation>PERLMOD_LATEX に YES を与えると必要な Makefile 規則を生成します。
+Perl スクリプト と LaTeX コード により、Perl モジュールの出力から PDF および DVI 出力を得ることができます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3621"/>
+        <source>If the PERLMOD_PRETTY tag is set to YES the Perl module output will be nicely
+formatted so it can be parsed by a human reader. This is useful if you want to
+understand what is going on. On the other hand, if this tag is set to NO the
+size of the Perl module output will be much smaller and Perl will parse it
+just the same.</source>
+        <translatorcomment>最後の行がやや意味不明か。</translatorcomment>
+        <translation>PERLMOD_PRETTY に YES を与えると Perl モジュール出力が適度に整形され、人が読んでもわかりやすい状態になります。
+実際の動作を知りたい場合に用いることができます。
+NO を与えた場合は Perl モジュール出力が小さくなり Perl は同じものとして解析します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3638"/>
+        <source>If the MACRO_EXPANSION tag is set to YES doxygen will expand all macro names
+in the source code. If set to NO only conditional compilation will be
+performed. Macro expansion can be done in a controlled way by setting
+EXPAND_ONLY_PREDEF to YES.</source>
+        <translation>MACRO_EXPANSION に YES を与えると スコープコードの中ですべてのマクロ名を展開します。
+NO の場合は条件判断のみを処理します。
+マクロ展開は MACRO_EXPANSION に YES を与えて動作を制御することができます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3644"/>
+        <source>If the EXPAND_ONLY_PREDEF and MACRO_EXPANSION tags are both set to YES then
+the macro expansion is limited to the macros specified with the PREDEFINED and
+EXPAND_AS_DEFINED tags.</source>
+        <translation>EXPAND_ONLY_PREDEF と MACRO_EXPANSION の両方に YES を与えると PREDEFINED と EXPAND_AS_DEFINED に指示したもののみマクロ展開を行います。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3649"/>
+        <source>If the SEARCH_INCLUDES tag is set to YES the includes files in the
+INCLUDE_PATH will be searched if a #include is found.</source>
+        <translation>SEARCH_INCLUDES に YES を与えると #include に対して INCLUDE_PATH にある include ファイルを検索します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3653"/>
+        <source>The INCLUDE_PATH tag can be used to specify one or more directories that
+contain include files that are not input files but should be processed by the
+preprocessor.</source>
+        <translation>入力には含まれませんがプリプロセッサでは処理してほしいファイルの格納先は INCLUDE_PATH でご指定ください。複数、またディレクトリでの指定もできます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3658"/>
+        <source>You can use the INCLUDE_FILE_PATTERNS tag to specify one or more wildcard
+patterns (like *.h and *.hpp) to filter out the header-files in the
+directories. If left blank, the patterns specified with FILE_PATTERNS will be
+used.</source>
+        <translation>INcLUDE_PATh ディレクトリにあるヘッダファイルを選別するために、ワイルドカードを用いた *.h, *.hpp といった任意数のフィルタを INCLUDE_FILE_PATTERNS に指定できます。指定がない場合は FILE_PATTERS の内容が用いられます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3664"/>
+        <source>The PREDEFINED tag can be used to specify one or more macro names that are
+defined before the preprocessor is started (similar to the -D option of e.g.
+gcc). The argument of the tag is a list of macros of the form: name or
+name=definition (no spaces). If the definition and the &quot;=&quot; are omitted, &quot;=1&quot;
+is assumed. To prevent a macro definition from being undefined via #undef or
+recursively expanded use the := operator instead of the = operator.</source>
+        <translation>プリプロセッサに事前に評価をすべきマクロは PREDEFINED に定義できます。 gcc などの -D オプションと同様の機能です。
+名前だけ、もしくは名前と定義の組(マクロ名=定義、余分な空白を入れないこと)を任意数並べて指定できます。名前だけが指定されている場合は &apos;=1&apos; が定義に使われたものとみなします。
+#undef や再帰展開により未定義状態にされるのを防ぐには = の代わりに := 演算子を使ってください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3672"/>
+        <source>If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then this
+tag can be used to specify a list of macro names that should be expanded. The
+macro definition that is found in the sources will be used. Use the PREDEFINED
+tag if you want to use a different macro definition that overrules the
+definition found in the source code.</source>
+        <translation>MACRO_EXPANSION および EXPAND_ONLY_PREDEF の両方が YES の時に限り EXPAND_AS_DEFINED に展開すべきマクロ名の一覧を与えることができます。
+ソースコードにあったマクロ定義のうちここで与えたものが使われます。ソースコード上の定義を上書きしたい場合はこのタグではなく PREDEFINED タグを用いてください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3679"/>
+        <source>If the SKIP_FUNCTION_MACROS tag is set to YES then doxygen&apos;s preprocessor will
+remove all refrences to function-like macros that are alone on a line, have an
+all uppercase name, and do not end with a semicolon. Such function macros are
+typically used for boiler-plate code, and will confuse the parser if not
+removed.</source>
+        <translation>SKIP_FUNCTION_MACROS に YES を与えると doxygen プリプロセッサは特定の関数形マクロへの参照を取り除くようになります。一行で定義されているもの、すべてが大文字のもの、セミコロンで終わっていないものが対象です。これらの多くは定番の慣習とじゃ使われるもの(boiler-plate code)であり、doxygenの解析器を混乱させる元となります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3686"/>
+        <source>The TAGFILES tag can be used to specify one or more tag files. For each tag
+file the location of the external documentation should be added. The format of
+a tag file without this location is as follows:
+TAGFILES = file1 file2 ...
+Adding location for the tag files is done as follows:
+TAGFILES = file1=loc1 &quot;file2 = loc2&quot; ...
+where loc1 and loc2 can be relative or absolute paths or URLs. See the
+section &quot;Linking to external documentation&quot; for more information about the use
+of tag files.
+Note: Each tag file must have an unique name (where the name does NOT include
+the path). If a tag file is not located in the directory in which doxygen is
+run, you must also specify the path to the tagfile here.</source>
+        <translation>TAGFILES にはタグファイルを任意数与えることができます。タグファイルごとに対応する外部文書の位置を追加すべきです。この位置を伴わないタグファイルの書式は次の通りです:
+TAGFILES = ファイル1 ファイル2 …
+タグファイルに位置を追加する書式は次のようになります:
+TAGFILES = ファイル1=場所1 &quot;ファイル2 = 場所2&apos; …
+場所1, 場所2 には絶対パス・相対パス・URL が使えます。タグファイルの詳細は &quot;Linking to external documentation&quot; を参照ください。
+注意: タグファイルの名前は重複を認められていません(パスが異なるものでも認められません)。対応ディレクトリにタグファイルがない場合は常にタグファイルに対するパスを指定する必要があります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3700"/>
+        <source>When a file name is specified after GENERATE_TAGFILE, doxygen will create a
+tag file that is based on the input files it reads. See section &quot;Linking to
+external documentation&quot; for more information about the usage of tag files.</source>
+        <translation>GENERATE_TAGFILE にファイル名を与えておくと、doxygen は入力を元に指定名でタグファイルを出力します。タグファイルの詳細は &quot;Linking to external documentation&quot; をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3705"/>
+        <source>If the ALLEXTERNALS tag is set to YES all external class will be listed in the
+class index. If set to NO only the inherited external classes will be listed.</source>
+        <translation>ALLEXTERNALS に YES を与えると外部クラスの全てがクラス索引に載せられます。 NO の場合は継承された外部クラスのみを索引に入れます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3709"/>
+        <source>If the EXTERNAL_GROUPS tag is set to YES all external groups will be listed in
+the modules index. If set to NO, only the current project&apos;s groups will be
+listed.</source>
+        <translation>EXTERNAL_GROUPS に YES を与えるとすべての外部グループがモジュール索引に載せられます。 NO の場合は入力から直接読み取ったグループのみが索引に入ります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3714"/>
+        <source>If the EXTERNAL_PAGES tag is set to YES all external pages will be listed in
+the related pages index. If set to NO, only the current project&apos;s pages will
+be listed.</source>
+        <translation>EXTERNAL_PAGES に YES を与えるとすべての外部ページが関連ページ索引に含まれます。 NO にすると入力から直接読み取ったページのみが索引に入ります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3719"/>
+        <source>The PERL_PATH should be the absolute path and name of the perl script
+interpreter (i.e. the result of &apos;which perl&apos;).</source>
+        <translation>PERL_PATH は perl スクリプトインタープリタへの絶対パスを与えるべきです。 &apos;which perl&apos; を実行できるのであればその結果を与えてください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3723"/>
+        <source>If the CLASS_DIAGRAMS tag is set to YES doxygen will generate a class diagram
+(in HTML and LaTeX) for classes with base or super classes. Setting the tag to
+NO turns the diagrams off. Note that this option also works with HAVE_DOT
+disabled, but it is recommended to install and use dot, since it yields more
+powerful graphs.</source>
+        <translation>CLASS_DIAGRAMS に YES を与えると HTML と LaTeX において基底クラスおよび継承クラスについての関係図を生成するようになります。
+NO を与えた場合はこの関係図を出力しません。 HAVE_DOT が無効でも動作できますが、よりしっかりした図を作成できる GraphViz/dot を設置、利用することをお勧めします。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3730"/>
+        <source>You can define message sequence charts within doxygen comments using the \msc
+command. Doxygen will then run the mscgen tool (see:
+http://www.mcternan.me.uk/mscgen/)) to produce the chart and insert it in the
+documentation. The MSCGEN_PATH tag allows you to specify the directory where
+the mscgen tool resides. If left empty the tool is assumed to be found in the
+default search path.</source>
+        <translation>doxygen では、\msc コマンドを使ったメッセージによる順接相関図(MSC, message sequence charts)を定義できます。
+doxygen は自動的に mscgen ツール http://www.mcternan.me.uk/mscgen/ を呼び出して相関図を生成し、これを出力文書に挿入します。
+
+MSCGEN_PATH には mscgen ツールの所在ディレクトリをご指定ください。空のままの場合は既存の検索パスにあるものと仮定します。
+</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3738"/>
+        <source>You can include diagrams made with dia in doxygen documentation. Doxygen will
+then run dia to produce the diagram and insert it in the documentation. The
+DIA_PATH tag allows you to specify the directory where the dia binary resides.
+If left empty dia is assumed to be found in the default search path.</source>
+        <translation>DIA_PATH には dia の実行ファイルがあるディレクトリをご指定ください。
+空のままにしている場合は規定の検索パスに dia があるものとみなします。
+
+関係図を dia ツールで作成して doxygen の出力文書に含めることができます。
+doxygen 本体から必要なだけ dia を呼び出し、生成された関係図は自動的に文書に挿入されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3744"/>
+        <source>If set to YES, the inheritance and collaboration graphs will hide inheritance
+and usage relations if the target is undocumented or is not a class.</source>
+        <translation>HIDE_UNDOC_RELATIONS に YES が与えられていると、継承・連携の相手先に文書がない、もしくは相手先がクラスではない場合に継承・連携図にそれらが記載されなくなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3748"/>
+        <source>If you set the HAVE_DOT tag to YES then doxygen will assume the dot tool is
+available from the path. This tool is part of Graphviz (see:
+http://www.graphviz.org/), a graph visualization toolkit from AT&amp;T and Lucent
+Bell Labs. The other options in this section have no effect if this option is
+set to NO.</source>
+        <oldsource>If you set the HAVE_DOT tag to YES then doxygen will assume the dot tool is
+available from the path. This tool is part of Graphviz (see:
+http://www.graphviz.org/), a graph visualization toolkit from AT&amp;T and Lucent
+Bell Labs. The other options in this section have no effect if this option is
+set to NO</oldsource>
+        <translation>HAVE_DOT に YES を与えると GraphViz/dot ツール http://www.graphviz.org/ が既存の実行パスから利用可能であると仮定して動作します。
+GraphViz は AT&amp;T と Lucent Bell 研究所によるグラフ可視化ツールキットです。
+NO を与えると(説明書の)この節にある他のオプションは一切無効となります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3755"/>
+        <source>The DOT_NUM_THREADS specifies the number of dot invocations doxygen is allowed
+to run in parallel. When set to 0 doxygen will base this on the number of
+processors available in the system. You can set it explicitly to a value
+larger than 0 to get control over the balance between CPU load and processing
+speed.</source>
+        <translation>DOT_NUM_THREADS には dot ツールの平行呼び出し可能数をご指定ください。
+0 を与えると、システム情報から得られるプロセッサ数をもとにこの値を自動判断します。 0 以外の値により CPU 負荷と処理速度の釣り合いを調整することができます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3762"/>
+        <source>When you want a differently looking font n the dot files that doxygen
+generates you can specify the font name using DOT_FONTNAME. You need to make
+sure dot is able to find the font, which can be done by putting it in a
+standard location or by setting the DOTFONTPATH environment variable or by
+setting DOT_FONTPATH to the directory containing the font.</source>
+        <translation>DOT_FONTNAME に書体名を与えると、doxygen から dot ファイルを生成するときに指定する書体を変更できます。指定書体は GraphViz/dot ツール自身が検索できるように、標準の位置に配置しておくか、環境変数 DOTFONTPATH もしくは設定 DOT_FONTPATH に指定書体が配置されているディレクトリを与えておいてください。
+
+訳注: 訳出時点では dot ツール側の問題で書体名に日本語を使うことができません。日本語用の ttf ファイルには日本語名と英語名の両方が記録されているはずですので、この英語名の方をご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3769"/>
+        <source>The DOT_FONTSIZE tag can be used to set the size (in points) of the font of
+dot graphs.</source>
+        <translation>DOT_FONTSIZE には dot による出力で使われる書体の大きさをポイント単位で指定できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3778"/>
+        <source>If the CLASS_GRAPH tag is set to YES then doxygen will generate a graph for
+each documented class showing the direct and indirect inheritance relations.
+Setting this tag to YES will force the CLASS_DIAGRAMS tag to NO.</source>
+        <translation>GROUP_GRAPHS に YES を与えるとクラス文書ごとに継承関係を表す関係図を生成します。継承関係は間接的なものも含みます。また YES を与えた場合は CLASS_DIAGRAMS が自動的に NO の扱いとなります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3789"/>
+        <source>If the GROUP_GRAPHS tag is set to YES then doxygen will generate a graph for
+groups, showing the direct groups dependencies.</source>
+        <translation>GROUP_GRAPHS に YES を与えるとグループに対して直接的なグループ依存に関する関係図を生成するようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3793"/>
+        <source>If the UML_LOOK tag is set to YES doxygen will generate inheritance and
+collaboration diagrams in a style similar to the OMG&apos;s Unified Modeling
+Language.</source>
+        <translation>UML_LOOK に YES を与えると継承・連携図は OMG の Unified Modeling Language(UML) の様式に合わせた出力になります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3798"/>
+        <source>If the UML_LOOK tag is enabled, the fields and methods are shown inside the
+class node. If there are many fields or methods and many nodes the graph may
+become too big to be useful. The UML_LIMIT_NUM_FIELDS threshold limits the
+number of items for each type to make the size more manageable. Set this to 0
+for no limit. Note that the threshold may be exceeded by 50% before the limit
+is enforced. So when you set the threshold to 10, up to 15 fields may appear,
+but if the number exceeds 15, the total amount of fields shown is limited to
+10.</source>
+        <translation>UML_LOOK が YES のときにフィールドとメソッドはクラス節内部に表示されます。フィールドやメソッドが多数あって節部分が肥大化するとあまり実用的でなくなることがあります。
+実用的な大きさにする目的で UML_LIMIT_NUM_FIELDS には型単位の項目数について閾値を指定できます。 0 のときは制限がかかりません。
+指定値の 150% までは制限がかからないことにご注意ください。たとえば 10 を与えると、15項目まで現れることがあります。15 を超えてしまうと、表示される項目数が 10 に抑えられます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3808"/>
+        <source>If the TEMPLATE_RELATIONS tag is set to YES then the inheritance and
+collaboration graphs will show the relations between templates and their
+instances.</source>
+        <translation>TEMPLATE_RELATIONS に YES を与えると、テンプレートとその実体化の関係も継承図や連携図に記されるようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3813"/>
+        <source>If the INCLUDE_GRAPH, ENABLE_PREPROCESSING and SEARCH_INCLUDES tags are set to
+YES then doxygen will generate a graph for each documented file showing the
+direct and indirect include dependencies of the file with other documented
+files.</source>
+        <translation>INCLUDE_GRAPH, ENABLE_PREPROCESSING, SEARCH_INCLUDES の全てに YES を与えると、各詳解ファイルからその元となったファイルが依存している他のファイルを示した官・図を出力するようになります。間接的に依存するものも含まれます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3819"/>
+        <source>If the INCLUDED_BY_GRAPH, ENABLE_PREPROCESSING and SEARCH_INCLUDES tags are
+set to YES then doxygen will generate a graph for each documented file showing
+the direct and indirect include dependencies of the file with other documented
+files.</source>
+        <translation>INCLUDED_BY_GRAPH, ENABLE_PREPROCESSING, SEARCH_INCLUDES の全てに YES を与えると、各詳解ファイルからその元となったファイルに依存している他のファイルを示した官・図を出力するようになります。間接的に依存しているものも含まれます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3825"/>
+        <source>If the CALL_GRAPH tag is set to YES then doxygen will generate a call
+dependency graph for every global function or class method.
+
+Note that enabling this option will significantly increase the time of a run.
+So in most cases it will be better to enable call graphs for selected
+functions only using the \callgraph command.</source>
+        <translation>CALL_GRAPH に YES を与えると各関数等の説明にそこから呼び出している関数等を示した図を出力するようになります。
+
+注意: YES にすると出力にかかる時間が明らかに長くなります。多くの場合は \callgraph コマンドを用いて特定の関数にのみこの図を出力させるのが良いでしょう。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3833"/>
+        <source>If the CALLER_GRAPH tag is set to YES then doxygen will generate a caller
+dependency graph for every global function or class method.
+
+Note that enabling this option will significantly increase the time of a run.
+So in most cases it will be better to enable caller graphs for selected
+functions only using the \callergraph command.</source>
+        <translation>CALLER_GRAPH に YES を与えると各関数等の説明にそれを呼び出している関数等を示した図を出力するようになります。
+
+注意: YES にすると出力にかかる時間が明らかに長くなります。多くの場合は \callergraph コマンドを用いて特定の関数にのみこの図を出力させるのが良いでしょう。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3841"/>
+        <source>If the GRAPHICAL_HIERARCHY tag is set to YES then doxygen will graphical
+hierarchy of all classes instead of a textual one.</source>
+        <translation>GRAPHICAL_HIERARCHY に YES を与えると文字ではなく画像による方法でクラス階層を出力するようになります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3845"/>
+        <source>If the DIRECTORY_GRAPH tag is set to YES then doxygen will show the
+dependencies a directory has on other directories in a graphical way. The
+dependency relations are determined by the #include relations between the
+files in the directories.</source>
+        <translation>DIRECTORY_GRAPH に YES を与えるとディレクトリ同志の依存関係を視覚的に出力するようになります。ディレクトリ同士の依存関係は各ディレクトリの各ファイルが使う #include の内容で決まります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3851"/>
+        <source>The DOT_IMAGE_FORMAT tag can be used to set the image format of the images
+generated by dot.
+Note: If you choose svg you need to set HTML_FILE_EXTENSION to xhtml in order
+to make the SVG files visible in IE 9+ (other browsers do not have this
+requirement).</source>
+        <translation>dot が生成すべき画像形式は DOT_IMAGE_FORMAT で指定できます。
+注意: svg を指定した場合は HTML_FILE_EXTENSION に xhtml を指定して IE 9 以降でそれを見られるようにする必要があります。他のブラウザにはこのような制限がありません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3858"/>
+        <source>If DOT_IMAGE_FORMAT is set to svg, then this option can be set to YES to
+enable generation of interactive SVG images that allow zooming and panning.
+
+Note that this requires a modern browser other than Internet Explorer. Tested
+and working are Firefox, Chrome, Safari, and Opera.
+Note: For IE 9+ you need to set HTML_FILE_EXTENSION to xhtml in order to make
+the SVG files visible. Older versions of IE do not have SVG support.</source>
+        <translation>DOT_IMAGE_FORMAT に svg を指定している場合、 INTERACTIVE_SVG に YES を与えると「操作可能な SVG 画像ファイル」を生成できます。拡大縮小および上下左右への移動ができるようになります。
+
+注意: この機能は Internet Explorer 以外の比較的新しいブラウザが必要となります。Firefox, Chrome, Safari, Opera での動作は確認されています。
+注意: IE 9 以降に対しては HTML_FILE_EXTENSION に xhtml を指定すると SVG が見られるようになります。それ以前の IE で SVG を見ることはできません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3867"/>
+        <source>The DOT_PATH tag can be used to specify the path where the dot tool can be
+found. If left blank, it is assumed the dot tool can be found in the path.</source>
+        <translation>GraphViz/dot の所在は DOT_PATH でご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3871"/>
+        <source>The DOTFILE_DIRS tag can be used to specify one or more directories that
+contain dot files that are included in the documentation (see the \dotfile
+command).</source>
+        <translation>\dotfile コマンドによる dot ファイルの場所を DOTFILE_DIRS に指示できます。任意数のディレクトリが指定可能です。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3876"/>
+        <source>The MSCFILE_DIRS tag can be used to specify one or more directories that
+contain msc files that are included in the documentation (see the \mscfile
+command).</source>
+        <translation>\mscfile コマンドによる msc ファイルの場所を MSCFILE_DIRS に指示できます。任意数のディレクトリが指定可能です。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3881"/>
+        <source>The DIAFILE_DIRS tag can be used to specify one or more directories that
+contain dia files that are included in the documentation (see the \diafile
+command).</source>
+        <translation>DIAFILE_DIRS には作成済み dia ファイルがあるディレクトリを任意数指定できます。
+\diafile コマンドを参照ください。
+</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3886"/>
+        <source>The DOT_GRAPH_MAX_NODES tag can be used to set the maximum number of nodes
+that will be shown in the graph. If the number of nodes in a graph becomes
+larger than this value, doxygen will truncate the graph, which is visualized
+by representing a node as a red box. Note that doxygen if the number of direct
+children of the root node in a graph is already larger than
+DOT_GRAPH_MAX_NODES then the graph will not be shown at all. Also note that
+the size of a graph can be further restricted by MAX_DOT_GRAPH_DEPTH.</source>
+        <translation>DOT_GRAPH_MAX_NODES には図一枚あたりの節表示数を最大値で指定できます。図面ひとつに対して節の数が指定値に達すると、先に続きのある箱は赤で表示されるだけになります。
+図の根本に直接つながる節が最初から指定値を超えている場合、図が空になるのでご注意ください。
+図の大きさは MAX_DOT_GRAPH_DEPTH によっても制限を与えることができます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3895"/>
+        <source>The MAX_DOT_GRAPH_DEPTH tag can be used to set the maximum depth of the graphs
+generated by dot. A depth value of 3 means that only nodes reachable from the
+root by following a path via at most 3 edges will be shown. Nodes that lay
+further from the root node will be omitted. Note that setting this option to 1
+or 2 may greatly reduce the computation time needed for large code bases. Also
+note that the size of a graph can be further restricted by
+DOT_GRAPH_MAX_NODES. Using a depth of 0 means no depth restriction.</source>
+        <translation>MAX_DOT_GRAPH_DEPTH には dot が生成する図の最大深さを指定できます。たとえばここに 3 を与えると図の根本から三手以内でたどり着ける端子・節のみを集めた図が作られます。特に 1 や 2 を指定した場合は大きな入力に対して効果的な時間の短縮できる可能性があります。0 を与えると深さ面での制限はなくなります。
+全体図の大きさは DOT_GRAPH_MAX_NODES によっても(訳注: 深さとは独立して節の数により)制限されます。
+</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3904"/>
+        <source>Set the DOT_TRANSPARENT tag to YES to generate images with a transparent
+background. This is disabled by default, because dot on Windows does not seem
+to support this out of the box.
+
+Warning: Depending on the platform used, enabling this option may lead to
+badly anti-aliased labels on the edges of a graph (i.e. they become hard to
+read).</source>
+        <translation>DOT_TRANSPARENT に YES を与えると dot が生成する画像の背景が透明色になります。Windows 用の dot が箱外の透明化に未対応のようなので省略時の設定は NO になっています。
+
+警告: 実行している環境によっては各図形の端に読み取り困難なほどの低質な補完処理が加わることがあります。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3913"/>
+        <source>Set the DOT_MULTI_TARGETS tag to YES allow dot to generate multiple output
+files in one run (i.e. multiple -o and -T options on the command line). This
+makes dot run faster, but since only newer versions of dot (&gt;1.8.10) support
+this, this feature is disabled by default.</source>
+        <translation>DOT_MULTI_TARGETS に YES を与えると一回の実行で複数ファイルの生成を行うよう dot ツールに指示します。dot を起動する際に複数の -o および -T オプションが用いられます。
+これにより処理が早くなりますが、dot 自体が新しいもの(1.8.10 より後)でなくてはなりません。省略地・初期値は NO です。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3919"/>
+        <source>If the GENERATE_LEGEND tag is set to YES doxygen will generate a legend page
+explaining the meaning of the various boxes and arrows in the dot generated
+graphs.</source>
+        <translation>GENERATE_LEGEND に YES を与えると関係図の凡例を示すページも出力されるようになります。この凡例ページは箱や矢印の意味を説明します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3924"/>
+        <source>If the DOT_CLEANUP tag is set to YES doxygen will remove the intermediate dot
+files that are used to generate the various graphs.</source>
+        <translation>DOT_CLEANUP に YES を与えると各種グラフ画像生成に用いた中間 dot ファイルを自動的に消去します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3180"/>
+        <source>The CHM_FILE tag can be used to specify the file name of the resulting .chm
+file. You can add a path in front of the file if the result should not be
+written to the html output directory.</source>
+        <translation>CHM_FILE に最終出力となる .chm ファイルの名前を指定できます。パスを含めることで HTML 出力ディレクトリ以外を指定できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2666"/>
+        <source>If the SORT_BRIEF_DOCS tag is set to YES then doxygen will sort the brief
+descriptions of file, namespace and class members alphabetically by member
+name. If set to NO the members will appear in declaration order. Note that
+this will also influence the order of the classes in the class list.</source>
+        <translation>SORT_BRIEF_DOCS に YES を与えると概要文をメンバ名順に並べ替えます。 NO の場合は宣言順で出力されます。
+名前空間やクラス内のメンバだけでなく、クラス一覧におけるクラスの並びもこの指定に従います。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2869"/>
+        <source>The EXCLUDE_SYMBOLS tag can be used to specify one or more symbol names
+(namespaces, classes, functions, etc.) that should be excluded from the
+output. The symbol name can be a fully qualified name, a word, or if the
+wildcard * is used, a substring. Examples: ANamespace, AClass,
+AClass::ANamespace, ANamespace::*Test</source>
+        <translation>EXCLUDE_SYMBOLS には出力から除外する名称を指定できます。ここで言う名称とは名前空間・クラス・関数などの名前です。完全名、一単語、あるいはワイルドカード * を用いた文字列が使えます。
+例) ANamespace, AClass, AClass::ANamespace, ANamespace::*Test</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3202"/>
+        <source>The TOC_EXPAND flag can be set to YES to add extra items for group members to
+the table of contents of the HTML help documentation and to the tree view.</source>
+        <translation>TOC_EXPAND に YES を与えると HTML ヘルプ型の文書およびツリービューの目次に、グループメンバへの項目が追加されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3212"/>
+        <source>If the QHG_LOCATION tag is specified, the QCH_FILE tag can be used to specify
+the file name of the resulting .qch file. The path specified is relative to
+the HTML output folder.</source>
+        <translation>QHG_LOCATION にパスが設定されてると QCH_FILE に最終的な .qch ファイルの置き場所を指定できるようになります。相対パスの場合は HTML の出力フォルダを基準に解析されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3417"/>
+        <source>If the GENERATE_LATEX tag is set to YES doxygen will generate LaTeX output.</source>
+        <translation>LaTeX の出力を得る時は GENERATE_LATEX に YES をご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3467"/>
+        <source>The LATEX_FOOTER tag can be used to specify a personal LaTeX footer for the
+generated LaTeX document. The footer should contain everything after the last
+chapter. If it is left blank doxygen will generate a standard footer.
+
+Note: Only use a user-defined footer if you know what you are doing.</source>
+        <translation>LATEX_FOOTER には独自の LaTeX 用下見出しを指定できます。
+下見出しは最後の章の後に来るべきすべてを含めてください。指定がなければ doxygen 内蔵の標準下見出しを使います。
+
+注意: 何をしているのか理解されている場合だけこの機能をご利用ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3491"/>
+        <source>If the LATEX_BATCHMODE tag is set to YES, doxygen will add the \batchmode
+command to the generated LaTeX files. This will instruct LaTeX to keep running
+if errors occur, instead of asking the user for help. This option is also used
+when generating formulas in HTML.</source>
+        <translation>LATEX_BATCHMODE に YES を与えると、出力する LaTeX ファイルに \batchmode コマンドを追加します。
+これにより LaTeX 側でエラーが発生してもユーザーへの問い合わせ発生の代わりに動作を続けるようになります。
+この機能は HTML 用に式を生成するときにも使われます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3508"/>
+        <source>The LATEX_BIB_STYLE tag can be used to specify the style to use for the
+bibliography, e.g. plainnat, or ieeetr. See
+http://en.wikipedia.org/wiki/BibTeX and \cite for more info.</source>
+        <translation>LATEX_BIB_STYLE を使うと、参考文献に対して plainnat や ieeetr といった書式を指定できます。詳細については http://en.wikipedia.org/wiki/BibTeX や \cite の説明をご覧ください。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3513"/>
+        <source>If the GENERATE_RTF tag is set to YES doxygen will generate RTF output. The
+RTF output is optimized for Word 97 and may not look too pretty with other RTF
+readers/editors.</source>
+        <translation>RTF ファイルを生成するには GENERATE_RTF に YES を与えてください。なお、出力は Word 97 に最適化されます。他の RTF リーダやエディタで有効な高機能は付加されません。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3585"/>
+        <source>The XML_DTD tag can be used to specify a XML DTD, which can be used by a
+validating XML parser to check the syntax of the XML files.</source>
+        <translation>XML_DTD は文字通り XML DTD を指定するときに使います。XMLパーサによる出力書式の検証で用いられます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3628"/>
+        <source>The names of the make variables in the generated doxyrules.make file are
+prefixed with the string contained in PERLMOD_MAKEVAR_PREFIX. This is useful
+so different doxyrules.make files included by the same Makefile don&apos;t
+overwrite each other&apos;s variables.</source>
+        <translation>生成された doxyrule における make 変数の名前には PERLMOD_MAKEVAR_PREFIX に含まれる文字列が先行します。
+単一の Makefile に複数の doxyrule が混用されるときにそれらを区別する目的で利用できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3634"/>
+        <source>If the ENABLE_PREPROCESSING tag is set to YES doxygen will evaluate all
+C-preprocessor directives found in the sources and include files.</source>
+        <translation>ENABLE_PREPROCESSING に YES を与えると C言語のソースコードにあるプリプロセッサディレクティブ全てを評価します。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3773"/>
+        <source>By default doxygen will tell dot to use the default font as specified with
+DOT_FONTNAME. If you specify a different font using DOT_FONTNAME you can set
+the path where dot can find it using this tag.</source>
+        <translation>GraphViz/dot が使うべき書体は DOT_FONTNAME に指定されたものが伝えられます。これに加えて DOT_FONTPATH はその書体がどこにあるかのパスを指定できます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="3783"/>
+        <source>If the COLLABORATION_GRAPH tag is set to YES then doxygen will generate a
+graph for each documented class showing the direct and indirect implementation
+dependencies (inheritance, containment, and class references variables) of the
+class with other documented classes.</source>
+        <translation>COLLABORATION_GRAPH に YES を与えると、文書化されたクラスごとに実装の依存関係を示した図を生成します。
+
+依存関係は直接的なものも間接的なものも含み、依存関係には継承・包含・参照している変数などが含まれます。別途暮らす文書があるものについて生成されます。</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2366"/>
+        <source>The STRIP_FROM_PATH tag can be used to strip a user-defined part of the path.
+Stripping is only done if one of the specified strings matches the left-hand
+part of the path. The tag can be used to show relative paths in the file list.
+If left blank the directory from which doxygen is run is used as the path to
+strip.
+
+Note that you can specify absolute paths here, but also relative paths, which
+will be relative from the directory where doxygen is started.</source>
+        <translation>STRIP_FROM_PATH には出力におけるパスのうち省略する部分を指定できます。
+指定された文字列が各パスの左端と一致したときのみ省略が実行されます。
+絶対パス・相対パス共にご利用になれます。相対パスは doxygen が呼び出されたディレクトリを基準に解析します。
+指定がなかった場合は doxygen を実行したパスがそのまま用いられます。
+</translation>
+    </message>
+    <message>
+        <location filename="configdoc.cpp" line="2838"/>
+        <source>If the value of the INPUT tag contains directories, you can use the
+FILE_PATTERNS tag to specify one or more wildcard patterns (like *.cpp and
+*.h) to filter out the source-files in the directories. If left blank the
+following patterns are tested:</source>
+        <translation>INPUT にディレクトリ群を与えているのであれば FILE_PATTERNS に *.cpp や *.h といったワイルドカードを指定できます。
+文を抽出するファイルを限定できます。指定がなければ既定の下記パターンに該当するファイルが検索されます:</translation>
+    </message>
+</context>
+<context>
+    <name>Expert</name>
+    <message>
+        <location filename="expert.cpp" line="63"/>
+        <source>Error parsing internal config.xml at line %1 column %2.
+%3</source>
+        <translation>内部の config.xml が %1 行 %2 桁目に問題を含んでいました。
+%3</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="65"/>
+        <source>Error</source>
+        <translation>問題発生</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="84"/>
+        <source>Previous</source>
+        <translation>一つ前</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="86"/>
+        <source>Next</source>
+        <translation>一つ次</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="129"/>
+        <source>Topics</source>
+        <translation>項目</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="169"/>
+        <source> %1</source>
+        <comment>for possible value list</comment>
+        <translation> %1</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="173"/>
+        <source> and </source>
+        <comment>for possible value list</comment>
+        <translation> 、 </translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="177"/>
+        <source>.</source>
+        <comment>for possible value list</comment>
+        <translation> です。</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="181"/>
+        <source>, </source>
+        <comment>for possible value list</comment>
+        <translation> 、 </translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="186"/>
+        <source>Possible values are: %1</source>
+        <translation>指定可能値は %1</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="189"/>
+        <location filename="expert.cpp" line="211"/>
+        <location filename="expert.cpp" line="319"/>
+        <source> The default value is: &lt;code&gt;%1&lt;/code&gt;.</source>
+        <translation> 省略値/初期値は &lt;code&gt;%1&lt;/code&gt; です。</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="195"/>
+        <source>Minimum value: %1, maximum value: %2, default value: %3</source>
+        <translation>省略値・初期値: %3 / 値の範囲: %1-%2</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="206"/>
+        <source> The default value is: system dependent.</source>
+        <translation> 省略値/初期値は実機依存です。</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="254"/>
+        <source> %1</source>
+        <comment>for documented list</comment>
+        <translation> %1</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="258"/>
+        <source> and </source>
+        <comment>for documented list</comment>
+        <translation>, </translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="262"/>
+        <source>.</source>
+        <comment>for documented list</comment>
+        <translation>.</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="266"/>
+        <source>, </source>
+        <comment>for documented list</comment>
+        <translation>,  </translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="284"/>
+        <source> The default directory is: &lt;code&gt;%1&lt;/code&gt;.</source>
+        <translation> 省略時のディレクトリは &lt;code&gt;%1&lt;/code&gt; です。</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="296"/>
+        <source> The default file is: &lt;code&gt;%1&lt;/code&gt;.</source>
+        <translation> 省略時のファイルは &lt;code&gt;%1&lt;/code&gt; です。</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="300"/>
+        <source> The default file (with absolute path) is: &lt;code&gt;%1&lt;/code&gt;.</source>
+        <translation> 省略時の完全ファイルパスは &lt;code&gt;%1&lt;/code&gt; です。</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="309"/>
+        <source> The file has to be specified with full path.</source>
+        <translation> ファイルは完全パスでご指定ください。</translation>
+    </message>
+    <message>
+        <location filename="expert.cpp" line="329"/>
+        <source> This tag requires that the tag \ref cfg_%1 &quot;%2&quot; is set to &lt;code&gt;YES&lt;/code&gt;.</source>
+        <translation> この機能は \ref cfg_%1 &quot;%2&quot; が &lt;code&gt;YES&lt;/code&gt; のときのみ有効です。</translation>
+    </message>
+</context>
+<context>
+    <name>HelpLabel</name>
+    <message>
+        <location filename="helplabel.h" line="23"/>
+        <source>Reset to default</source>
+        <translation>初期設定に戻す</translation>
+    </message>
+</context>
+<context>
+    <name>InputStrList</name>
+    <message>
+        <location filename="inputstrlist.cpp" line="37"/>
+        <source>Add item</source>
+        <translation>項目を追加</translation>
+    </message>
+    <message>
+        <location filename="inputstrlist.cpp" line="40"/>
+        <source>Delete selected item</source>
+        <translation>選択項目を削除</translation>
+    </message>
+    <message>
+        <location filename="inputstrlist.cpp" line="43"/>
+        <source>Update selected item</source>
+        <translation>選択項目を更新</translation>
+    </message>
+    <message>
+        <location filename="inputstrlist.cpp" line="57"/>
+        <source>Browse to a file</source>
+        <translation>ファイルを選択</translation>
+    </message>
+    <message>
+        <location filename="inputstrlist.cpp" line="63"/>
+        <source>Browse to a folder</source>
+        <translation>フォルダを選択</translation>
+    </message>
+</context>
+<context>
+    <name>InputString</name>
+    <message>
+        <location filename="inputstring.cpp" line="63"/>
+        <source>Browse to a file</source>
+        <translation>ファイルを選択</translation>
+    </message>
+    <message>
+        <location filename="inputstring.cpp" line="68"/>
+        <source>Browse to a folder</source>
+        <translatorcomment>単語をフォルダからディレクトリに一本化。GUIだからフォルダの方がいいかなぁ?</translatorcomment>
+        <translation>ディレクトリを選択</translation>
+    </message>
+    <message>
+        <location filename="inputstring.cpp" line="142"/>
+        <source>Select file</source>
+        <translation>ファイルを選択ください</translation>
+    </message>
+    <message>
+        <location filename="inputstring.cpp" line="156"/>
+        <source>Select directory</source>
+        <translation>ディレクトリを選択ください</translation>
+    </message>
+</context>
+<context>
+    <name>MainWindow</name>
+    <message>
+        <location filename="doxywizard.cpp" line="24"/>
+        <source>&amp;File</source>
+        <translation>ファイル (&amp;F)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="25"/>
+        <source>&amp;Open...</source>
+        <translation>開く (&amp;O)…</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="27"/>
+        <source>Open &amp;recent</source>
+        <translation>最近使ったものを開く (&amp;R)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="28"/>
+        <source>&amp;Save</source>
+        <translation>保存 (&amp;S)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="30"/>
+        <source>Save &amp;as...</source>
+        <translation>名前を変えて保存 (&amp;A)…</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="32"/>
+        <source>&amp;Quit</source>
+        <translation>終了 (&amp;Q)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="35"/>
+        <source>&amp;Settings</source>
+        <translation>設定 (&amp;S)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="36"/>
+        <source>&amp;Reset to factory defaults</source>
+        <translation>初期設定に戻す (&amp;R)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="38"/>
+        <source>&amp;Use current settings at startup</source>
+        <translation>現在の内容を起動時設定にする (&amp;U)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="40"/>
+        <source>&amp;Clear recent list</source>
+        <translation>最近使ったものの一覧を消去 (&amp;C)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="43"/>
+        <source>&amp;Help</source>
+        <translation>説明 (&amp;H)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="44"/>
+        <source>&amp;Online manual</source>
+        <translation>説明書 (&amp;O)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="46"/>
+        <source>&amp;About</source>
+        <translation>このソフトウェアについて (&amp;A)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="59"/>
+        <source>Select...</source>
+        <translation>選択…</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="69"/>
+        <location filename="doxywizard.cpp" line="476"/>
+        <location filename="doxywizard.cpp" line="508"/>
+        <source>Run doxygen</source>
+        <translation>Doxygenを実行</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="71"/>
+        <location filename="doxywizard.cpp" line="477"/>
+        <location filename="doxywizard.cpp" line="509"/>
+        <source>Status: not running</source>
+        <translation>状態: 未実行/完了</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="72"/>
+        <source>Save log...</source>
+        <translation>動作記録を保存…</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="74"/>
+        <source>Show configuration</source>
+        <translation>設定の表示</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="83"/>
+        <source>Output produced by doxygen</source>
+        <translation>Doxygenからの出力</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="93"/>
+        <source>Show HTML output</source>
+        <translation>HTML出力を見る</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="101"/>
+        <source>Wizard</source>
+        <translation>簡易設定</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="102"/>
+        <source>Expert</source>
+        <translation>詳細設定</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="103"/>
+        <source>Run</source>
+        <translation>実行</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="105"/>
+        <source>Step 1: Specify the working directory from which doxygen will run</source>
+        <translation>1) Doxygen を実行する作業ディレクトリをご指定ください</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="107"/>
+        <source>Step 2: Configure doxygen using the Wizard and/or Expert tab, then switch to the Run tab to generate the documentation</source>
+        <translation>2) 簡易設定/詳細設定タブの内容を指定し、実行タブで Doxygen を呼び出してください</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="111"/>
+        <source>Welcome to Doxygen</source>
+        <translation>Doxygen の各種設定を行ってください</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="170"/>
+        <source>Select working directory</source>
+        <translation>作業ディレクトリをお選びください</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="196"/>
+        <source>Doxygen GUI</source>
+        <translation>Doxygen GUI (Doxywizard)</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="204"/>
+        <source>Open configuration file</source>
+        <translation>指定の設定ファイルを開きます</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="246"/>
+        <source>Error saving</source>
+        <translation>保存中に問題が発生</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="247"/>
+        <source>Error: cannot open the file %1 for writing.
+Reason given: %2</source>
+        <translation>書き込み用途では %1 を開けません。
+通知された理由は次の通りです: %2</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="281"/>
+        <source>Use current setting at startup?</source>
+        <translation>現況を起動時設定にしますか?</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="282"/>
+        <source>Do you want to save the current settings and use them next time Doxywizard starts?</source>
+        <translation>現況を今後のDoxywizard 起動時設定として保存します。
+起動時設定を置き換えて構いませんか?</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="296"/>
+        <source>Clear the list of recent files?</source>
+        <translation>最近の設定ファイル一覧を削除しますか?</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="297"/>
+        <source>Do you want to clear the list of recently loaded configuration files?</source>
+        <translation>最近使ったファイルの一覧を消します。
+差し支えありませんか?</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="315"/>
+        <source>Reset settings to their default values?</source>
+        <translation>初期設定へ戻しますか?</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="316"/>
+        <source>Do you want to revert all settings back to their original values?</source>
+        <translation>全設定を初期値に戻します。
+差し支えありませんか?</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="418"/>
+        <source>Doxygen path: </source>
+        <translation>Doxygenへのパス:</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="428"/>
+        <source>Can&apos;t find the doxygen command, make sure it&apos;s in your $$PATH.</source>
+        <translation>doxygen 本体が見つかりません。 $$PATH の内容をご確認ください。</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="432"/>
+        <source>Getting doxygen from: </source>
+        <translation>次のパスにある doxygen を使います:</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="468"/>
+        <source>Stop doxygen</source>
+        <translation>動作を中断</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="469"/>
+        <source>Status: running</source>
+        <translation>状態: 実行中</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="501"/>
+        <source>*** Doxygen has finished
+</source>
+        <translation>*** Doxygen は動作を完了しました</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="505"/>
+        <source>*** Cancelled by user
+</source>
+        <translation>*** 動作停止の指示を受け付けました</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="541"/>
+        <source>Save log file</source>
+        <translation>動作記録を保存</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="551"/>
+        <source>Output log saved</source>
+        <translation>動作記録を保存しました</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="555"/>
+        <source>Warning</source>
+        <translation>警告</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="556"/>
+        <source>ok</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="556"/>
+        <source>Cannot open file %1 for writing. Nothing saved.</source>
+        <translation>保存に失敗しました。 %1 を書き込み先として開くことができません。</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="580"/>
+        <source>Doxygen GUI frontend</source>
+        <translation>Doxygen/DoxyWizard</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="600"/>
+        <location filename="doxywizard.cpp" line="614"/>
+        <source>Unsaved changes</source>
+        <translation>変更点の保存について</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="601"/>
+        <source>Unsaved changes will be lost! Do you want to save the configuration file?</source>
+        <translation>未保存の変更点があります。設定ファイルを保存しますか?</translation>
+    </message>
+    <message>
+        <location filename="doxywizard.cpp" line="615"/>
+        <source>Unsaved changes will be lost! Do you want to continue?</source>
+        <translation>未保存の変更点があります。破棄した上で続行しますか?</translation>
+    </message>
+</context>
+<context>
+    <name>Step1</name>
+    <message>
+        <location filename="wizard.cpp" line="450"/>
+        <source>Provide some information about the project you are documenting</source>
+        <translation>入力元ソースコードや出力先などをご指定ください</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="459"/>
+        <source>Project name:</source>
+        <translation>プロジェクト名:</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="463"/>
+        <source>Project synopsis:</source>
+        <translation>プロジェクトの概要:</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="467"/>
+        <source>Project version or id:</source>
+        <translation>プロジェクトの版号ないし識別子:</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="471"/>
+        <source>Project logo:</source>
+        <translation>プロジェクトの意匠:</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="483"/>
+        <location filename="wizard.cpp" line="517"/>
+        <location filename="wizard.cpp" line="544"/>
+        <source>Select...</source>
+        <translation>選択…</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="507"/>
+        <source>Specify the directory to scan for source code</source>
+        <translation>入力元コードがあるディレクトリをご指定ください</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="513"/>
+        <source>Source code directory:</source>
+        <translation>ソースコードディレクトリ:</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="523"/>
+        <source>Scan recursively</source>
+        <translation>入れ子のディレクトリも対象</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="533"/>
+        <source>Specify the directory where doxygen should put the generated documentation</source>
+        <translation>出力先ディレクトリをご指定ください</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="540"/>
+        <source>Destination directory:</source>
+        <translation>出力先ディレクトリ:</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="569"/>
+        <source>Select project icon/image</source>
+        <translation>プロジェクトの図像・画像</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="582"/>
+        <source>Select source directory</source>
+        <translation>入力元ディレクトリの選択</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="599"/>
+        <source>Select destination directory</source>
+        <translation>出力先ディレクトリの選択</translation>
+    </message>
+</context>
+<context>
+    <name>Step2</name>
+    <message>
+        <location filename="wizard.cpp" line="700"/>
+        <source>Select the desired extraction mode:</source>
+        <translation>文章の引き出し方法をお選びください:</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="702"/>
+        <source>Documented entities only</source>
+        <translation>詳解を付けた項目のみ</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="707"/>
+        <source>All Entities</source>
+        <translation>すべての項目</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="712"/>
+        <source>Include cross-referenced source code in the output</source>
+        <translation>ソースコードも出力する（相互参照が付きます）</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="724"/>
+        <source>Select programming language to optimize the results for</source>
+        <translation>出力をどのプログラミング言語に合わせるかご指定ください</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="728"/>
+        <source>Optimize for C++ output</source>
+        <translation>C++ に合わせる</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="738"/>
+        <source>Optimize for C++/CLI output</source>
+        <translation>C++/CLI に合わせる</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="747"/>
+        <source>Optimize for Java or C# output</source>
+        <translation>Java や C# に合わせる</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="756"/>
+        <source>Optimize for C or PHP output</source>
+        <translation>C や PHP に合わせる</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="765"/>
+        <source>Optimize for Fortran output</source>
+        <translation>Fortran に合わせる</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="774"/>
+        <source>Optimize for VHDL output</source>
+        <translation>VHDL に合わせる</translation>
+    </message>
+</context>
+<context>
+    <name>Step3</name>
+    <message>
+        <location filename="wizard.cpp" line="840"/>
+        <source>Select the output format(s) to generate</source>
+        <translation>出力形式をお選びください</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="842"/>
+        <source>HTML</source>
+        <translation>HTML</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="846"/>
+        <source>plain HTML</source>
+        <translation>一般的な HTML</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="851"/>
+        <source>with navigation panel</source>
+        <translation>本文と連動できる索引の付与</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="855"/>
+        <source>prepare for compressed HTML (.chm)</source>
+        <translation>圧縮HTML(.chm)用の出力を行う</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="859"/>
+        <source>With search function</source>
+        <translation>検索機能を付ける</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="863"/>
+        <source>Change color...</source>
+        <translation>色を変更…</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="873"/>
+        <source>LaTeX</source>
+        <translation>LaTeX</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="878"/>
+        <source>as intermediate format for hyperlinked PDF</source>
+        <translation>リンク付きPDF生成用の中間出力</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="883"/>
+        <source>as intermediate format for PDF</source>
+        <translation>PDF生成用の中間出力</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="887"/>
+        <source>as intermediate format for PostScript</source>
+        <translation>PostScript用の中間出力</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="897"/>
+        <source>Man pages</source>
+        <translation>Unix系 Man ページ </translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="899"/>
+        <source>Rich Text Format (RTF)</source>
+        <translation>リッチテキストフォーマット(RTF)</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="901"/>
+        <source>XML</source>
+        <translation>XML</translation>
+    </message>
+</context>
+<context>
+    <name>Step4</name>
+    <message>
+        <location filename="wizard.cpp" line="1044"/>
+        <source>Diagrams to generate</source>
+        <translation>関係図の設定</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1046"/>
+        <source>No diagrams</source>
+        <translation>関係図なし</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1051"/>
+        <source>Use built-in class diagram generator</source>
+        <translation>自前で関係図を生成する</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1055"/>
+        <source>Use dot tool from the GraphViz package</source>
+        <translation>GraphViz (dot) を使う</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1060"/>
+        <source>Dot graphs to generate</source>
+        <translation>GraphViz 利用時の設定</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1062"/>
+        <source>Class diagrams</source>
+        <translation>クラス関係図を作る</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1064"/>
+        <source>Collaboration diagrams</source>
+        <translation>利用関係図を作る</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1066"/>
+        <source>Overall Class hierarchy</source>
+        <translation>クラス階層全体を対象にする</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1068"/>
+        <source>Include dependency graphs</source>
+        <translation>参照先ファイル関係図を作る</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1070"/>
+        <source>Included by dependency graphs</source>
+        <translation>参照元ファイル関係図を作る</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1072"/>
+        <source>Call graphs</source>
+        <translation>呼び出し先関係図を作る</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1074"/>
+        <source>Called by graphs</source>
+        <translation>呼び出し元関係図を作る</translation>
+    </message>
+</context>
+<context>
+    <name>TuneColorDialog</name>
+    <message>
+        <location filename="wizard.cpp" line="149"/>
+        <source>Tune the color of the HTML output</source>
+        <translation>HTML出力の色をご指定ください</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="154"/>
+        <source>Example output: use the sliders on the right to adjust the color</source>
+        <translation>出力例:/右端の三要素棒で色を補正できます</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="158"/>
+        <source>Ok</source>
+        <translation>決定</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="161"/>
+        <source>Cancel</source>
+        <translation>破棄</translation>
+    </message>
+</context>
+<context>
+    <name>Wizard</name>
+    <message>
+        <location filename="wizard.cpp" line="1196"/>
+        <source>Topics</source>
+        <translation>項目</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1198"/>
+        <location filename="wizard.cpp" line="1246"/>
+        <source>Project</source>
+        <translation>入力元/出力先</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1199"/>
+        <location filename="wizard.cpp" line="1252"/>
+        <source>Mode</source>
+        <translation>出力制御</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1200"/>
+        <location filename="wizard.cpp" line="1258"/>
+        <source>Output</source>
+        <translation>出力形式</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1201"/>
+        <location filename="wizard.cpp" line="1264"/>
+        <source>Diagrams</source>
+        <translation>関係図</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1216"/>
+        <source>Previous</source>
+        <translation>一つ前</translation>
+    </message>
+    <message>
+        <location filename="wizard.cpp" line="1218"/>
+        <source>Next</source>
+        <translation>一つ後</translation>
+    </message>
+</context>
+</TS>
diff --git a/addon/doxywizard/expert.cpp b/addon/doxywizard/expert.cpp
index 4c988c9..c735707 100644
--- a/addon/doxywizard/expert.cpp
+++ b/addon/doxywizard/expert.cpp
@@ -1,10 +1,10 @@
 #include <QtGui>
 #include <QtXml>
+#include <qmap.h>
 #include "expert.h"
 #include "inputbool.h"
 #include "inputstring.h"
 #include "inputint.h"
-#include "inputstring.h"
 #include "inputstrlist.h"
 #include "config.h"
 #include "version.h"
@@ -27,6 +27,8 @@ static QString convertToComment(const QString &s)
   }
 }
 
+static QMap<QString, QString> translatedTemplateDocs;
+
 void Expert::setHeader(const char *header)
 {
   m_header = SA(header);
@@ -64,6 +66,9 @@ Expert::Expert()
       exit(1);
     }
   }
+
+  addConfigDocs(&translatedTemplateDocs);
+
   m_rootElement = configXml.documentElement();
 
   createTopics(m_rootElement);
@@ -121,7 +126,7 @@ void Expert::createTopics(const QDomElement &rootElem)
     }
     childElem = childElem.nextSiblingElement();
   }
-  m_treeWidget->setHeaderLabels(QStringList() << SA("Topics"));
+  m_treeWidget->setHeaderLabels(QStringList() << tr("Topics"));
   m_treeWidget->insertTopLevelItems(0,items);
   connect(m_treeWidget,
           SIGNAL(currentItemChanged(QTreeWidgetItem *,QTreeWidgetItem *)),
@@ -133,28 +138,13 @@ static QString getDocsForNode(const QDomElement &child)
 {
   QString type = child.attribute(SA("type"));
   QString docs = SA("");
-  // read documentation text
-  QDomElement docsVal = child.firstChildElement();
-  while (!docsVal.isNull())
-  {
-    if (docsVal.tagName()==SA("docs") &&
-        docsVal.attribute(SA("doxywizard")) != SA("0"))
-    {
-      for (QDomNode n = docsVal.firstChild(); !n.isNull(); n = n.nextSibling())
-      {
-        QDomText t = n.toText();
-        if (!t.isNull()) docs+=t.data();
-      }
-      docs += SA("<br/>");
-    }
-    docsVal = docsVal.nextSiblingElement();
-  }
+  QDomElement docsVal;
 
   // for an enum we list the values
   if (type==SA("enum"))
   {
     docs += SA("<br/>");
-    docs += SA("Possible values are: ");
+    QString visList;
     int numValues=0;
     docsVal = child.firstChildElement();
     while (!docsVal.isNull())
@@ -172,55 +162,53 @@ static QString getDocsForNode(const QDomElement &child)
       if (docsVal.tagName()==SA("value"))
       {
         i++;
-        docs += SA("<code>") + docsVal.attribute(SA("name")) + SA("</code>");
+        visList += SA("<code>") + docsVal.attribute(SA("name")) + SA("</code>");
         QString desc = docsVal.attribute(SA("desc"));
         if (!desc.isEmpty())
         {
-          docs+= SA(" ")+desc;
+          visList+=Expert::tr(" %1", "for possible value list").arg(desc);
         }
         if (i==numValues-1)
         {
-          docs+=SA(" and ");
+          visList+=Expert::tr(" and ", "for possible value list");
         }
         else if (i==numValues)
         {
-          docs+=SA(".");
+          visList+=Expert::tr(".", "for possible value list");
         }
         else
         {
-          docs+=SA(", ");
+          visList+=Expert::tr(", ", "for possible value list");
         }
       }
       docsVal = docsVal.nextSiblingElement();
     }
+    docs+=Expert::tr("Possible values are: %1").arg(visList);
     docs+=SA("<br/>");
     docs+=SA("<br/>");
-    docs+=SA(" The default value is: <code>")+
-          child.attribute(SA("defval"))+
-          SA("</code>.");
-    docs+= SA("<br/>");
+    docs+=Expert::tr(" The default value is: <code>%1</code>.").arg(child.attribute(SA("defval")));
+    docs+=SA("<br/>");
   }
   else if (type==SA("int"))
   {
     docs+=SA("<br/>");
-    docs+=SA("Minimum value: ")+child.attribute(SA("minval"))+SA(", ");
-    docs+=SA("maximum value: ")+child.attribute(SA("maxval"))+SA(", ");
-    docs+=SA("default value: ")+child.attribute(SA("defval"))+SA(".");
-    docs+= SA("<br/>");
+    docs+=Expert::tr("Minimum value: %1, maximum value: %2, default value: %3")
+       .arg(child.attribute(SA("minval")))
+       .arg(child.attribute(SA("maxval")))
+       .arg(child.attribute(SA("defval")));
+    docs+=SA("<br/>");
   }
   else if (type==SA("bool"))
   {
     docs+=SA("<br/>");
     if (child.hasAttribute(SA("altdefval")))
     {
-      docs+=SA(" The default value is: system dependent.");
+      docs+=Expert::tr(" The default value is: system dependent.");
     }
     else
     {
       QString defval = child.attribute(SA("defval"));
-      docs+=SA(" The default value is: <code>")+
-            (defval==SA("1")?SA("YES"):SA("NO"))+
-            SA("</code>.");
+      docs+=Expert::tr(" The default value is: <code>%1</code>.").arg((defval==SA("1")?SA("YES"):SA("NO")));
     }
     docs+= SA("<br/>");
   }
@@ -263,19 +251,19 @@ static QString getDocsForNode(const QDomElement &child)
               QString desc = docsVal.attribute(SA("desc"));
               if (desc != SA(""))
               {
-                docs += SA(" ") + desc;
+                docs += Expert::tr(" %1", "for documented list").arg(desc);
               }
               if (i==numValues-1)
               {
-                docs += SA(" and ");
+                docs += Expert::tr(" and ", "for documented list");
               }
               else if (i==numValues)
               {
-                docs += SA(".");
+                docs += Expert::tr(".", "for documented list");
               }
               else
               {
-                docs += SA(", ");
+                docs += Expert::tr(", ", "for documented list");
               }
             }
           }
@@ -293,7 +281,7 @@ static QString getDocsForNode(const QDomElement &child)
       if (defval != SA(""))
       {
         docs+=SA("<br/>");
-        docs += SA(" The default directory is: <code>") + defval + SA("</code>.");
+        docs += Expert::tr(" The default directory is: <code>%1</code>.").arg(defval);
         docs += SA("<br/>");
       }
     }
@@ -305,11 +293,11 @@ static QString getDocsForNode(const QDomElement &child)
         docs+=SA("<br/>");
         if (abspath != SA("1"))
         {
-          docs += SA(" The default file is: <code>") + defval + SA("</code>.");
+          docs += Expert::tr(" The default file is: <code>%1</code>.").arg(defval);
         }
         else
         {
-          docs += SA(" The default file (with absolute path) is: <code>") + defval + SA("</code>.");
+          docs += Expert::tr(" The default file (with absolute path) is: <code>%1</code>.").arg(defval);
         }
         docs += SA("<br/>");
       }
@@ -318,7 +306,7 @@ static QString getDocsForNode(const QDomElement &child)
         if (abspath == SA("1"))
         {
           docs+=SA("<br/>");
-          docs += SA(" The file has to be specified with full path.");
+          docs += Expert::tr(" The file has to be specified with full path.");
           docs += SA("<br/>");
         }
       }
@@ -328,8 +316,8 @@ static QString getDocsForNode(const QDomElement &child)
       if (defval != SA(""))
       {
         docs+=SA("<br/>");
-        docs += SA(" The default value is: <code>") + defval + SA("</code>.");
-        docs += SA("<br/>");
+        docs+=Expert::tr(" The default value is: <code>%1</code>.").arg(defval);
+        docs+=SA("<br/>");
       }
     }
   }
@@ -338,22 +326,24 @@ static QString getDocsForNode(const QDomElement &child)
   {
     QString dependsOn = child.attribute(SA("depends"));
     docs+=SA("<br/>");
-    docs+=  SA(" This tag requires that the tag \\ref cfg_");
-    docs+=  dependsOn.toLower();
-    docs+=  SA(" \"");
-    docs+=  dependsOn.toUpper();
-    docs+=  SA("\" is set to <code>YES</code>.");
+    docs+=Expert::tr(" This tag requires that the tag \\ref cfg_%1 \"%2\" is set to <code>YES</code>.")
+          .arg(dependsOn.toLower())
+          .arg(dependsOn.toUpper());
   }
 
+  return docs;
+}
+
+static QString replaceDoxygenMarkUpToHtml(QString docs)
+{
   // Remove / replace doxygen markup strings
   // the regular expressions are hard to read so the intention will be given
   QRegExp regexp;
-  // remove \n at end and replace by a space
-  regexp.setPattern(SA("\\n$"));
-  docs.replace(regexp,SA(" "));
-  // remove <br> at end
-  regexp.setPattern(SA("<br> *$"));
-  docs.replace(regexp,SA(" "));
+  
+  // replace \n to <br/>, because QTextBrowser treats \n as white-space.
+  regexp.setPattern(SA("\\n"));
+  docs.replace(regexp,SA("<br/>"));
+
   // \c word -> <code>word</code>; word ends with ')', ',', '.' or ' '
   regexp.setPattern(SA("\\\\c[ ]+([^ \\)]+)\\)"));
   docs.replace(regexp,SA("<code>\\1</code>)"));
@@ -371,7 +361,7 @@ static QString getDocsForNode(const QDomElement &child)
   regexp.setPattern(SA("`([^`]+)`"));
   docs.replace(regexp,SA("<code>\\1</code>"));
   // \ref key "desc" -> <code>desc</code>
-  regexp.setPattern(SA("\\\\ref[ ]+[^ ]+[ ]+\"([^ ]+)\""));
+  regexp.setPattern(SA("\\\\ref[ ]+[^ ]+[ ]+\"([^\"]+)\""));
   docs.replace(regexp,SA("<code>\\1</code> "));
   //\ref specials
   // \ref <key> -> description
@@ -383,10 +373,10 @@ static QString getDocsForNode(const QDomElement &child)
   docs.replace(regexp,SA("\"Linking to external documentation\""));
   // fallback for not handled
   docs.replace(SA("\\\\ref"),SA(""));
-  // \b word -> <b>word<\b>
+  // \b word -> <b>word</b>
   regexp.setPattern(SA("\\\\b[ ]+([^ ]+) "));
   docs.replace(regexp,SA("<b>\\1</b> "));
-  // \e word -> <em>word<\em>
+  // \e word -> <em>word</em>
   regexp.setPattern(SA("\\\\e[ ]+([^ ]+) "));
   docs.replace(regexp,SA("<em>\\1</em> "));
   // \note -> <br>Note:
@@ -421,8 +411,8 @@ static QString getDocsForNode(const QDomElement &child)
   // \> -> &gt;
   docs.replace(SA("\\<"),SA("&lt;"));
   docs.replace(SA("\\>"),SA("&gt;"));
-  regexp.setPattern(SA(" (http:[^ \\)]*)([ \\)])"));
-  docs.replace(regexp,SA(" <a href=\"\\1\">\\1</a>\\2"));
+  regexp.setPattern(SA("\\b(http:[^\\s\\)]+)"));
+  docs.replace(regexp,SA("<a href=\"\\1\">\\1</a>"));
   // LaTeX name as formula -> LaTeX
   regexp.setPattern(SA("\\\\f\\$\\\\mbox\\{\\\\LaTeX\\}\\\\f\\$"));
   docs.replace(regexp,SA("LaTeX"));
@@ -447,19 +437,22 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
     QString setting = child.attribute(SA("setting"));
     if (setting.isEmpty() || IS_SUPPORTED(setting.toAscii()))
     {
+      const QString theId = child.attribute(SA("id"));
+      QString docs = translatedTemplateDocs.value(theId) + SA("<br/>");
       QString type = child.attribute(SA("type"));
-      QString docs = getDocsForNode(child);
+      docs += getDocsForNode(child);
+      docs = replaceDoxygenMarkUpToHtml(docs);
       if (type==SA("bool"))
       {
         InputBool *boolOption = 
           new InputBool(
               layout,row,
-              child.attribute(SA("id")),
+              theId,
               child.attribute(SA("defval"))==SA("1"),
               docs
               );
         m_options.insert(
-            child.attribute(SA("id")),
+            theId,
             boolOption
             );
         connect(boolOption,SIGNAL(showHelp(Input*)),SLOT(showHelp(Input*)));
@@ -484,14 +477,14 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
         InputString *stringOption = 
           new InputString(
               layout,row,
-              child.attribute(SA("id")),
+              theId,
               child.attribute(SA("defval")),
               mode,
               docs,
               child.attribute(SA("abspath"))
               );
         m_options.insert(
-            child.attribute(SA("id")),
+            theId,
             stringOption
             );
         connect(stringOption,SIGNAL(showHelp(Input*)),SLOT(showHelp(Input*)));
@@ -501,7 +494,7 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
       {
         InputString *enumList = new InputString(
             layout,row,
-            child.attribute(SA("id")),
+            theId,
             child.attribute(SA("defval")),
             InputString::StringFixed,
             docs
@@ -517,7 +510,7 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
         }
         enumList->setDefault();
 
-        m_options.insert(child.attribute(SA("id")),enumList);
+        m_options.insert(theId,enumList);
         connect(enumList,SIGNAL(showHelp(Input*)),SLOT(showHelp(Input*)));
         connect(enumList,SIGNAL(changed()),SIGNAL(changed()));
       }
@@ -526,14 +519,14 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
         InputInt *intOption = 
           new InputInt(
               layout,row,
-              child.attribute(SA("id")),
+              theId,
               child.attribute(SA("defval")).toInt(),
               child.attribute(SA("minval")).toInt(),
               child.attribute(SA("maxval")).toInt(),
               docs
               );
         m_options.insert(
-            child.attribute(SA("id")),
+            theId,
             intOption
             );
         connect(intOption,SIGNAL(showHelp(Input*)),SLOT(showHelp(Input*)));
@@ -572,13 +565,13 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
         InputStrList *listOption = 
           new InputStrList(
               layout,row,
-              child.attribute(SA("id")),
+              theId,
               sl,
               mode,
               docs
               );
         m_options.insert(
-            child.attribute(SA("id")),
+            theId,
             listOption
             );
         connect(listOption,SIGNAL(showHelp(Input*)),SLOT(showHelp(Input*)));
@@ -744,7 +737,7 @@ bool Expert::writeConfig(QTextStream &t,bool brief)
   }
 
   QTextCodec *codec = 0;
-  Input *option = m_options[QString::fromAscii("DOXYFILE_ENCODING")];
+  Input *option = m_options[SA("DOXYFILE_ENCODING")];
   if (option)
   {
     codec = QTextCodec::codecForName(option->value().toString().toAscii());
@@ -781,12 +774,12 @@ void Expert::showHelp(Input *option)
   {
     m_inShowHelp = TRUE;
     m_helper->setText(
-        QString::fromAscii("<qt><b>")+option->id()+
-        QString::fromAscii("</b><br>")+
-        QString::fromAscii("<br/>")+
+        SA("<qt><b>")+option->id()+
+        SA("</b><br>")+
+        SA("<br/>")+
         option->docs().
         replace(QChar::fromAscii('\n'),QChar::fromAscii(' '))+
-        QString::fromAscii("</qt>")
+        SA("</qt>")
         );
     m_inShowHelp = FALSE;
   }
@@ -825,7 +818,7 @@ void Expert::resetToDefaults()
 static bool stringVariantToBool(const QVariant &v)
 {
   QString s = v.toString().toLower();
-  return s==QString::fromAscii("yes") || s==QString::fromAscii("true") || s==QString::fromAscii("1");
+  return s==SA("yes") || s==SA("true") || s==SA("1");
 } 
 
 static bool getBoolOption(
@@ -847,7 +840,7 @@ static QString getStringOption(
 
 bool Expert::htmlOutputPresent(const QString &workingDir) const
 {
-  bool generateHtml = getBoolOption(m_options,QString::fromAscii("GENERATE_HTML"));
+  bool generateHtml = getBoolOption(m_options,SA("GENERATE_HTML"));
   if (!generateHtml || workingDir.isEmpty()) return false;
   QString indexFile = getHtmlOutputIndex(workingDir);
   QFileInfo fi(indexFile);
@@ -856,8 +849,8 @@ bool Expert::htmlOutputPresent(const QString &workingDir) const
 
 QString Expert::getHtmlOutputIndex(const QString &workingDir) const
 {
-  QString outputDir = getStringOption(m_options,QString::fromAscii("OUTPUT_DIRECTORY"));
-  QString htmlOutputDir = getStringOption(m_options,QString::fromAscii("HTML_OUTPUT"));
+  QString outputDir = getStringOption(m_options,SA("OUTPUT_DIRECTORY"));
+  QString htmlOutputDir = getStringOption(m_options,SA("HTML_OUTPUT"));
   //printf("outputDir=%s\n",qPrintable(outputDir));
   //printf("htmlOutputDir=%s\n",qPrintable(htmlOutputDir));
   QString indexFile = workingDir;
@@ -867,7 +860,7 @@ QString Expert::getHtmlOutputIndex(const QString &workingDir) const
   }
   else // append
   { 
-    indexFile += QString::fromAscii("/")+outputDir;
+    indexFile += SA("/")+outputDir;
   }
   if (QFileInfo(htmlOutputDir).isAbsolute()) // override
   {
@@ -875,27 +868,27 @@ QString Expert::getHtmlOutputIndex(const QString &workingDir) const
   }
   else // append
   {
-    indexFile += QString::fromAscii("/")+htmlOutputDir;
+    indexFile += SA("/")+htmlOutputDir;
   }
-  indexFile+=QString::fromAscii("/index.html");
+  indexFile+=SA("/index.html");
   return indexFile;
 }
 
 bool Expert::pdfOutputPresent(const QString &workingDir) const
 {
-  bool generateLatex = getBoolOption(m_options,QString::fromAscii("GENERATE_LATEX"));
-  bool pdfLatex = getBoolOption(m_options,QString::fromAscii("USE_PDFLATEX"));
+  bool generateLatex = getBoolOption(m_options,SA("GENERATE_LATEX"));
+  bool pdfLatex = getBoolOption(m_options,SA("USE_PDFLATEX"));
   if (!generateLatex || !pdfLatex) return false;
-  QString latexOutput = getStringOption(m_options,QString::fromAscii("LATEX_OUTPUT"));
+  QString latexOutput = getStringOption(m_options,SA("LATEX_OUTPUT"));
   QString indexFile;
   if (QFileInfo(latexOutput).isAbsolute())
   {
-    indexFile = latexOutput+QString::fromAscii("/refman.pdf");
+    indexFile = latexOutput+SA("/refman.pdf");
   }
   else
   {
-    indexFile = workingDir+QString::fromAscii("/")+
-                latexOutput+QString::fromAscii("/refman.pdf");
+    indexFile = workingDir+SA("/")+
+                latexOutput+SA("/refman.pdf");
   }
   QFileInfo fi(indexFile);
   return fi.exists() && fi.isFile();
diff --git a/addon/doxywizard/for_lupdate_doxywizard.pro.in b/addon/doxywizard/for_lupdate_doxywizard.pro.in
new file mode 100644
index 0000000..5a1ecec
--- /dev/null
+++ b/addon/doxywizard/for_lupdate_doxywizard.pro.in
@@ -0,0 +1,5 @@
+# This project file used only as the parameter of 'lupdate' command.
+# The 'lupdate' command don't search configdoc.cpp through doxywizard.pro.
+
+include(doxywizard.pro)
+SOURCES *= configdoc.cpp
diff --git a/addon/doxywizard/wizard.cpp b/addon/doxywizard/wizard.cpp
index ce989e7..f13a7c2 100644
--- a/addon/doxywizard/wizard.cpp
+++ b/addon/doxywizard/wizard.cpp
@@ -1193,7 +1193,7 @@ Wizard::Wizard(const QHash<QString,Input*> &modelData, QWidget *parent) :
 {
   m_treeWidget = new QTreeWidget;
   m_treeWidget->setColumnCount(1);
-  m_treeWidget->setHeaderLabels(QStringList() << QString::fromAscii("Topics"));
+  m_treeWidget->setHeaderLabels(QStringList() << tr("Topics"));
   QList<QTreeWidgetItem*> items;
   items.append(new QTreeWidgetItem((QTreeWidget*)0,QStringList(tr("Project"))));
   items.append(new QTreeWidgetItem((QTreeWidget*)0,QStringList(tr("Mode"))));
diff --git a/configure b/configure
index 9c3d28b..38a9350 100755
--- a/configure
+++ b/configure
@@ -868,7 +868,7 @@ done
 cat src/libdoxycfg.t.in | sed -e "s|%%FLEX%%|$f_flex|g" -e "s|%%BISON%%|$f_bison|g" -e "s|%%PYTHON%%|$f_python|g" > src/libdoxycfg.t
 cat src/libdoxygen.t.in | sed -e "s|%%FLEX%%|$f_flex|g" -e "s|%%BISON%%|$f_bison|g" -e "s|%%PYTHON%%|$f_python|g" > src/libdoxygen.t
 
-f_inprofiles="qtools/qtools.pro.in src/libdoxygen.pro.in src/libdoxycfg.pro.in src/doxygen.pro.in addon/doxywizard/doxywizard.pro.in addon/doxmlparser/src/doxmlparser.pro.in addon/doxmlparser/test/xmlparse.pro.in addon/doxmlparser/examples/metrics/metrics.pro.in libmd5/libmd5.pro.in addon/doxyapp/doxyapp.pro.in addon/doxysearch/doxysearch.pro.in addon/doxysearch/doxyindexer.pro.in" 
+f_inprofiles="qtools/qtools.pro.in src/libdoxygen.pro.in src/libdoxycfg.pro.in src/doxygen.pro.in addon/doxywizard/doxywizard.pro.in addon/doxywizard/for_lupdate_doxywizard.pro.in addon/doxmlparser/src/doxmlparser.pro.in addon/doxmlparser/test/xmlparse.pro.in addon/doxmlparser/examples/metrics/metrics.pro.in libmd5/libmd5.pro.in addon/doxyapp/doxyapp.pro.in addon/doxysearch/doxysearch.pro.in addon/doxysearch/doxyindexer.pro.in" 
 
 for i in $f_inprofiles ; do
      SRC=$i
diff --git a/src/config.xml b/src/config.xml
index eff8cff..a15e3a3 100644
--- a/src/config.xml
+++ b/src/config.xml
@@ -403,7 +403,7 @@ Go to the <a href="commands.html">next</a> section or return to the
 <![CDATA[
  If the \c FULL_PATH_NAMES tag is set to \c YES doxygen will prepend the full
  path before files name in the file list and in the header files. If set
- to \c NO the shortest path that makes the file name unique will be used
+ to \c NO the shortest path that makes the file name unique will be used.
 ]]>
       </docs>
     </option>
@@ -1200,7 +1200,7 @@ FILE_VERSION_INFO = "cleartool desc -fmt \%Vn"
  warning originated and the warning text.
  Optionally the format may contain 
  <code>$version</code>, which will be replaced by the version of the file (if it could 
- be obtained via \ref cfg_file_version_filter "FILE_VERSION_FILTER") 
+ be obtained via \ref cfg_file_version_filter "FILE_VERSION_FILTER"). 
 ]]>
       </docs>
     </option>
@@ -1325,7 +1325,7 @@ FILE_VERSION_INFO = "cleartool desc -fmt \%Vn"
  certain files from those directories.
  <br>Note that the wildcards are matched 
  against the file with absolute path, so to exclude all test directories 
- for example use the pattern `*``/test/``*`
+ for example use the pattern `*``/test/``*`.
 ]]>
       </docs>
     </option>
@@ -1337,9 +1337,6 @@ FILE_VERSION_INFO = "cleartool desc -fmt \%Vn"
  output. The symbol name can be a fully qualified name, a word, or if the 
  wildcard `*` is used, a substring. Examples: `ANamespace`, `AClass`, 
  `AClass::ANamespace`, `ANamespace::*Test` 
- <br>Note that the wildcards are matched against the file with absolute path, 
- so to exclude all test directories use the pattern 
- `*``/test/``*`
 ]]>
       </docs>
     </option>
@@ -1608,7 +1605,7 @@ to disable this feature.
       <docs>
 <![CDATA[
  If the \c GENERATE_HTML tag is set to \c YES doxygen will
- generate HTML output
+ generate HTML output.
 ]]>
       </docs>
     </option>
@@ -2061,7 +2058,7 @@ The \c DOCSET_PUBLISHER_NAME tag identifies the documentation publisher.
     <option type='string' id='QHP_VIRTUAL_FOLDER' format='string' defval='doc' depends='GENERATE_QHP'>
       <docs>
 <![CDATA[
- The \c QHP_VIRTUAL_FOLDER tag specifies the namespace to use when
+ The \c QHP_VIRTUAL_FOLDER tag specifies the virtual folder to use when
  generating Qt Help Project output. For more information please see
  <a href="http://qt-project.org/doc/qt-4.8/qthelpproject.html#virtual-folders">Qt Help Project / Virtual Folders</a>.
 ]]>
@@ -2508,7 +2505,7 @@ EXTRA_PACKAGES=times
  the last chapter. If it is left blank doxygen will generate a 
  standard footer.
  
- <br>Note: Only use a user-defined footer if you know what you are doing!
+ <br>Note: Only use a user-defined footer if you know what you are doing.
 ]]>
       </docs>
     </option>
@@ -3051,7 +3048,7 @@ to be found in the default search path.
  available from the \c path. This tool is part of 
  <a href="http://www.graphviz.org/">Graphviz</a>, a graph 
  visualization toolkit from AT\&T and Lucent Bell Labs. The other options in 
- this section have no effect if this option is set to \c NO
+ this section have no effect if this option is set to \c NO.
 ]]>
       </docs>
     </option>
diff --git a/src/configgen.py b/src/configgen.py
index 4aed8bf..1e8937e 100755
--- a/src/configgen.py
+++ b/src/configgen.py
@@ -133,6 +133,19 @@ def parseHeader(node,objName):
 			print "              \"%s\"" % (line)
 	print "             );"
 
+def pickTemplateDocument(node):
+        doc = ""
+        type = node.getAttribute('type')
+        if type == 'obsolete':
+                return doc
+        for n in node.childNodes:
+                if n.nodeName != 'docs' \
+                or n.getAttribute('doxyfile') == '0' \
+                or n.nodeType != Node.ELEMENT_NODE:
+                        continue
+                doc += parseDocs(n)
+        return transformDocs(doc)
+                
 
 def prepCDocs(node):
 	type = node.getAttribute('type')
@@ -356,6 +369,25 @@ def parseGroupCDocs(node):
 						print "              \"%s\"" % (line)
 				print "          );"
 
+def appendInsertingFunction(node):
+	for n in node.childNodes:
+		if n.nodeType == Node.ELEMENT_NODE:
+			type = n.getAttribute('type')
+			if type != 'obsolete':
+				name = n.getAttribute('id')
+				docC = pickTemplateDocument(n)
+				print "  map->insert(SA(\"%s\"), tr(" % (name)
+				rng = len(docC)
+				for i in range(rng):
+					line = docC[i]
+					if i != rng - 1:  # since we go from 0 to rng-1
+						# If you want to fix here, don't forget to
+						# notice translators of doxy"wizard".
+						print "              \"%s\\n\"" % (line)
+					else:
+						print "              \"%s\"" % (line)
+				print "              ));"
+
 def parseOptionDoc(node, first):
 	# Handling part for documentation
 	name = node.getAttribute('id')
@@ -602,6 +634,9 @@ def main():
 		print " */"
 		print "#include \"configdoc.h\""
 		print "#include \"docintf.h\""
+		print "#include <QCoreApplication>"
+		print "#include <qmap.h>"
+		print "#include <qstring.h>"
 		print ""
 		print "void addConfigDocs(DocIntf *doc)"
 		print "{"
@@ -614,6 +649,28 @@ def main():
 				if (n.nodeName == "group"):
 					parseGroupCDocs(n)
 		print "}"
+		print ""
+		print "class ConfigDoc"
+		print "{"
+		print "  Q_DECLARE_TR_FUNCTIONS(ConfigDoc)"
+		print "public:"
+		print "  void addConfigDocs(QMap<QString, QString>* map);"
+		print "  QString SA(const char *s) { return QString::fromAscii(s); }"
+		print "};"
+		print ""
+		print "void addConfigDocs(QMap<QString, QString>* map)"
+		print "{"
+		print "  ConfigDoc().addConfigDocs(map);"
+		print "}"
+		print ""
+		print "void ConfigDoc::addConfigDocs(QMap<QString, QString>* map)"
+		print "{"
+		for n in elem.childNodes:
+			if n.nodeType == Node.ELEMENT_NODE:
+				if (n.nodeName == "group"):
+					appendInsertingFunction(n)
+		print "}"
+		print ""
 
 if __name__ == '__main__':
 	main()
